var Dfe11000_LancamentoEntrada_Controller = function(ScreenService, templateManager, localStorageEngine, Df11000_Lancamento_Service, Df11000_Lancamento_Repositories, General, Dfe11000_LancamentoEntrada_Service, ValidacoesEstoque_Service, ZhFilterPreferences, ZHPromise, metaDataFactory, eventEngine, MessageService, Lib00206_InfComplProduto_Controller) {

    var self = this;
    var atualizaEstoque;
    var sitSugAlmox;
    var datasourceRelacionamento;
    var utilizaControladoria;
    var atualizouRelacionamento = false;

    /* ************************* Lancamento Entrada - Gerais ********************************* */

    const MESSAGES = {
        TIPO_OPERACAO_BLOQ_FORNECEDOR: {
            type: 'ERROR'
        },
        CHAVE_ACESSO_INVALIDA: {
            type: 'ALERT'
        },
        CHAVE_ACESSO_UTILIZADA: {
            type: 'ALERT'
        },
        PRODUTO_JA_RELACIONADO: {
            type: 'ALERT'
        },
        EXISTE_PRODUTOS_NAO_RELACIONADO: {
            type: 'ERROR'
        },
        NF_ORIGEM_NECESSARIA: {
            type: 'ERROR'
        },
        NF_ORIGEM_NAO_NECESSARIA: {
            type: 'ALERT'
        },
        NF_ORIGEM_NAO_CADASTRADA: {
            type: 'ERROR'
        },
        NFS_ORIGEM_NAO_CADASTRADAS: {
            type: 'ERROR'
        },
        AF_OBRIGATORIA: {
            type: 'INFORMATION'
        },
        AF_OBRIGATORIA_E_NENHUMA_ENCONTRADA: {
            type: 'ALERT'
        },
        AF_OBRIGATORIA_E_NENHUMA_SELECIONADA: {
            type: 'ERROR'
        },
        AF_OBRIGATORIA_E_INSUFICIENTE: {
            type: 'ALERT'
        },
        AFS_OBRIGATORIAS_E_INSUFICIENTES: {
            type: 'ALERT'
        },
        PERMITE_LANCAMENTO_MANUAL: {
            type: 'INFORMATION'
        }
    };
    
    this.preLoadAutocomplete = function(widget){
      if(widget.dataSource.data.length === 0)
        widget.reload();
    };

    const showMessageDfe = messageName => {
        const data = MESSAGES[messageName];

        return MessageService.showMessageByCode(messageName, null, data);
    };
    

    var requestError = function(error) {
        if (typeof error === 'string') {
            return error in MESSAGES ? showMessageDfe(error) : ScreenService.showMessage(error, 'ERROR');
        }

        if (Array.isArray(error)) {
            var erros = error.join(', ');
            return ScreenService.showMessage(erros, 'ERROR');
        }

        if (typeof error === 'object' && !!error.data) {
            return error.data.error in MESSAGES ?
                showMessageDfe(error.data.error) : ScreenService.showMessage(error.data.error, 'ERROR');
        }

        return ScreenService.showMessage('Tempo de execução se esgotou.<br>Por favor, tente novamente!', 'ERROR');
    };
    
    var getItensWidget = function(){
        return templateManager.container.getWidget("itens");
    };
    
    this.getWidget = (name) => {
        return templateManager.container.getWidget(name);
    };
    
    this.getDataSourceWidget = name => {
        return templateManager.container.getWidget(name).dataSource.data;
    };
    
    //Função que ajusta casas decimais de valor unitario de acordo com o parametro
    //Desativada por enquanto até futura definição
    this.ajustaCasasDecimais = function(){
        var itemsWidget = getItensWidget();
        var fieldItem = itemsWidget.getField('VRUNITITEM');
        
        /*General.callRestEngine('df#/crud/paramgeral', 'FilterData', []).then(function(success) {
            if(success.dataset.paramgeral[0]){
                var paramgeral = success.dataset.paramgeral[0];
                fieldItem.mask.params.precision = paramgeral.NRDECITOTANF;
            }
        });*/
    };


    const prepareAndCleanTaxes = tax => {
        tax.__is_new = true;

        tax.VRCONTIMPOIT = 0;
        tax.VRREDBCIMPOIT = 0;
        tax.VRBCALCIMPOIT = 0;
        tax.VRPDEDIMPOIT = 0;

        return tax;
    };

    const alteraTabelasImpostos = ({CDFILIAL, NRLANCTONF}) => Df11000_Lancamento_Service.getDataSourceItensImpostos()
        .then(taxes => taxes.map(prepareAndCleanTaxes))
        .then(Df11000_Lancamento_Service.salvaImpostosTmpItem)
        .then(() => Dfe11000_LancamentoEntrada_Service.limpaTrabsLancamento(CDFILIAL, NRLANCTONF));
        

    const alteraStatusNotafiscal = ({currentRow}, needSaveCabecalho = true) => {
        
        //needSaveCabecalho, caso seja true, salva o cabecalho na chamada. Resolve o problema da nota pendente que acusa duplicidade.
        
        let deferred = ZHPromise.defer();

        if (currentRow.IDSTATUS !== 'D') {
            currentRow.IDSTATUS = 'D';

            validaEdicaoNota();
            
            if(needSaveCabecalho) Df11000_Lancamento_Service.salvaCabecalho(currentRow).then().catch(requestError);
            
            if(currentRow.IDNFGERADAVIAXML != 'S') {
                alteraTabelasImpostos(currentRow).then(deferred.resolve);
            } else {
                salvaImpostosTmpItemNotaXML();
            }
            
        } else
            deferred.resolve();

        return deferred.promise;
    };

    //Evento chamado ao sair da tela de lançamento de nota - deprecated on list
    this.voltarListaLancamentosNotas = function(args) {
        removeDataSourcesConsultaLancEntradaActionEvent();
        General.backOrCancel(args);
        args.owner.widget.reload();
    };

    const criaDetalhesLancamentoWidgetAfterMoveRow = consultaLancamentoRow =>
        Df11000_Lancamento_Service.criaDetalhesLancamento(consultaLancamentoRow)
            .then(lancamentoSaida => {
                templateManager.container.getWidget('itens').dataSource.data = lancamentoSaida.ITENS;
                templateManager.container.getWidget('encargos').dataSource.data = lancamentoSaida.ENCARGO;
                templateManager.container.getWidget('vencimentos').dataSource.data = lancamentoSaida.VENCIMENTO;
                templateManager.container.getWidget('dados_adicionais').dataSource.data = lancamentoSaida.DADOSADICIONAIS;
                templateManager.container.getWidget('detComb').dataSource.data = lancamentoSaida.ITENSCOMBS;
            });

    var validaEdicaoNota = function() {
        var lancamentoNotaWidget = getCabecalhoWidget();
        var row = lancamentoNotaWidget.currentRow;
        var statusNota = lancamentoNotaWidget.currentRow.IDSTATUS || 'D';
        var statusNotaTransmissao = lancamentoNotaWidget.currentRow.IDSTATUSNFE;
        var situacaoSefaz;
        
        var notaOl = lancamentoNotaWidget.currentRow.DSNOTAFISORIGOL != null;
        var notaCanceladaOuAprovada = (statusNota === 'A' || statusNota === 'C');
        var notaTransmissao = (statusNotaTransmissao === 'T' || statusNotaTransmissao === 'A' || statusNotaTransmissao === 'C' || statusNotaTransmissao === 'D');
        var permiteEditarNota = (!notaCanceladaOuAprovada && !notaTransmissao && (statusNota === 'D' || statusNota === 'P' || statusNota === 'L') && !notaOl);
        var allActions = lancamentoNotaWidget.getActions();
        let actionsAprovacao = {actAprovarLancamento:{}, actCancelarAprovacao:{}, actAuditarLancamento:{}};

        var invisibleActions = allActions.filter(action => {
            var widgetName = action.widget.name;
            var actionName = action.name.toLowerCase();
            var isActionVoltar = (actionName.indexOf('voltar') === -1);
            var novaNota = (actionName.indexOf('novo') !== -1 && widgetName === 'cabecalho');
            var controleLancRetroativo = (actionName.indexOf('controlelancretro') !== -1 && widgetName === 'cabecalho');
            var zeedhiWidgets = (widgetName !== 'filterPopup' && widgetName !== 'stripe');
            return (isActionVoltar && zeedhiWidgets && !novaNota && !controleLancRetroativo);
        });

        invisibleActions.forEach(action => {
            action.isVisible = permiteEditarNota;

            if (action.name.toLowerCase().indexOf('fecharnota') !== -1 && statusNota === 'P') {
                action.isVisible = false;
            }
            
            if(action.name === 'actDocumentosComposicaoCustos') {
                validaVisibilidadeActionDocComp(lancamentoNotaWidget);         
            }
            
            if(statusNota === 'L' 
                && action.name.toLowerCase().indexOf('fecharnota') === -1 
                && action.name !== 'actCancelarCabecalho'){
                action.isVisible = false;
            }
            
            if(action.name.indexOf('actApagarCabecalho') !== -1) {
                action.isVisible = !notaOl;
            } 
            
            if(action.name.indexOf('DOWNLOAD') !== -1) {
                action.isVisible = true;
            }
            if(action.name === 'actApagarCabecalho'){
                if(lancamentoNotaWidget.currentRow.IDSTATUSNFE  === 'R'){
                    General.callRestEngine("df#/consultaSituacaoAtualNF", "Row", row).then((sucess) => {
                        if(sucess.dataset.consultaSituacaoAtualNfeNF.cStat){
                            var status = sucess.dataset.consultaSituacaoAtualNfeNF.cStat;
                            if(status == 101){
                                situacaoSefaz = "C";
                            }else if(status == 110 || status== 301 || status == 302){
                                situacaoSefaz = "D";
                            }else if(status == 100){
                               situacaoSefaz = "A";
                            }else{
                                situacaoSefaz = "R";
                            }
                            if(situacaoSefaz === 'R'){
                                //deixa excluir nota
                                 action.isVisible = true;
                            }else{
                                //sincroniza nota
                                action.isVisible = false;
                                //localStorageEngine.getDataSource("df#/config_transmissao").then(function(transmissao){
                                    //row.CONFIG = transmissao[0].config;
                                    General.callRestEngine("df#/sincronizaDadosNF", "Row", row).then((sucess) => {
                                    });
                                //});
                            }
                        }
                    });
                }
            }
            
            if(action.name in actionsAprovacao) action.isVisible = true;
        });

        var encargoInlineEdit = lancamentoNotaWidget.container.getWidget('encargos').getField('VRITEMENCA');
        if (permiteEditarNota) {
            encargoInlineEdit.inlineEditable = 'number';
        } else {
            delete encargoInlineEdit.inlineEditable;
        }
        
        lancamentoNotaWidget.redraw();
    };
    
    this.vencimentoWidgetAfterLoadDataSource = function(){
        var vencimentoWidget = templateManager.container.getWidget('vencimentos');
        
        if(vencimentoWidget.dataSource.data.length == 0){
            vencimentoWidget.dataSource.reload();
        }
    };

    this.validacoesNotaAfterMoveRow = function(consultaLancamentoArgs, widgetCabecalho) {
        var cabecalhoWidget = widgetCabecalho ? widgetCabecalho : consultaLancamentoArgs.owner;
        var consultaLancamentoRow = widgetCabecalho ? widgetCabecalho.currentRow : consultaLancamentoArgs.row;
        removeDataSourcesConsultaLancEntradaActionEvent();

        if ('NRLANCTONF' in consultaLancamentoRow)
            criaDetalhesLancamentoWidgetAfterMoveRow(consultaLancamentoRow);

        validaEdicaoNota();
        alteraVisibilidadeCampoInscricao();

        validaCampoModDocFiscal(cabecalhoWidget, consultaLancamentoRow);

        var cbutilizaafField = cabecalhoWidget.getField('CBUTILIZAAF');
        cbutilizaafField.readOnly = (!consultaLancamentoRow.CDTIPOOPER || !consultaLancamentoRow.CDFORNECED);
        
        this.habilitaTabProdutosOuNotas(cabecalhoWidget);
        
        cabecalhoWidget.getField('NMTIPOOPER').reload().then(() => {
            let widget = templateManager.container.getActiveWidget();
            if(!widget.editing) { //True = Visualizar nota.
                this.controlVisibilityLocalPrestServ(widget);
            }
        });
        
    };

    
this.fecharNota = function(args) {
        var row, forcaFechamento;
        var cabecalhoWidget = templateManager.container.getWidget('cabecalho');
        
        var rowValidaProdutosEntradaEst;
        var arrayProdsFechamento = templateManager.container.getWidget('itens').dataSource.data;
        var produtos = [];
        arrayProdsFechamento.forEach(produto =>{   
            if(produto.CDPRODUTO != null){
                var obj = {
                            NMPRODUTO: produto.NMPRODUTO,
                            CDARVPROD: produto.CDARVPROD,
                            CDPRODUTO: produto.CDPRODUTO,
                            boo: ""
                        };
                        
                produtos.push(obj);
                
            }
        });
        
        sitSugAlmox = false;
        cabecalhoWidget.reload();
        
        
        
        if(args) {
            if(args.owner.getParent().name == 'cabecalho') var popup = true;
            row = args.row;
            forcaFechamento = false;
        } else{
            row = cabecalhoWidget.currentRow;
            forcaFechamento = true;
        }
        
        if(cabecalhoWidget.currentRow.CDTIPOOPER == '11'){
            templateManager.container.getWidget('entrada_semnf').reload();
            if(templateManager.container.getWidget('entrada_semnf').dataSource.data.length == 0){
                return MessageService.showMessageByCode('AUSENCIA_DE_NF_RELACIONADA');
            }
        }
        
        rowValidaProdutosEntradaEst = {
                        "CDTIPOOPER": cabecalhoWidget.currentRow.CDTIPOOPER,
                        "CDFILIAL": cabecalhoWidget.currentRow.CDFILIRECE,
                        "CDEMPRESA": cabecalhoWidget.currentRow.CDEMPRESA,
                        "Produtos": produtos
                    };
                    
        
        
        
        
        
        General.callRestEngine("df#/getParamsValidacaoProdutosEntrTipoOp","Row", rowValidaProdutosEntradaEst).then(respBack => {
            let response = respBack.dataset.validacoesProdutoEntrada[0];
            let fecharNota = true;
            
            if(response.cdtipooperValida){
                let prodErros = [];
                
                response.produtos.forEach(produto => {
                    if ((((cabecalhoWidget.currentRow.CDTIPOOPER == '01') && (response.IDBLOQPRESTO == 'S')) || ((response.IDBLOQPRESTTPOP == 'S') && (response.IDFUNCAOFILI != 'O' ))) && produto.boo) {
                        prodErros.push(produto);
                    }
                });
                
                if(prodErros.length > 0){
                    fecharNota = false;
                    MessageService.getMessageByCode("PROD_EST_NF_COMPRA")
                    .then(message => {
                        ScreenService.errorNotification(message);
                        prodErros.forEach(erro => {
                            ScreenService.errorNotification('Produto: ' + erro.CDARVPROD + " " + erro.NMPRODUTO );
                        });
                    });
                }
                
            }
            
            if(fecharNota){
                Df11000_Lancamento_Service.getStatusNota(cabecalhoWidget.currentRow).then(salvaNota => {
                    if(salvaNota) {
                        if(row.IDSTATUS === 'L'){
                            ScreenService.openPopup(templateManager.container.getWidget("confirmaDataLancto"));
                        } else {
                           ScreenService.confirmMessage('Deseja realizar o fechamento da nota fiscal?', 'question',
                                (success) =>  {
                                    Df11000_Lancamento_Service.fecharNota(cabecalhoWidget.currentRow, forcaFechamento)
                                    .then(processaFechamento)
                                    .catch((error) => erroFechamento(error, popup))
                                    .then(() => reloadWidgetCabecalho())
                                    .then(() => {
                                        if(popup && templateManager.container.getActiveWidget().name != 'errosAvisos') {
                                            ScreenService.closePopup();
                                        }
                                    });
                                }, function(error) {
                                     return ScreenService.errorNotification(error, 'ERROR');
                                }
                            );
                        }
                    }
                    else MessageService.showMessageByCode('BLOCK_NOTE');
                }, requestError);
            }
        });
    };
    
    this.setDefaultValuesConfDtLncto = function(widget){
        if(widget.getParent().currentRow.DTENTRSAID)
            widget.currentRow.DTENTRSAID = widget.getParent().currentRow.DTENTRSAID;  
    };
    
    this.fecharNotaLiberada = function(widget){
        var cabecalhoWidget = templateManager.container.getWidget('cabecalho');
        
        widget.getParent().currentRow.DTENTRSAID = widget.currentRow.DTENTRSAID;
        
        Df11000_Lancamento_Service.fecharNota(cabecalhoWidget.currentRow, false)
        .then(processaFechamento)
        .catch((error) => erroFechamento(error, true))
        .then(() => reloadWidgetCabecalho())
        .then(() => {
            if(templateManager.container.getActiveWidget().name != 'errosAvisos') {
                ScreenService.closePopup();
            }
        });
    };
     
    var reloadWidgetCabecalho = function() {
        templateManager.container.getWidget('cabecalho').reload();
    };

    const processaFechamento = (response) => {
        var dataset = response.dataset;
        var fechamento = dataset.fecharNota;
        const currentRow = getCabecalhoWidget().currentRow;
        var cabecalhoWidget = templateManager.container.getWidget('cabecalho');
        var widgetRateio = templateManager.container.getWidget('GER03600RateioPorProduto');
        var gridRateio = templateManager.container.getWidget('gridItensRateio');
        var tipoOperacao = cabecalhoWidget.currentRow.CDTIPOOPER;

        currentRow.IDSTATUS = fechamento.STATUS;
        currentRow.VRNOTAFISC = fechamento.CABECALHO.VRNOTAFISC;
        
        if(fechamento.ERROS_APROVACAO[0]) {
            ScreenService.successNotification('Nota fechada com sucesso! Porém, não foi possível efetuar a aprovação da nota fiscal.');
        }
        else {
            ScreenService.successNotification('Nota fechada com sucesso!');
        }
        
        var filter = [
            {
                operator: "=",
                name: "IDENTRSAIDOP",
                value: "E"
            },
            {
                operator: "=",
                name: "CDTIPOOPER",
                value: tipoOperacao
            }
        ];
        
        this.verificaRateio();
        General.callRestEngine('df#/crud/tipooperac_tipocusto', 'FilterData', filter).then(function(success) {
            if(success.dataset.tipooperac_tipocusto[0].IDREARATMANNF == 'S'){
                ScreenService.confirmMessage('Deseja realizar rateio para a nota fiscal?', 'question', (success) =>  {
                    var widgetItens = templateManager.container.getWidget("itens");
                    if(widgetItens.active){
                        if(widgetItens.mode == "view"){
                            ScreenService.goBack();
                        }
                    }else if(templateManager.container.getWidget("impostosItem").active){
                        ScreenService.goBack();
                    }
                    
                    widgetRateio.enabled = true;
                    widgetRateio.isVisible = true;
                    ScreenService.closePopup();
                    widgetRateio.activate();
                    cabecalhoWidget.reload();
                }, (error) => {
                    Df11000_Lancamento_Service.geraRateio();
                    widgetRateio.geraRateio = false;
                    ScreenService.closeSwipe(0);
                    cabecalhoWidget.reload();
                   
                }
            );
            }else{
                Df11000_Lancamento_Service.geraRateio();
                widgetRateio.geraRateio = false;
                ScreenService.closeSwipe(0);
                cabecalhoWidget.reload();
            }
        });
    };
    
    this.verificaRateio = function () {
        var cabecalhoWidget = templateManager.container.getWidget('cabecalho');
        var widgetRateio = templateManager.container.getWidget('GER03600RateioPorProduto');
        General.callRestEngine("df#/verificaRateio", "Row", cabecalhoWidget.currentRow).then((sucess) => {
            if(sucess.dataset.dadosRateio.length == 0){
                widgetRateio.geraRateio = true;
            }else{
                widgetRateio.geraRateio = false;
            }
        });	
    };

    const erroFechamento = (error, popup) => { 
        if(popup) ScreenService.closePopup();
        var errosAvisos = templateManager.container.getWidget('errosAvisos');
        var bloqueia   = false;
        var consiste   = false;
        var errosAf    = ["AV01", "AV11", "AV12", "AV13", "AV15", "AV16"];
        errosAvisos.dataSource.data = error.data.dataset.errosFechamento;
        error.data.dataset.errosFechamento.forEach((erro) => {
            if(erro.IDERROAVISO == 'B') bloqueia = true;
            if(errosAf.indexOf(erro.CDERROAVISO) != -1) consiste = true;
        });
        errosAvisos.isVisible = true;
        errosAvisos.getAction('confirmarFechamento').isVisible = !bloqueia;
        errosAvisos.getAction('consistir_af_nf').isVisible = consiste;
        ScreenService.openPopup(errosAvisos);
        
        ScreenService.showMessage(error.data.error);
        this.errosAvisosAtualizaItens(templateManager.container.getWidget("errosAvisos"));
        return error;
    };
    
    this.errosAvisosAtualizaItens = function (widget) {
        var errosAvisos = widget.dataSource.data;
        var widgetProdutos = widget.getParent().widgets.filter (widget => widget.name === "itens")[0];
        widgetProdutos.reload().then ( () => {
            //Verifica erros que não são gravados no campo IDERROSITEM
            let produtos = widgetProdutos.dataSource.data;
            errosAvisos.forEach (erroAviso => {
                var produto;
                if (erroAviso.NRSEQITPROD) {
                    produto = produtos.filter(produto => produto.NRSEQITPROD === erroAviso.NRSEQITPROD)[0];
                }
                else if (erroAviso.ITEMERRO) {
                    let cdItem = erroAviso.ITEMERRO.split(" - ")[0];
                    produto = produtos.filter(produto => produto.CDPRODUTO === cdItem)[0];
                }
                else {
                    return;
                }
                if (erroAviso.IDERROAVISO === "B") {
                    produto.IDERROSITEM = "1";
                }
                else if (erroAviso.IDERROAVISO === "C") {
                    produto.IDAVISOSITEM = "1";
                }
            });
        });
    };

    var controlaStatusWidgets = function(widgetPai, nomeWidgetAtual, status, ignoredWidgets) {
        var allWidgets = widgetPai.widgets;

        allWidgets.filter(widget => widget.name !== nomeWidgetAtual).forEach(widget => widget.enabled = status);

        if (widgetPai.name !== nomeWidgetAtual)
            widgetPai.enabled = status;

        if (Array.isArray(ignoredWidgets))
            allWidgets.filter(widget => ignoredWidgets.indexOf(widget.name) !== -1).forEach(widget => widget.enabled = !status);
    };

    var removeEdicaoLinhasWidget = function(registrosAlterados) {
        registrosAlterados.forEach(registro => {
            registro.__is_new = false;
            Object.keys(registro).filter(key => !key.indexOf('changed') ? delete registro[key] : !key.indexOf('changed'));
        });
    };
    
    this.validacoesWidgetOnEnterOnce = function(consultaLancamentoArgs) {
        var cabecalhoWidget = consultaLancamentoArgs.owner;
        if(sessionStorage.getItem('TABLE_NAME') == 'rastreioContabil'){
                var filter = [
                        {
                            "name": "CDEMPRESA",
                            "operator": "=",
                            "value": sessionStorage.getItem('CDEMPRESA')
                        },
                        {
                            "name": "CDFILIRECE",
                            "operator": "=",
                            "value": sessionStorage.getItem('CDFILIRECE')
                        },
                        {
                            "name": "NRNOTAFISC",
                            "operator": "=",
                            "value": sessionStorage.getItem('NRNOTAFISC')
                        },
                        {
                            "name": "DTENTRSAID",
                            "operator": "BETWEEN",
                            "value": [sessionStorage.getItem('DTENTRSAID'), sessionStorage.getItem('DTENTRSAID')]
                        }
                ];
                cabecalhoWidget.dataSourceFilter = filter;
                cabecalhoWidget.reload().then ( () => {
                    cabecalhoWidget.moveToFirst();
                });
                sessionStorage.removeItem('TABLE_NAME');
                sessionStorage.removeItem('CDEMPRESA');
                sessionStorage.removeItem('CDFILIRECE');
                sessionStorage.removeItem('NRNOTAFISC');
                sessionStorage.removeItem('DTENTRSAID');
                return;
        }
        setDefaultFilialFilter(cabecalhoWidget).then(defaultFilter => {
            ZhFilterPreferences.setOriginalFilter(cabecalhoWidget.id, defaultFilter);
            ZhFilterPreferences.openFilterWidget(cabecalhoWidget, defaultFilter).then( () =>
                {
                    var filterWidget = templateManager.container.getActiveWidget();
                    filterWidget.getField('NMFILIAL').reload();
                    filterWidget.getField("IDSTATUS").setValue("");
                    filterWidget.getField("IDORIGDESTNF").setValue("");
                    filterWidget.actions.filter(action => action.name === "clear")[0].shortcutKey = "ctrl+backspace";
                });
            removeDataSourcesConsultaLancEntradaActionEvent();
            
            
        });
    
     
    };
    this.validaEntrada = function(consultaLancamentoArgs) {
    var cabecalhoWidget = consultaLancamentoArgs.owner;
    console.log(sessionStorage.getItem('NRACESSONFE'));
    if(sessionStorage.getItem('NRACESSONFE')){
        sessionStorage.setItem('fromLancamento','true');
        var filterWidget = templateManager.container.getActiveWidget();
        filterWidget.reload().then(() => {
            setTimeout(() => {
                filterWidget = templateManager.container.getActiveWidget();
                if(filterWidget.getAction('never')){             
                    filterWidget.getAction('never').element.click();
                }
		    	setTimeout(() => {this.notaAction(cabecalhoWidget);}, 1200);
		    	}, 2500);
            });
        }
    };

    
    var removeDataSourcesConsultaLancEntradaActionEvent = function() {
        Df11000_Lancamento_Service.removeDataSourceLancamentoNota();
    };
    
    
    const setDefaultFilialFilter = (widget, index) => {
                var promise = ZHPromise.defer();
        let defaultFilter = Util.clone(widget.currentRow);
        defaultFilter.DTENTRSAID = undefined;

        General.callRestEngine('df#/filioper_lancamento_notafiscal', 'FilterData', 
                                [{"name": "CDOPERADOR", "operator": "=", "value": "OPERADOR_LOGADO"},
                                {"name": "CDFILIAL"  , "operator": "=", "value": "FILIAL_LOGADA"}]
            ).then(function(filialLogada) {
                let filialDefaultValue, cdFilialOut = null;
                let filialFieldOutData = widget.getField('NMFILIAL').outData;
                
                //Utiliza o primeiro dataset retornado. Necessário pois o dataset pode ser filioper_lancamento_notafiscal ou perfacessfili_lancamento_notafiscal
                for (let datasetName in filialLogada.dataset) {
                    if (filialLogada.dataset.hasOwnProperty(datasetName)) {
                        filialDefaultValue = filialLogada.dataset[datasetName][0];
                	    break;
                    }
                }
                if(filialDefaultValue) cdFilialOut = filialDefaultValue.CDFILIAL;
                
                Df11000_Lancamento_Service.buscaDataProcessamento(cdFilialOut).then(([processamento]) => {
                    if(processamento) {
                        const dtProcessFormat = moment(processamento.DTPROCESSA, 'DD/MM/YYYY').format('DD/MM/YYYY');
                        defaultFilter.DTENTRSAID = {start: dtProcessFormat, period: undefined, end: dtProcessFormat};
                    }
                    promise.resolve(defaultFilter);
                });
                setCurrentRowWithOutData(defaultFilter, filialDefaultValue, filialFieldOutData);
        });
        return promise;
        
    };
    
    const setCurrentRowWithOutDataFilial = (CDFILIAL, {dataSourceFilter, dataSource: {name: route}, outData}, currentRow, entryDateField = false) => {
        const DEFAULT_FILTER = {name: 'CDFILIAL', operator: '=', value: CDFILIAL},
            DATASOURCE_NAME_REGEXP = /(?:[A-z_]+#)?\/?(?:crud\/)?(.*)/; //matches the last part of the route, ignoring '/', 'serviceUrl#' and 'crud/'

        const filial = filter => filter.name == 'CDFILIAL',
            remove = fn => obj => !fn(obj),
            getDataSource = RegExp.prototype.exec.bind(DATASOURCE_NAME_REGEXP);

        const [, dataSourceName] = getDataSource(route), //[, var] to skip the match and get the capture group
            filter = [
                DEFAULT_FILTER,
                ...(dataSourceFilter && dataSourceFilter.length?
                    dataSourceFilter.some(filial)?
                        dataSourceFilter.filter(remove(filial))
                        : dataSourceFilter
                    : [])
            ];

        if (entryDateField)
                return Df11000_Lancamento_Service.buscaDataProcessamento(CDFILIAL)
                .then(([processing]) => {
                    const DTPROCESSA = moment(processing.DTPROCESSA, 'DD/MM/YYYY').format('DD/MM/YYYY');
                    currentRow.DTENTRSAID = {start: DTPROCESSA, period: undefined, end: DTPROCESSA};
                    return General.callRestEngine(route, 'FilterData', filter)
                        .then(response =>response.dataset[dataSourceName])
                        .then(([filialRow]) => setCurrentRowWithOutData(currentRow, filialRow, outData) || filialRow);
                });
        else {
            return General.callRestEngine(route, 'FilterData', filter)
            .then(response =>response.dataset[dataSourceName])
            .then(([filialRow]) => setCurrentRowWithOutData(currentRow, filialRow, outData) || filialRow);
        }
        
    };
    
    this.getDataProcessamento = function(filialSelecionada){
        var promise = ZHPromise.defer();
        Df11000_Lancamento_Service.buscaDataProcessamento(filialSelecionada).then(function(processamento){
            var dtProcessFormat = moment(processamento[0].DTPROCESSA, 'DD/MM/YYYY').format('DD/MM/YYYY');
            promise.resolve(dtProcessFormat);
        });
        return promise;
    };
    
    var setCurrentRowWithOutData = function(currentRow, valuesToSetOnCurrentRow, outDataValue) {
        for (var key in outDataValue) {
            currentRow[outDataValue[key]] = valuesToSetOnCurrentRow[key];
        }
    };

    var limpaWidgetAutoForne = function(autoForneWidget, cabecalhoWidget) {
        autoForneWidget.unSelectAll();
        delete cabecalhoWidget.currentRow.AF;
        cabecalhoWidget.currentRow.CBUTILIZAAF = null;
    };

    var getCabecalhoWidget = function() {
        return templateManager.container.getWidget('cabecalho');
    };

    var removeOutDataAndRequired = function(currentRow) {
        for (var i = 1; i < arguments.length; i++) {
            var field = arguments[i];
            setCampoNaoObrigatorio(field);
            limpaCamposOutData(field, currentRow);
        }
    };

    var setCampoObrigatorio = function(field, readOnly) {
        field.validations = {required: true};
        field.readOnly = !!readOnly;
    };

    var setCampoNaoObrigatorio = function(field) {
        delete field.validations;
        field.readOnly = true;
    };

    var limpaCamposOutData = function(field, currentRow) {
        var outData = field.outData;
        for (var value in outData) {
            delete currentRow[outData[value]];
        }
    };

    var buscaOperadorLogado = function() {
        return Df11000_Lancamento_Service.buscaOperadorLogado();
    };


    var clearRowWithOutData = function(currentRow, outDataValue) {
        for (var key in outDataValue) {
            currentRow[outDataValue[key]] = null;
        }
    };

    /* ************************* Lancamento Entrada - Filtro  *********************************** */
    this.getFieldValueFilter = function(filedName, widgetName) {
        var container =  templateManager.container;
        if(container) {
            var filterWidget;
            var filterBforeApply = templateManager.container.getActiveWidget();
            if(filterBforeApply.name == 'zhFilterPreferencesSelectConditions')
              filterWidget = filterBforeApply;
            else {
                var f = container.getWidget(widgetName);
                if(f) {
                     filterWidget = container.getWidget(widgetName).appliedFilter;
                }
               
            }
            
            if(filterWidget) {
                var valueField;
                if(filterBforeApply.name == 'zhFilterPreferencesSelectConditions')
                    valueField = filterWidget.currentRow[filedName];
                else
                    valueField = filterWidget.FILTER_ROW[filedName];
                    
                return valueField || null;
            }
            else return null;
        }
        else return null;
    };

    var validacaoCamposOutTpOperacFilter = function(principalField) {
        principalField.showOnView = true;
        principalField.showOnForm = true;
        principalField.isVisible = true;
        principalField.readOnly = false;
        principalField.reload();

        for (var i = 1; i < arguments.length; i++) {
            arguments[i].showOnView = false;
            arguments[i].showOnForm = false;
            arguments[i].isVisible = false;
            arguments[i].readOnly = true;
        }
    };

    var alteraVisibilidadeCampoInscricaoFiltro = function(filterArgs) {
        var filtroWidget = filterArgs.owner.field.widget;
        var currentRow = filtroWidget.currentRow;
        var cliente = filtroWidget.getField('NMRAZSOCCLIE');
        var fornecedor = filtroWidget.getField('NMRAZSOCFORN');
        var filial = filtroWidget.getField('DSFILIEMIT');
        var tipoDestino = filterArgs.row.IDORIGDESTNF;

        removeOutDataAndRequired(currentRow, cliente, fornecedor, filial);

        switch (tipoDestino) {
            case 'C':
                validacaoCamposOutTpOperacFilter(cliente, fornecedor, filial);
                break;
            case 'F':
                validacaoCamposOutTpOperacFilter(fornecedor, cliente, filial);
                break;
            case 'L':
                validacaoCamposOutTpOperacFilter(filial, fornecedor, cliente);
                break;
            default:
                cliente.readOnly = true;
                cliente.reload();
                fornecedor.readOnly = true;
                fornecedor.reload();
                filial.readOnly = true;
                filial.reload();
                break;
        }
    };

    /**
         * @desc - Altera o campo de remetente dependendo do valor que usuário escolher
        * @emit - No evento OnChange do campo IDORIGDESTNF do filtro
        * @param {[object]} filterArgs
    */
    this.idorigdestnfOnChangeFiltro = function (filterArgs) {
        alteraVisibilidadeCampoInscricaoFiltro(filterArgs);
    };

    /**
         * @desc - Limpa o "dataSourceFilter", pois o framework está concatenando a row do filter com o dataSourceFilter,
        *         o que gerava objetos repetidos.
        * @emit - No evento FilterBeforeApply
        * @param object filterArgs
    */
    this.criaDataSourceFilterBeforeApply = function(filterArgs) {
        var widgetPrincipal = filterArgs.owner;
        widgetPrincipal.dataSourceFilter = [];
    };

    /**
         * @desc - Adicionar os paremetros seguindo os "parameters bag" da query.
        * @emit - No evento FilterAfterApply
        * @param Object filterArgs
    */


    /* ************************* Lancamento Entrada - Cabeçalho ********************************* */

    const setCamposDefaultValueCabecalho = cabecalhoWidget => {
        var deferred = ZHPromise.defer();
        var {currentRow} = cabecalhoWidget;

        Df11000_Lancamento_Service.getDefaultNovaNota().then((defaultNota) => {
            currentRow = Object.assign(currentRow, defaultNota[0]);
            currentRow.__is_new = true;
            this.defaultValueDestinatario();
            unidadeOnChangeNovaNota(cabecalhoWidget).then(() => {
                cabecalhoWidget.activate();
                deferred.resolve();
                
            });
        });

        return deferred;
    };
    
    this.defaultValueDestinatario = function() {
        var data,
            dataSource,
            currentRow  =  getCabecalhoWidget().currentRow,
            filterRow = getCabecalhoWidget().appliedFilter.FILTER_ROW,
            dataSourceFilter =  [{ "name": "CDOPERADOR", "operator": "=", "value": "OPERADOR_LOGADO"}];
        
        General.callRestEngine("df#/filioper_lancamento_notafiscal", "FilterData", dataSourceFilter).then((filialLogada) => {
            
            for (let datasetName in filialLogada.dataset) {
                if (filialLogada.dataset.hasOwnProperty(datasetName)) {
                    dataSource = filialLogada.dataset[datasetName];
            	    break;
                }
            }
            
            if (dataSource) {
                data = dataSource.filter(data => data.CDFILIAL == filterRow.CDFILIRECE)[0];

                currentRow.DSENDEDEST       = data.DSENDEFILI;
                currentRow.NMBAIRDEST       = data.NMBAIRFILI;
                currentRow.NRCEPDEST        = data.NRCEPFILI;
                currentRow.NRTELEDEST       = data.NRTELEFILI;
                currentRow.IEDEST           = data.IEDEST;
                currentRow.SGESTADODEST     = data.SGESTADO ;
                currentRow.NMMUNICIPIODEST  = data.NMMUNICIPIO;
            }

        });
    };
    
    
 this.notaAction=function(widget){
     Df11000_Lancamento_Service.removeDataSourceLancamentoNota()
            .then(() => {
               
                ScreenService.showLoader();
                Df11000_Lancamento_Service.inicializaLancamento();
                return Df11000_Lancamento_Service.setDataSourceLancamentoNota();
            }).then(() => {
                widget.newRow();
                widget.getField('DSLINKANEXO').isVisible = true;
                this.modeloDeDocumentoOnChange('', widget);
                widget.getField('CBUTILIZAAF').validations = {};
                widget.getField("CDSERIEENTR").reload();
                this.requireCTE(widget);
                controlaStatusWidgets(widget, widget.name, false, ['relacionamentoItens']);
                widget.container.getWidget('relacionamentoItens').isVisible = false;
                setCamposDefaultValueCabecalho(widget)
                .then(() => {
                    this.modeloDeDocumentoOnChange('', widget);
                    var widgetCabecalho = templateManager.container.getWidget('cabecalho');
                    widgetCabecalho.redraw();
                });
                applyAccessKeyAccessibilityRules(widget, false);
                ScreenService.hideLoader();
                
            }).then(() => { var widgetCabecalho = templateManager.container.getWidget('cabecalho');
            setTimeout(() => {widgetCabecalho.getField('NRACESSONFE').setValue(sessionStorage.getItem('NRACESSONFE')); widgetCabecalho.getField('NRACESSONFE').blur();sessionStorage.removeItem('NRACESSONFE');} , 2200); });
            
    };
    
    this.notaActionEvent = ({owner: {widget}}) =>
        Df11000_Lancamento_Service.removeDataSourceLancamentoNota()
            .then(() => {
                console.log(widget);
                ScreenService.showLoader();
                Df11000_Lancamento_Service.inicializaLancamento();
                return Df11000_Lancamento_Service.setDataSourceLancamentoNota();
            }).then(() => {
                widget.newRow();
                widget.getField('DSLINKANEXO').isVisible = true;
                this.modeloDeDocumentoOnChange('', widget);
                widget.getField('CBUTILIZAAF').validations = {};
                widget.getField("CDSERIEENTR").reload();
                this.requireCTE(widget);
                controlaStatusWidgets(widget, widget.name, false, ['relacionamentoItens']);
                widget.container.getWidget('relacionamentoItens').isVisible = false;
                setCamposDefaultValueCabecalho(widget)
                
                .then(() => {
                    this.modeloDeDocumentoOnChange('', widget);
                    var widgetCabecalho = templateManager.container.getWidget('cabecalho');
                    widgetCabecalho.redraw();
                    this.adicionaValores();
                    this.alteraEmpresa();
                });
                applyAccessKeyAccessibilityRules(widget, false);
                ScreenService.hideLoader();
            });

    this.excluirNotaEntradaActionEvent = cabecalhoArgs => {
        ScreenService.confirmMessage(
            ScreenService.i18n('Excluir Registro?'),
            'question', () => Df11000_Lancamento_Service.getStatusNota(cabecalhoArgs.row).then(salvaNota => {
                if(salvaNota) {
                    Dfe11000_LancamentoEntrada_Service.excluirNotaEntrada(cabecalhoArgs.row).then(() => {
                        General.backOrCancel(cabecalhoArgs);
                        const {data} = cabecalhoArgs.owner.widget.dataSource;
                        const index = data.findIndex(notafiscal => cabecalhoArgs.row.NRLANCTONF === notafiscal.NRLANCTONF);
    
                        if (index > 0) data.splice(index, 1);
    
                        cabecalhoArgs.owner.widget.reload();
                        ScreenService.successNotification('Nota Fiscal excluída com sucesso');
                    }).catch(requestError);
                }
                else MessageService.showMessageByCode('BLOCK_NOTE');
            }).catch(requestError)
        );
    };
    
    this.carregaEmpresa = function(args, isFilter){
        var widget = templateManager.container.getWidget('cabecalho');
        var fieldUnid = args.owner.owner.widget.getField('NMFILIAL');
        var field = args.owner.owner.widget.getField('NMEMPRESA');
        
        if(!utilizaControladoria){
            if(isFilter){
                if(fieldUnid.value() != ''){
                    field.readOnly = false;
                    field.readOnlyOnEdit = false;
                    templateManager.container.getWidget('cabecalho').getField('NMEMPRESA').readOnly = false;
                }else{
                   field.readOnly = true; 
                   widget.currentRow.CDEMPRESA = '';
                   widget.currentRow.NMEMPRESA = '';
                   widget.currentRow.CDINSCESTA = '';
                   widget.currentRow.IEDEST = '';
                }  
            }else{
                if(fieldUnid.value() != ''){
                    templateManager.container.getWidget('cabecalho').getField('NMEMPRESA').readOnly = false;
                    var filter = [
                       {
                            "name": "P_CDFILIAL",
                            "operator": "=",
                            "value": widget.currentRow.CDFILIRECE
                        }
                    ];
                    widget.getField('NMEMPRESA').dataSourceFilter = filter;
                    widget.currentRow.IEDEST = widget.currentRow.CDINSCESTA;
                }else{
                   field.readOnly = true; 
                   widget.currentRow.CDEMPRESA = '';
                   widget.currentRow.NMEMPRESA = '';
                   widget.currentRow.CDINSCESTA = '';
                   widget.currentRow.IEDEST = '';
                }
                templateManager.container.getWidget('cabecalho').getField('NMEMPRESA').reload();
            }
            field.reload(); 
        }
    };
    
    this.adicionaValores = function(){
        var cdEmpresa = this.getFieldValueFilter('CDEMPRESA', 'cabecalho');
        var nmEmpresa = this.getFieldValueFilter('NMEMPRESA', 'cabecalho');
        var inscricao = this.getFieldValueFilter('IEDEST', 'cabecalho');
        var widgetCabecalho = templateManager.container.getWidget('cabecalho');
        
        widgetCabecalho.currentRow.CDEMPRESA = cdEmpresa;
        widgetCabecalho.currentRow.NMEMPRESA = nmEmpresa;
        widgetCabecalho.currentRow.IEDEST =inscricao;
        this.endIsnceEstadual(inscricao, cdEmpresa, widgetCabecalho);
    };
    
    this.verificaControladoria = function(args){
        var row = templateManager.container.getWidget('cabecalho').currentRow;
        General.callRestEngine("df_entrada#/verificaControladoria", "Row", row).then((sucess) => {
            if(sucess.dataset.utilizaControladoria.length > 0){
                utilizaControladoria = sucess.dataset.utilizaControladoria[0];
                if(!utilizaControladoria){
                    var field = templateManager.container.getActiveWidget().getField('NMEMPRESA');
                    field.readOnly = false;
                    field.readOnlyOnEdit = false;
                    templateManager.container.getWidget('cabecalho').getField('NMEMPRESA').readOnly = false;
                    field.reload();
                }
            }
        });
    };
    
    this.alteraEmpresa = function(){
        if(!utilizaControladoria){
            templateManager.container.getWidget('cabecalho').getField('NMEMPRESA').readOnly = false;
        }
    };
    
    this.endIsnceEstadual = function(inscEst,cdEmpresa, widget){
        var filter =  [
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": cdEmpresa
                },
                {
                    "name": "CDINSESTA",
                    "operator": "=",
                    "value": inscEst
                },
            ];
         General.callRestEngine('df#/crud/endereco_insc_estadual', 'FilterData', filter).then(function(success) {
            if(success.dataset.endereco_insc_estadual[0]){
                var data = success.dataset.endereco_insc_estadual[0];
                widget.currentRow.DSENDEDEST = data.DSENDEIEST;
                widget.currentRow.NMBAIRDEST = data.NMBAIRIEST;
                widget.currentRow.NRCEPDEST = data.NRCEPIEST;
                widget.currentRow.NMMUNICIPIODEST = data.NMMUNICIPIO;
                widget.currentRow.NRTELEDEST = data.NRTELEIEST;
                widget.currentRow.SGESTADODEST = data.SGESTADO;
            }
        });
    };
    
    this.editarNotaEntrada = function(args){
        let widget = args.owner.widget,
        currentRow = Util.clone(widget.currentRow);
        
        controlaStatusWidgets(widget, widget.name, false);
        applyZeroFillNumeroNota(widget);
        
        widget.getField('DSLINKANEXO').isVisible = false;
        
        this.getDataProcessamento(currentRow.CDFILIAL).then( dtProcessamento => {
            currentRow.DTPROCESSA = moment(dtProcessamento, 'DD/MM/YYYY');
            currentRow.DTENTRSAID = moment(currentRow.DTENTRSAID, "DD/MM/YYYY hh:mm:ss");
            if(currentRow.DTPROCESSA.valueOf() > currentRow.DTENTRSAID.valueOf()){
                Dfe11000_LancamentoEntrada_Service.tipoEdicao(currentRow, dtProcessamento).then( response => {
                    if(response == 'N'){
                        this.habilitaEdicaoNotaEntrada(widget);
                        this.validaEdicaoCabecalho(null, widget);
                        this.controlVisibilityLocalPrestServ(widget);
                    } else if(response == 'S'){
                        this.openLancRetro(args);
                    } else if(response == 'B'){
                        ScreenService.showMessage("Edição bloqueada");
                    }
                });  
            } else{
                this.habilitaEdicaoNotaEntrada(widget);
                this.validaEdicaoCabecalho(null, widget);
                this.controlVisibilityLocalPrestServ(widget);
            }
              
        });
        
         
    };
    
    this.validaEdicaoCabecalho = function(widget){
        this.modeloDeDocumentoOnChange(null, widget);
    };
    
    this.habilitaEdicaoNotaEntrada = function(widget){
        General.edit(widget);
        widget.getField('CBUTILIZAAF').validations = {};
    };

    var validaCampoModDocFiscal = function(lancamentoCabecalhoWidget, lancamentoCabecalhoRow) {
        var descModFisc = lancamentoCabecalhoWidget.getField('DSMODDOCFISC');
        descModFisc.readOnly = !lancamentoCabecalhoRow.CDTIPOOPER;
        descModFisc.reload();

        var tipoOperac = lancamentoCabecalhoRow.CDTIPOOPER;
        if (tipoOperac === '09' || tipoOperac === '10')
            delete descModFisc.validations;
        else
            descModFisc.validations = {required: true};
    };

    var validaCampoEmpresa = function(lancamentoCabecalhoArgs) {
        var empresa = getCabecalhoWidget().getField('NMEMPRESA');
        empresa.readOnly = !lancamentoCabecalhoArgs.row.CDFILIEMIT;
    };

    var validaCampoSerie = function(lancamentoCabecalhoRow, limpaCampo = false) {
        var serie = getCabecalhoWidget().getField('CDSERIEENTR');
        serie.readOnly = !lancamentoCabecalhoRow.NMEMPRESA;

        if (limpaCampo)
            serie.value(null);

        var tipoOperac = lancamentoCabecalhoRow.CDTIPOOPER;
        var operacoesSerieNaoObrig = ['09', '10', '12', '13'];
        var tipoOperacObrigaSerie = operacoesSerieNaoObrig.indexOf(tipoOperac) !== -1;

        if (tipoOperacObrigaSerie) {
            delete serie.validations;
        } else {
            serie.validations = {required: true};
        }
    };

    
    this.dateOnChange = function(dateField){
        var dataAtual =  dateField.value();
        var widget = dateField.widget;
        var status = dateField.widget.getField('IDSTATUS');
        
        var today = moment().format('DD/MM/YYYY');
        var nowFullTime = moment().format('DD/MM/YYYY');
        if(moment(dateField.value(), 'DD/MM/YYYY').format('DD/MM/YYYY') === today)
            dateField.value(nowFullTime);

    };


    var validaCampoNumero = function(lancamentoCabecalhoRow) {
        var numero = getCabecalhoWidget().getField('NRNOTAFISC');

        var tipoOperac = lancamentoCabecalhoRow.CDTIPOOPER;
        var operacoesNumeroNaoObrig = ['08', '09', '10', '12', '13'];

        var tipoOperacObrigaNumero = operacoesNumeroNaoObrig.indexOf(tipoOperac) !== -1;

        if (tipoOperacObrigaNumero || lancamentoCabecalhoRow.IDUTILEMISNF === 'S')
            delete numero.validations.required;
        else {
            if(!numero.validations.required) {
                numero.validations =  { "required": {"message": "Obrigatório"},
                                        "maxLength": { "length": 20}};
            }
        }
    };

    var limpaCamposOutDataSelectsTpOperac = function() {
        var cabecalhoWidget = getCabecalhoWidget();
        var cabecalhoRow = cabecalhoWidget.currentRow;
        var cliente = cabecalhoWidget.getField('NMRAZSOCCLIE');
        var fornecedor = cabecalhoWidget.getField('NMRAZSOCFORN');
        var filial = cabecalhoWidget.getField('DSFILIEMIT');

        filial.value(null);

        cliente.value(null);
        cabecalhoRow.CDCLIENTE = null;

        fornecedor.value(null);
        cabecalhoRow.CDFORNECED = null;
        cabecalhoRow.IDSITUCADA = null;
        cabecalhoRow.IDBLQNFRELAFOAF = null;

        cabecalhoRow.NRINSJURNF = null;
        cabecalhoRow.NMRAZSOCFORN = null;
        cabecalhoRow.IDTPIJURNF = null;
    };

    var validacaoCamposOutTpOperac = function(princialField) {
        setCampoObrigatorio(princialField);
        princialField.showOnView = true;
        princialField.showOnForm = true;
        princialField.isVisible = true;
        princialField.reload();

        for (var i = 1; i < arguments.length; i++) {
            setCampoNaoObrigatorio(arguments[i]);
            arguments[i].showOnView = false;
            arguments[i].showOnForm = false;
            arguments[i].isVisible = false;
        }
    };

    const reloadCampoTipoOperacao = widget => {
        var deferred = ZHPromise.defer();
        const field = widget.getField('NMTIPOOPER');
        field.reload().then(() => {
                var data = field.dataSource.data;
                if (!data || !data.length)
                    return false;

                const {currentRow} = field.widget;
                const defaultRow = data.find(operacao => operacao.CDTIPOOPER === '01');
                if(defaultRow)
                    setCurrentRowWithOutData(currentRow, defaultRow, field.outData);
                else
                    field.value(null);
                field.change();
                deferred.resolve();
            });
        return deferred;
    };
    
    const unidadeOnChangeNovaNota = cabecalhoWidget => {
        var deferred = ZHPromise.defer();
        var autoForneWidget = cabecalhoWidget.container.getWidget('autorizacaoFornecimento');
        limpaWidgetAutoForne(autoForneWidget, cabecalhoWidget);
        applyZeroFillNumeroNota(cabecalhoWidget);
        reloadCampoTipoOperacao(cabecalhoWidget).then(() => {
            deferred.resolve();
        });
        return deferred;
    };

    const validaFornecedorBloqTpOperac = widget => {
        var row = widget.currentRow;
        if(row.IDUTBLOQOPAF === 'S')
            Dfe11000_LancamentoEntrada_Service.validaFornecedorBloqTpOperac(row.CDTIPOOPER, row.NRINSJURNF)
                .then(({dataset: {parambloqnfafor_fornecedorparamsbloq: data}}) => {
                    const BLOCK = (data.length === 1);
                    row.ERROS_LANCAMENTO = {
                        fornecedorBloqTipoOperac: BLOCK
                    };

                    if (BLOCK){
                        showMessageDfe('TIPO_OPERACAO_BLOQ_FORNECEDOR');
                        row.CDTIPOOPER = null;
                        row.NMTIPOOPER = null;
                        widget.getField('NMTIPOOPER').change();
                    }
                });
        else
            return false;
    };

    var limpaCampoChaveAcessoPeloTipoOperac = function(cabecalhoWidget) {
        var currentRowCabecalho = cabecalhoWidget.currentRow;
        var fieldChaveAcesso = cabecalhoWidget.getField('NRACESSONFE');
        var chaveAcessoValue = fieldChaveAcesso.value();
        var tipoOpeacaoValue = currentRowCabecalho.CDTIPOOPER;

        fieldChaveAcesso.readOnly = !tipoOpeacaoValue;

        if (chaveAcessoValue) {
            limpaOutDataChaveAcess(currentRowCabecalho);
            applyAccessKeyAccessibilityRules(cabecalhoWidget, false);
        }
    };

    /**
         * @desc - Chama as validações responsáveis por alterar a visibilidade dos
        *         campos de "remetente" verificando se é "Cliente", "Fornecedor" ou "Filial"
        *       - Validar se a "chave de acesso" e "af" é obrigatório
        *       - Validar se o número da nota "NRNOTAFISC" é obrigatório
        *       - Validar se o "modelo de documento" é obrigatório
        *       - Validar se a "série" é obrigatória
        * @emit - No evento de onChange do campo "Operação" - "NMTIPOOPER"
        * @param object cabecalhoArgs
    */
    this.tipoOperacaoOnChange = function(cabecalhoArgs) {
        var cabecalhoCurrentRow = cabecalhoArgs.row;
        var cabecalhoWidget = cabecalhoArgs.owner.field.widget;

        cabecalhoCurrentRow.IDORIGDESTNF = cabecalhoCurrentRow.IDORIGDESTOP;

        limpaCampoChaveAcessoPeloTipoOperac(cabecalhoWidget);
        alteraVisibilidadeCampoInscricao();
        validaCampoModDocFiscal(cabecalhoWidget, cabecalhoCurrentRow);
        validaCampoSerie(cabecalhoCurrentRow);
        validaCampoNumero(cabecalhoCurrentRow);
        limpaCamposOutDataSelectsTpOperac(cabecalhoWidget);
        validaCampoAF(cabecalhoWidget);
        validaChaveAcessoObrigatoria(cabecalhoWidget);
        validaCampoNotaOrigem(cabecalhoWidget, cabecalhoCurrentRow);
        this.controlVisibilityLocalPrestServ(cabecalhoWidget);
    };

    /**
        * @desc - Chama a validação da chave de acesso obrigatória
        * @emit - No evento de onChange do campo "Modelo de Documentos" - "DSMODDOCFISC"
        * @param object cabecalhoArgs
    */
    this.modeloDeDocumentoOnChange = function(cabecalhoArgs, cabecalhoWidget = '') {
        cabecalhoWidget = (cabecalhoWidget) ? cabecalhoWidget : templateManager.container.getWidget('cabecalho');
        
        // filtro passado para a busca de modelo de documento.
         var dataSourceFilter =  [
            {
                "name": "IDENTRSAIDOP",
                "operator": "=",
                "value": "E"
            },
            {
                "name": "CDTIPOOPER",
                "operator": "=",
                "value": cabecalhoWidget.currentRow.CDTIPOOPER
            }
        ];
        
        // Busca os dados de modelo de documento conforme filtro, itera sobre eles, e compara com os valores que estão setado nos campos.
        // Se os indice bater com o valor setado no campo de (CDTIPOOPER , CDMODDOCFISC), ele pega o valor de IDOBRIGANEXO e substitui o mesmo no datasource que atualmente se passa vazio.
        General.callRestEngine("df#/moddocfisc_moddocfisctpop", "FilterData", dataSourceFilter).then((response) => {
            var dados = response.dataset.moddocfisc_moddocfisctpop;
            for (let key in dados) {
              if (cabecalhoWidget.currentRow.CDTIPOOPER === dados[key].CDTIPOOPER) {
                if (cabecalhoWidget.currentRow.CDMODDOCFISC === dados[key].CDMODDOCFISC) {
                    cabecalhoWidget.currentRow.IDOBRIGANEXO = dados[key].IDOBRIGANEXO;
                    if(cabecalhoWidget.currentRow.IDOBRIGANEXO == 'S'){
                        cabecalhoWidget.getField('DSLINKANEXO').validations.required = true;
                    } else
                        cabecalhoWidget.getField('DSLINKANEXO').validations = {};
                    }
                }
            }
        });
        
        if(cabecalhoWidget.currentRow.IDOBRIGANEXO == 'S')
            cabecalhoWidget.getField('DSLINKANEXO').validations.required = true;
        else
            cabecalhoWidget.getField('DSLINKANEXO').validations = {};
            
        validaChaveAcessoObrigatoria(cabecalhoWidget);
        this.requireCTE(cabecalhoWidget);
    };

    this.requireCTE = function(widget){
        //Verifica se é necessário os campos de CTE
        let requireCTE =  ["57", "63", "67"].includes(widget.currentRow.CDMODDOCFISC);
        
        if(requireCTE){
            widget.getField("CDIBGEORIG").validations.required = true;
            widget.getField("CDIBGEDEST").validations.required = true;
            widget.getField("CDTIPOCTE").validations.required  = true;
        } else{
            widget.getField("CDIBGEORIG").validations = {};
            widget.getField("CDIBGEDEST").validations = {};
            widget.getField("CDTIPOCTE").validations  = {};
        }
    };

    this.unidadeFieldOnChange = function(cabecalhoWidget) {
        var autoForneWidget = cabecalhoWidget.container.getWidget('autorizacaoFornecimento');
        limpaWidgetAutoForne(autoForneWidget, cabecalhoWidget);
        applyZeroFillNumeroNota(cabecalhoWidget);
        reloadCampoTipoOperacao(cabecalhoWidget);
    };
    
    this.empresaFieldOnChange = function(field) {
        /*var widget = field.widget;
        var fieldFilial =  widget.getField('NMFILIAL');
        widget.currentRow.CDFILIAL = '';
        widget.currentRow.NMFILIAL = '';
        if (field.value()) {
           fieldFilial.readOnly = false;
        }
        else {
            fieldFilial.readOnly = true;
        }
        fieldFilial.setValue("");
        widget.getField('NMFILIAL').reload();*/
        var widget = field.widget;
        var fieldInscEst = widget.getField('IEDEST');
        if(widget.currentRow.CDEMPRESA != ''){
            widget.currentRow.IEDEST = widget.currentRow.CDINSCESTA;
            widget.currentRow.SGESTADODEST = widget.currentRow.SGESTADODEST;
            this.endIsnceEstadual(widget.currentRow.IEDEST, widget.currentRow.CDEMPRESA, widget);
        }else{
            widget.currentRow.IEDEST = '';
            widget.currentRow.DSENDEDEST = '';
            widget.currentRow.NMBAIRDEST = '';
            widget.currentRow.NRCEPDEST = '';
            widget.currentRow.NMMUNICIPIODEST = '';
            widget.currentRow.NRTELEDEST = '';
            widget.currentRow.SGESTADODEST = '';
        }
        
        fieldInscEst.reload();
    };

    this.cdfiliemitOnChange = function(lancamentoCabecalhoArgs) {
        validaCampoEmpresa(lancamentoCabecalhoArgs);
        validaCampoSerie(lancamentoCabecalhoArgs.row);
    };

    this.cancelaEdicaoCabecalho = function(cabecalhoArgs) {
        var cabecalhoWidget = cabecalhoArgs.owner.widget;
        General.backOrCancel(cabecalhoArgs).then(() => {
            controlaStatusWidgets(cabecalhoWidget, cabecalhoWidget.name, true);
            alteraVisibilidadeCampoInscricao();
            
            cabecalhoWidget.getField('DSLINKANEXO').isVisible = false;
            
            cabecalhoWidget.reload();
        });
    };

    this.remetenteFieldOnChange = function(cabecalhoArgs) {
        var remetenteField = cabecalhoArgs.owner.field;
        var cabecalhoWidget = remetenteField.widget;

        if (remetenteField.name == 'NMRAZSOCFORN')
            this.validaFornecedorOnChange(cabecalhoArgs);
        
        var dsinsjurnf;
        switch (remetenteField.name) {
            case "NMRAZSOCCLIE": dsinsjurnf = cabecalhoWidget.currentRow.NMRAZSOCCLIE; break;
            case "NMRAZSOCFORN" : dsinsjurnf = cabecalhoWidget.currentRow.NMRAZSOCFORN; break;
            case "DSFILIEMIT": dsinsjurnf = cabecalhoWidget.currentRow.DSFILIEMIT; break;
        }
        
        cabecalhoWidget.currentRow.DSINSJURNF = dsinsjurnf;

        validaCampoNotaOrigem(cabecalhoWidget, cabecalhoWidget.currentRow);
        validaChaveAcessoObrigatoria(cabecalhoWidget);
        validaCampoAF(cabecalhoWidget);
        // processaModelFieldNotaOrigem(cabecalhoWidget.getField('DSNOTAFISCORIG'), cabecalhoWidget.currentRow);
    };
    
    var alteraVisibilidadeCampoNotaOrigem = function(cabecalhoWidget) {
        var validacoes = processaValidacoesNotaOrigem(cabecalhoWidget.currentRow);
        if(validacoes.usaNotaOrigem) {
            if(validacoes.usaListaNotaOrigem) {
                cabecalhoWidget.getField('DSNOTAFISCORIG').isVisible = false; 
                cabecalhoWidget.getField('PKNOTAFISCORIG').isVisible = true; 
            } else {
                cabecalhoWidget.getField('PKNOTAFISCORIG').isVisible = false; 
                cabecalhoWidget.getField('DSNOTAFISCORIG').isVisible = true; 
            }    
        } else {
            cabecalhoWidget.getField('PKNOTAFISCORIG').isVisible = false; 
            cabecalhoWidget.getField('DSNOTAFISCORIG').isVisible = false; 
        }
    };
    
    this.cabecalhoWidgetAfterMoveRow = function(cabecalhoWidget) {
        alteraVisibilidadeCampoNotaOrigem(cabecalhoWidget);
        this.preencheInfoCompra(cabecalhoWidget);
    };
    
    this.preencheInfoCompra = function(cabecalhoWidget) {
        var widget = cabecalhoWidget.container.getWidget('cabecalho');
        var fieldNotaEmp = widget.getField('DSNOTAEMPENHO');
        var fieldPed = widget.getField('CDPEDIDO');
        var fieldContr = widget.getField('CDCONTRATO');
       
        fieldNotaEmp.reload().then(function() { 
            if(fieldNotaEmp.dataSource.data[0]){
                fieldNotaEmp.setValue(fieldNotaEmp.dataSource.data[0].DSNOTAEMPENHO);
                fieldPed.setValue(fieldNotaEmp.dataSource.data[0].CDPEDIDO);
                fieldContr.setValue(fieldNotaEmp.dataSource.data[0].CDCONTRATO);
            }
        });
    };
    
    var getNotaOrigemField = function(cabecalhoWidget) {
        var notaOrigemField;
        alteraVisibilidadeCampoNotaOrigem(cabecalhoWidget);
        notaOrigemField = cabecalhoWidget.getField('DSNOTAFISCORIG').isVisible? cabecalhoWidget.getField('DSNOTAFISCORIG') : cabecalhoWidget.getField('PKNOTAFISCORIG');
        
        return notaOrigemField;
        
    };

    //POR ENQUANTO SÓ ESTÁ PREPARADO PARA NOTAS DE DEVOLUÇÃO, DESCONSIDERANDO AS DE COMPLEMENTO E A DE DEVOLUÇÃO INDUSTRIAL
    var validaCampoNotaOrigem = function(cabecalhoWidget, cabecalhoCurrentRow) {
        var notaOrigemField = getNotaOrigemField(cabecalhoWidget);

        limpaCamposOutData(notaOrigemField, cabecalhoCurrentRow);
        processaViewFieldNotaOrigem(notaOrigemField, cabecalhoCurrentRow);

        processaModelFieldNotaOrigem(notaOrigemField, cabecalhoCurrentRow);
    };

    var processaValidacoesNotaOrigem = function(cabecalhoCurrentRow) {
        var validacoesNotaOrigem = {};

        validacoesNotaOrigem.usaNotaOrigem = cabecalhoCurrentRow.IDOPERDEVONF == 'S' &&
                                                !!cabecalhoCurrentRow.NRINSJURNF;

        validacoesNotaOrigem.notaOrigemObrigatoria = validacoesNotaOrigem.usaNotaOrigem &&
                                                        cabecalhoCurrentRow.IDNFORIGOBRI == 'S';

        validacoesNotaOrigem.usaListaNotaOrigem = validacoesNotaOrigem.usaNotaOrigem &&
                                                    cabecalhoCurrentRow.IDUTLLISTORI == 'S';

        validacoesNotaOrigem.limitaNotaOrigem = validacoesNotaOrigem.usaNotaOrigem &&
                                                cabecalhoCurrentRow.DSOPERNFORIG !== null &&
                                                cabecalhoCurrentRow.DSOPERNFORIG !== undefined &&
                                                cabecalhoCurrentRow.DSOPERNFORIG.length > 4;

        validacoesNotaOrigem.notaOrigemEntrada = validacoesNotaOrigem.limitaNotaOrigem &&
                                                    cabecalhoCurrentRow.DSOPERNFORIG.indexOf('E') !== -1;

        validacoesNotaOrigem.notaOrigemSaida = validacoesNotaOrigem.limitaNotaOrigem &&
                                                cabecalhoCurrentRow.DSOPERNFORIG.indexOf('S') !== -1;

        validacoesNotaOrigem.estorno = cabecalhoCurrentRow.IDNFESTCANC != 'N';

        var DESTINATARIO = cabecalhoCurrentRow.IDORIGDESTOP || cabecalhoCurrentRow.IDORIGDESTNF;

        validacoesNotaOrigem.destinatario = {};
        validacoesNotaOrigem.destinatario.cliente    = DESTINATARIO == 'C';
        validacoesNotaOrigem.destinatario.fornecedor = DESTINATARIO == 'F';
        validacoesNotaOrigem.destinatario.filial     = DESTINATARIO == 'L';

        validacoesNotaOrigem.complemento = cabecalhoCurrentRow.CDTIPOOPER == 3; //REGRA PODE MUDAR!

        validacoesNotaOrigem.devolucao = validacoesNotaOrigem.usaNotaOrigem &&
                                        !validacoesNotaOrigem.complemento;

        return validacoesNotaOrigem;
    };

    var processaViewFieldNotaOrigem = function(notaOrigemField, cabecalhoCurrentRow) {
        var validacoes = processaValidacoesNotaOrigem(cabecalhoCurrentRow);

        if (validacoes.usaNotaOrigem) {
            notaOrigemField.isVisible = true;
        }
        else {
            notaOrigemField.isVisible = false;
        }

        if (validacoes.notaOrigemObrigatoria)
            notaOrigemField.validations = {required: true};
        else
            delete notaOrigemField.validations;
        
        templateManager.container.getActiveWidget().reload();
    };

    var processaModelFieldNotaOrigem = function(notaOrigemField, cabecalhoCurrentRow) {
        var validacoes = processaValidacoesNotaOrigem(cabecalhoCurrentRow),
            valoresFiltro = processaValoresFiltroNotaOrigem(cabecalhoCurrentRow),
            filtros;

        if (validacoes.estorno) {
            filtros = {};
            filtros.CDFILIAL    = 'CDFILIAL';
            filtros.IDTPIJURNF  = 'IDTPIJURNF';
            filtros.NRINSJURNF  = 'NRINSJURNF';
            filtros.CDFILIRECE  = 'CDFILIRECE';
            filtros.NOTAFISC    = 'NOTAFISC';
            filtros.TNRNOTAFISC = 'TNRNOTAFISC';
            filtros.CDSERIE     = 'CDSERIE';
            filtros.TSERIE      = 'TSERIE';
            filtros.CDTIPOOPEN  = 'CDTIPOOPEN';
            filtros.CDTIPOOPSA  = 'CDTIPOOPSA';
            filtros.CDFILIEMIT  = 'CDFILIRECE'; //atenção!

            notaOrigemField.dataSource.name = 'df_entrada#/crud/doc_origem_estorno_lancamento_entrada';
        } else {
            filtros = [];
            filtros.push('CDFILIAL', 'IDTPIJURNF', 'NRINSJURNF', 'CDFILIRECE', 'RELACDOORI');

            if (validacoes.notaOrigemEntrada) {
                filtros.push('CDTIPOOPEN', 'CDTIPOOPSA', 'CDTIPOOPER');

                if (validacoes.notaOrigemSaida)
                    notaOrigemField.dataSource.name = 'df_entrada#/crud/doc_origem_entrsaid_lancamento_entrada';
                else
                    notaOrigemField.dataSource.name = 'df_entrada#/crud/doc_origem_entrada_lancamento_entrada';
            } else {
                if (validacoes.notaOrigemSaida) {
                    filtros.push('CDTIPOOPSA');

                    notaOrigemField.dataSource.name = 'df_entrada#/crud/doc_origem_saida_lancamento_entrada';
                } else {
                    filtros.push('CDTIPOOPER');

                    notaOrigemField.dataSource.name = 'df_entrada#/crud/doc_origem_todos_lancamento_entrada';
                }
            }
        }

        notaOrigemField.dataSourceFilter = processaFiltro(filtros, valoresFiltro); //array/object, object => object array
    };

    var processaFiltro = function(nomes, valores) {
        if (typeof nomes != 'object')
            throw {data: {error: 'Tipo de variável inválido para a função processaFiltro!'}};
        else if (Array.isArray(nomes))
            return nomes.map(nome => ({name: nome, operator: '=', value: valores[nome]}));
        else return Object.keys(nomes).map(key => ({name: key, operator: '=', value: valores[nomes[key]]}));
    };

    var processaValoresFiltroNotaOrigem = function(cabecalhoCurrentRow) {
        var validacoes = processaValidacoesNotaOrigem(cabecalhoCurrentRow),
            valoresFiltro = {};

        valoresFiltro.CDSERIE = '';
        valoresFiltro.TSERIE = 'T';
        // valoresFiltro.NRNOTAFISC = 'L';
        valoresFiltro.TNRNOTAFISC = 'T';

        valoresFiltro.CDTIPOOPER = cabecalhoCurrentRow.CDTIPOOPER;
        valoresFiltro.RELACDOORI = cabecalhoCurrentRow.IDDCORIGRELAC;

        valoresFiltro.CDTIPOOPEN = processaTiposOrigemPermitidosPorOperacao(cabecalhoCurrentRow, 'E');
        valoresFiltro.CDTIPOOPSA = processaTiposOrigemPermitidosPorOperacao(cabecalhoCurrentRow, 'S');

        if (validacoes.destinatario.cliente || validacoes.destinatario.fornecedor) {
            valoresFiltro.CDFILIAL = cabecalhoCurrentRow.CDFILIRECE;
            valoresFiltro.IDTPIJURNF = cabecalhoCurrentRow.IDTPIJURNF;
            valoresFiltro.NRINSJURNF = cabecalhoCurrentRow.NRINSJURNF;
            valoresFiltro.CDFILIRECE = 'T';
        } else {
            valoresFiltro.IDTPIJURNF = '';
            valoresFiltro.NRINSJURNF = '';

            if (validacoes.estorno) {
                valoresFiltro.CDFILIAL = cabecalhoCurrentRow.CDFILIRECE;
                valoresFiltro.CDFILIRECE = cabecalhoCurrentRow.CDFILIEMIT;
            } else {
                valoresFiltro.CDFILIAL = cabecalhoCurrentRow.CDFILIEMIT;
                valoresFiltro.CDFILIRECE = cabecalhoCurrentRow.CDFILIRECE;
            }
        }

        return valoresFiltro;
    };
    
    //Função para adicionar sequencialmente as informações complementares dos Produtos.
    this.nextProdutoLib = function() {
        var widget = templateManager.container.getWidget("itens");
        widget.currentRow.NRLANCTONF = widget.getParent().currentRow.NRLANCTONF;
        
        var validacoes = processaValidacoesNotaOrigem(templateManager.container.getWidget("cabecalho").currentRow);
        
        var row2 = {
            IDENTRSAIDOP:widget.getParent().currentRow.IDENTRSAIDOP,
            CDTIPOOPER:widget.getParent().currentRow.CDTIPOOPER
        };
        
        General.callRestEngine("df_entrada#/getIDATUESTTPOP", "Row", row2).then((success) => {
          atualizaEstoque = success.dataset.atualizaEstoque.IDATUESTTPOP;
           
        });
        
        if(validacoes.devolucao) 
            widget.paramInfoCompl.DocuDevo = true;
        
        if(!widget.currentRow.__is_new) //salva mudança de almoxarifado em itens já importados.
            Df11000_Lancamento_Service.salvaItem(widget.getParent().currentRow, widget.currentRow);
            
            if(widget.itemsInfCompl){  //confere se existe mais produtos na lista de produtos do datasource para ser adicional local de estoque
                for(var i=0 ; i < widget.dataSource.data.length  ; i++){ //atualiza datasourceLocal da widget para setar no localstorage no final do processo
                    if(widget.dataSource.data[i].NRSEQITPROD === widget.currentRow.NRSEQITPROD)
                        widget.dataSource.data[i] = widget.currentRow;
                        Df11000_Lancamento_Service.setDataSourceItem(widget.dataSource.data)
                        .then(
                            Df11000_Lancamento_Service.atualizaLancamento()
                    );
                }    
                    widget.itemsInfCompl.shift();
                if(widget.itemsInfCompl[0]) {
                    var row = widget.itemsInfCompl[0];
                    widget.currentRow = row;
                    setValoresEmissaoProdutoOnChange(row);
                    
                    Dfe11000_LancamentoEntrada_Service.getFornImportRastXml().then((success) => {
                        let fornImportRastXml = (success) ? success.IDIMPRASTXML : 'N';
                        var FilterData = [{
                            'name':"CDPRODUTO",
                            "operator":"=",
                            "value":row.CDPRODUTO
                        },
                        {
                            'name':"CDFILIAL",
                            "operator":"=",
                            "value":row.CDFILIAL
                        }
                        ];    
                            
                        General.callRestEngine('df#/crud/prodfili', 'FilterData', FilterData).then(function(success) {
                            if (success.dataset.prodfili[0]){
                                row.IDCNTRESTOQ = success.dataset.prodfili[0].IDCNTRESTOQ;
                                if(fornImportRastXml === 'S') Lib00206_InfComplProduto_Controller.infComplementares(widget, row, true, atualizaEstoque);
                                else                          Lib00206_InfComplProduto_Controller.infComplementares(widget, row, false, atualizaEstoque);             
                            }
                        });
                    });
                }
                else {
                    Df11000_Lancamento_Service.setDataSourceItem(widget.dataSource.data)
                    .then(function(success){
                        Df11000_Lancamento_Service.atualizaLancamento();
                    });
                }
            }
            
    };

    var processaTiposOrigemPermitidosPorOperacao = function(cabecalhoCurrentRow, operacao) {
        var validacoes = processaValidacoesNotaOrigem(cabecalhoCurrentRow);

        if (validacoes.limitaNotaOrigem)
            return cabecalhoCurrentRow.DSOPERNFORIG.split('_')
                .filter(piece => piece.length == 4 && piece[0] == operacao)
                .reduce((prevValue, currValue) => prevValue += currValue + '_', '_');
        else
            return '_';
    };

    var alteraVisibilidadeCampoInscricao = function() {
        var cabecalhoWidget = getCabecalhoWidget();
        var cabecalhoCurrentRow = cabecalhoWidget.currentRow;
        var cliente = cabecalhoWidget.getField('NMRAZSOCCLIE');
        var fornecedor = cabecalhoWidget.getField('NMRAZSOCFORN');
        var filial = cabecalhoWidget.getField('DSFILIEMIT');
        var tipoDestino = cabecalhoCurrentRow.IDORIGDESTOP || cabecalhoCurrentRow.IDORIGDESTNF;

        switch (tipoDestino) {
            case 'C':
                validacaoCamposOutTpOperac(cliente, fornecedor, filial);
                break;
            case 'F':
                validacaoCamposOutTpOperac(fornecedor, cliente, filial);
                break;
            case 'L':
                validacaoCamposOutTpOperac(filial, fornecedor, cliente);
                break;
            default:
                filial.readOnly = true;
                cliente.readOnly = true;
                fornecedor.readOnly = true;
        }
    };

    var validaChaveAcessoObrigatoria = function(cabecalhoWidget) {
        var cabecalhoRow = cabecalhoWidget.currentRow,
            chaveAcessoField = cabecalhoWidget.getField('NRACESSONFE'),
            chaveAcessoObrigatoria = cabecalhoRow.IDMODDOCNFE === 'S' && cabecalhoRow.IDORIGDESTNF === 'F' && (cabecalhoRow.IDOBRCHAVACES === 'S') && cabecalhoRow.IDTIPOOPERELE === 'S';
        
        if(chaveAcessoObrigatoria == false && cabecalhoRow.CDFORNECED) {
            var filter = [
                {
                    "name": "CDFORNECED",
                    "operator": "=",
                    "value": cabecalhoRow.CDFORNECED
                }
            ];
            General.callRestEngine("df#/crud/paramforne", "FilterData", filter).then((sucesso) => {
                if(sucesso.dataset.paramforne[0]) {
                    var paramforne = sucesso.dataset.paramforne[0];
                    chaveAcessoObrigatoria = cabecalhoRow.IDMODDOCNFE === 'S' && cabecalhoRow.IDORIGDESTNF === 'F' && (paramforne.IDOBRCHAVACESFO === 'S') && cabecalhoRow.IDTIPOOPERELE === 'S';
                    
                    if (chaveAcessoObrigatoria)
                        chaveAcessoField.validations = {required: true};
                    else
                        delete chaveAcessoField.validations; 
                    
                    Dfe11000_LancamentoEntrada_Service.setFornImportRastXml(paramforne.IDIMPRASTXML);
                } 
            });
        }
        else {
            if (chaveAcessoObrigatoria)
                chaveAcessoField.validations = {required: true};
            else
                delete chaveAcessoField.validations; 
        }
        
    };

    var validaCampoAF = function(cabecalhoWidget, importingXML) {
        var cabecalhoRow = cabecalhoWidget.currentRow;
        var cbutilizaafField = cabecalhoWidget.getField('CBUTILIZAAF');

        cbutilizaafField.readOnly = (!cabecalhoRow.CDTIPOOPER || !cabecalhoRow.CDFORNECED);

        Dfe11000_LancamentoEntrada_Service.validaAF(cabecalhoRow).then(function(response){
            var obrigaAF = response.dataset.validaAF[0];
            if(obrigaAF)
                cbutilizaafField.validations = {required: true};
            else{
                if (isAFRequired(cabecalhoRow, importingXML))
                    cbutilizaafField.validations = {required: true};
                else{
                    cbutilizaafField.readOnly = false;
                    delete cbutilizaafField.validations;
            
                }    
            }
        });
        
        
    };
    
    
    var isAFRequired = function(cabecalhoRow, importingXML){
        if(isNFCompra(cabecalhoRow))
            return AFRequiredForSupplier(cabecalhoRow) || cabecalhoRow.IDBLOQAF == 'S';
        else{
            General.callRestEngine('df#/crud/paramgeral', 'FilterData', []).then(function(success) {
                if(success.dataset.paramgeral[0]){
                    var paramgeral = success.dataset.paramgeral[0];
                    if(paramgeral.IDUTBLOQOPAFPG  == 'S')
                        return Dfe11000_LancamentoEntrada_Service.isAFTipoOper(cabecalhoRow.CDTIPOOPER, cabecalhoRow.CDFILIRECE).then(result => {
                            if(result == true)
                                return importOnlyAFProducts(cabecalhoRow) && importingXML;
                            else
                                return false;
                        });
                    else
                        return false;
                }
                return false;
            });
            
        }

    };
    
    this.venctosSemDataSourceFilter = (widget) => {
       if(widget.dataSourceFilter.length) {
           if(widget.dataSourceFilter[0].isCustomFilter) {
               widget.dataSourceFilter = [];
               widget.dataSource.reload();
           }
       }
   };
    
    //const isAFRequired = (cabecalhoRow, importingXML) =>  isNFCompra(cabecalhoRow)? cabecalhoRow.IDBLOQAF == 'S' || AFRequiredForSupplier(cabecalhoRow) : importingXML && importOnlyAFProducts(cabecalhoRow);

    const isNFCompra = ({CDTIPOOPER, IDORIGDESTNF, IDNFPRESTSERV = 'N', IDNFESTCANC = 'N', IDNFRETIND = 'N'}) => (CDTIPOOPER == '01');

    const AFRequiredForSupplier = ({CDTIPOOPER, IDBLOQCMPSAFFIL = 'N', IDBLOQCMPSAFFOR = 'N'}) => !!(IDBLOQCMPSAFFIL === 'S' && IDBLOQCMPSAFFOR === 'S' && CDTIPOOPER === '01');

    const importOnlyAFProducts = row => row.IDPERIMPSPRAF === 'S';
    
    var isAFTipoOper = function(cabecalhoRow){
            return Dfe11000_LancamentoEntrada_Service.isAFTipoOper(cabecalhoRow.CDTIPOOPER, cabecalhoRow.CDFILIAL);
    };
    
    /**
         * @desc - Adiciona valores obrigatorios na current row da nota.
        * @emit - Chamada na funcao responsável pelo salvamento da nota fiscal(salvaCabeçalhoLancamentoOnClick)
        * @param object cabecalhoRow
        * @param object paramsNewCode
    */
    var addValoresObrigatoriosCurrentRowCabebalho = function(cabecalhoRow, paramsNewCode) {
        cabecalhoRow.IDBLOQUEADO  = 'N';
        cabecalhoRow.IDDOCFISCAL  = 'S';
        cabecalhoRow.IDDOCFINANC  = 'S';

        cabecalhoRow.VRPRODUTOS   = 0;

        cabecalhoRow.IDENTRSAIDOP = 'E';
        cabecalhoRow.IDSISTEMA    = 'DFE';
        cabecalhoRow.IDSTATUS     = 'D';
        
        if(cabecalhoRow.IDNFGERADAVIAXML !== 'S')
            cabecalhoRow.IDNFGERADAVIAXML = (!!cabecalhoRow.NRACESSONFE && !cabecalhoRow.MANUAL_POSTING) ? 'S' : 'N';

        cabecalhoRow.CDTIPOOPEN = processaTiposOrigemPermitidosPorOperacao(cabecalhoRow, 'E');
        cabecalhoRow.CDTIPOOPSA = processaTiposOrigemPermitidosPorOperacao(cabecalhoRow, 'S');

        if (paramsNewCode && typeof paramsNewCode === 'object') {
            var keysParamsNewCode = Object.keys(paramsNewCode);
            keysParamsNewCode.forEach(value => {
                cabecalhoRow[value] = paramsNewCode[value];
            });
        }
    };

    var realizaSalvamentoCabecalhoNotaFiscal = function(cabecalhoWidget, datasourceProduto = null) {
        var paramsNewCode = cabecalhoWidget.paramsNewCode,
            cabecalhoRow = cabecalhoWidget.currentRow;

        var fornecedBloqTipoOperac = ('ERROS_LANCAMENTO' in cabecalhoRow && !!cabecalhoRow.ERROS_LANCAMENTO.fornecedorBloqTipoOperac);

        if (fornecedBloqTipoOperac) {
            return showMessageDfe('TIPO_OPERACAO_BLOQ_FORNECEDOR');
        }
        
        addValoresObrigatoriosCurrentRowCabebalho(cabecalhoRow, paramsNewCode);
        
        validacaoRelacionamentoItens(cabecalhoWidget).then(() => {

            if(cabecalhoWidget.currentRow.__is_new == false) {
                General.callRestEngine("df_entrada#/af_indice", "Row", cabecalhoRow).then((response) => {
                    if(response.dataset.af_indice.utilizaIndice) {
                        ScreenService.confirmMessage('O valor do índice financeiro pode ser diferente para a nova data de emissão. Deseja atualizar os valores dos produtos importados de uma AF com o novo índice?', 'question',
                            (success) =>  {
                                cabecalhoRow.ATUALIZAINDICE = true;
                                this.salvaCabecalho(cabecalhoWidget, cabecalhoRow);
                            },
                            (error) => {
                                cabecalhoRow.ATUALIZAINDICE = false;
                                this.salvaCabecalho(cabecalhoWidget, cabecalhoRow);
                            }
                        ); 
                    }
                    else {
                        cabecalhoRow.ATUALIZAINDICE = false;
                        this.salvaCabecalho(cabecalhoWidget, cabecalhoRow);
                    }
                });
            }
            else {
               
                cabecalhoRow.ATUALIZAINDICE = false;
                this.salvaCabecalho(cabecalhoWidget, cabecalhoRow, datasourceProduto);
                
            }
            
             this.habilitaTabProdutosOuNotas(cabecalhoWidget);
            
        });
        
    }.bind(this);
    
    this.salvaCabecalho = (cabecalhoWidget, cabecalhoRow, datasourceProduto = null) => {
        const novaNota = cabecalhoRow.__is_new;
        const usaAf    = (cabecalhoRow.AF) ? true : false;
        
        //if( !novaNota && cabecalhoRow.IDSTATUS == 'D' ) { cabecalhoRow.IDSTATUS = 'P'; }
        
        General.callRestEngine("df_entrada#/validaNotaCadastrada", "Row", cabecalhoRow).then(() => {
            General.callRestEngine("df_entrada#/salvarNotaEntrada", "Row", cabecalhoRow).then((cabecalho) => {
                if(cabecalhoRow.NRACESSONFE){
                    if(!atualizouRelacionamento){
                        cabecalhoWidget.container.getWidget('relacionamentoItens').dataSource.reload();
                        datasourceRelacionamento = cabecalhoWidget.container.getWidget('relacionamentoItens').dataSource.data; 
                    }
                    if(datasourceRelacionamento.length != 0){
                        datasourceRelacionamento[0].CDFILIAL = cabecalho.dataset.columnsToReturn[0].CDFILIAL;
                        datasourceRelacionamento[0].NRLANCTONF = cabecalho.dataset.columnsToReturn[0].NRLANCTONF;
                        General.callRestEngine("df_entrada#/atualizaDadosProduto", "Row", datasourceRelacionamento).then((cabecalhoRelacionamento) => {
                            this.atualizaCabecalho(cabecalho,cabecalhoRow,cabecalhoWidget, novaNota,usaAf,datasourceProduto);
                            //cabecalhoWidget.container.getWidget('itens').reload();
                        });
                    }else{
                       this.atualizaCabecalho(cabecalho,cabecalhoRow,cabecalhoWidget, novaNota,usaAf,datasourceProduto); 
                    } 
                }else{
                    this.atualizaCabecalho(cabecalho,cabecalhoRow,cabecalhoWidget, novaNota,usaAf,datasourceProduto); 
                }
                 this.validaSugereAlmox();
                
            }).catch((error) => {
                MessageService.showMessageByCode(ScreenService.showMessage(error.data.error)).catch (response => {
                    ScreenService.showMessage(error.data.error); 
                });
                //ScreenService.showMessage(error.data.error);
            });
            
        }).catch((error) => {
           ScreenService.showMessage("Nota fiscal já cadastrada para remetente ");
        });
    };

    this.atualizaCabecalho = function(cabecalho,cabecalhoRow,cabecalhoWidget, novaNota,usaAf,datasourceProduto){
        var columnsToReturn = cabecalho.dataset.columnsToReturn[0];
                cabecalhoRow.NRLANCTONF = columnsToReturn.NRLANCTONF;
                cabecalhoRow.CDFILIAL = columnsToReturn.CDFILIAL;
    
                cabecalhoWidget.container.getWidget('relacionamentoItens').isVisible = false;
    
                controlaStatusWidgets(cabecalhoWidget, cabecalhoWidget.name, true);
                
    
                criaDetalhesLancamentoWidgetAfterMoveRow(cabecalhoRow)
                .then(() => {
                    if(novaNota) {
                        if(cabecalhoRow.NRACESSONFE || usaAf) {
                            cabecalhoWidget.paramInfoCompl.showLote = true;
                            this.persisteLocalEstoque(cabecalhoWidget, cabecalhoRow, datasourceProduto);
                        }
                    }
                    else {
                        cabecalhoWidget.activate();
                    }
                });
                
                if(cabecalhoWidget.isValid() && cabecalhoWidget.currentRow.DSLINKANEXO != null){
                    General.callRestEngine('df_entrada#/salvar_Anexo', "Row", cabecalhoRow);
                }
                
                if (!!cabecalhoRow.__is_new && (!!cabecalhoRow.NRACESSONFE || 'AF' in cabecalhoRow)) {
                    delete cabecalhoRow.AF;
                }
                cabecalhoWidget.container.getWidget('impostosItem').reload();
                cabecalhoWidget.currentWidget = cabecalhoWidget;
                cabecalhoWidget.view();
                validaEdicaoNota();
                cabecalhoRow.__is_new = false; 
    };
    
    //Ao importar XML confere se utiliza local de estoque e almoxarifado para chamar Lib de dados complementares do produto
    this.persisteLocalEstoque = (cabecalhoWidget, cabecalhoRow, datasourceProduto = null) => {
        var widgetProduto = cabecalhoWidget.container.getWidget('itens');
        var validacoes = processaValidacoesNotaOrigem(cabecalhoRow);
        
        if(validacoes.devolucao) 
            widgetProduto.paramInfoCompl.DocuDevo = true;
            
        var row = {
            IDENTRSAIDOP:widgetProduto.getParent().currentRow.IDENTRSAIDOP,
            CDTIPOOPER:widgetProduto.getParent().currentRow.CDTIPOOPER
        };
        
        General.callRestEngine("df_entrada#/getIDATUESTTPOP", "Row", row).then((success) => {
          atualizaEstoque = success.dataset.atualizaEstoque.IDATUESTTPOP;
           
        });

        
        General.callRestEngine("df#/crud/paramfilial", "FilterData", [{name: "CDFILIAL", operator: "=", value: cabecalhoRow.CDFILIRECE}]).then((success) => {
            if(success.dataset.paramfilial[0].IDUTILALMOX == 'S' && success.dataset.paramfilial[0].IDCTRLESTQ == 'S') {
    
                widgetProduto.reload();
                var data = cabecalhoWidget.container.getWidget('itens').dataSource.data;
                // data[0]["NMPRODUTO"] = datasourceProduto.NMPRODUTOFORNXML;
                // data[0]["SGUNIDADE"] = datasourceProduto.SGUNIDADE;
                // data[0]["DSPRODEMIS"] = datasourceProduto.NMPRODUTOFORNXML;
                // data[0]["CDPRODEMIS"] = datasourceProduto.CDPRODUTOXML;
                // data[0]["DSPRODEMIS"] = datasourceProduto.NMPRODUTOFORNXML;
                cabecalhoWidget.openTab('itens');
                widgetProduto.activate();
                data.forEach(function(row){
                    row.CDFILIMOVI = cabecalhoRow.CDFILIRECE;
                });
                widgetProduto.itemsInfCompl = data; 
                widgetProduto.currentRow = data[0];
                var row = data[0];
                if(row){
                     Dfe11000_LancamentoEntrada_Service.getFornImportRastXml().then((success) => {
                        let fornImportRastXml = (success) ? success.IDIMPRASTXML : 'N';
                        General.callRestEngine('df#/crud/paramfilial', 'FilterData', []).then(function(success) {
                            var filiais =  success.dataset.paramfilial;
                            var filialFiltrada;
                            
                            filiais.forEach(filial=>{
                               if(filial.CDFILIAL == getCabecalhoWidget().currentRow.CDFILIRECE) {
                                   return ((filialFiltrada = filial));
                               }
                            });
                            if(filialFiltrada){
                                if(fornImportRastXml === 'S') Lib00206_InfComplProduto_Controller.infComplementares(widgetProduto, row, true, atualizaEstoque);
                                else                          Lib00206_InfComplProduto_Controller.infComplementares(widgetProduto, row, false, atualizaEstoque); 
                            }
                        });
                    });
                }
                else
                    Df11000_Lancamento_Service.setDataSourceItem(widgetProduto.dataSource.data)
                    .then(Df11000_Lancamento_Service.atualizaLancamento());
            } 
            else {
                cabecalhoWidget.openTab('itens');

                widgetProduto.reload();
                widgetProduto.activate();
            }
        });
    };
    
    this.chamaDadosAdicionais = (args) => {
        var widgetProduto =  templateManager.container.getWidget("itens"),
            row = args.row,
            widgetCabecalho = widgetProduto.getParent();
        
        Df11000_Lancamento_Service.getStatusNota(widgetCabecalho.currentRow).then(salvaNota => {
            if(salvaNota) {
                var validacoes = processaValidacoesNotaOrigem(widgetCabecalho.currentRow),
                    rows = {
                        IDENTRSAIDOP:widgetProduto.getParent().currentRow.IDENTRSAIDOP,
                        CDTIPOOPER:widgetProduto.getParent().currentRow.CDTIPOOPER
                    };
                row.CDFILIMOVI = widgetCabecalho.currentRow.CDFILIRECE;
                
                General.callRestEngine("df_entrada#/getIDATUESTTPOP", "Row", rows).then((success) => {
                  atualizaEstoque = success.dataset.atualizaEstoque.IDATUESTTPOP;
                });
                
                if(validacoes.devolucao)
                    widgetProduto.paramInfoCompl.DocuDevo = true;
                
                Dfe11000_LancamentoEntrada_Service.getFornImportRastXml().then((success) => {
                    let fornImportRastXml = (success) ? success.IDIMPRASTXML : 'N';
                    
                    if(fornImportRastXml === 'S') Lib00206_InfComplProduto_Controller.infComplementares(widgetProduto, row, true, atualizaEstoque);
                    else                          Lib00206_InfComplProduto_Controller.infComplementares(widgetProduto, row, false, atualizaEstoque);
                });
            }
            else MessageService.showMessageByCode('BLOCK_NOTE');
        }, requestError);
    };

    this.persisteImpostos = (cabecalhoWidget, cabecalhoRow) => {
        if (!cabecalhoRow.__is_new) {
            return calculaImpostoItemProduto(cabecalhoRow, cabecalhoWidget.container.getWidget('itens').dataSource.data[0]);
        }
    };

    this.realizaImportacaoItensNotaOrigem = function(cabecalhoWidget, cabecalhoRow) {
        //VERFICAR COMO CHEGA O DSNOTAFISCORIG
        cabecalhoRow = Util.clone(cabecalhoRow, ["__rightActions", "__leftActions"]);
        var deferred = ZHPromise.defer(),
            itensWidget = cabecalhoWidget.container.getWidget('itens'),
            validacoes = processaValidacoesNotaOrigem(cabecalhoRow);

        if (validacoes.usaNotaOrigem) {
            //to-do: implementar importação de notas de complemento e estorno
            if (validacoes.devolucao) {
                Dfe11000_LancamentoEntrada_Service.realizaImportacaoItensNotaOrigem(cabecalhoRow)
                    .then(itens => {
                        itens = itens.dataset.itens_notas_origem_entrada;
                        /*var isInvalid = itens.some(function(item) {
                            return !item.QTITEMPROD || !item.VRUNITITEM || !item.VRTOTAITEM;
                        });

                        if (isInvalid) {
                            return ScreenService.showMessage('Campos obrigatórios não preenchidos.');
                        }*/

                        itens.forEach(item => {
                            item.__is_new = true;
                            delete(item.__rightActions); 
                            delete(item.__leftActions);
                        });

                        itensWidget.dataSource.data = itens;

                        return Dfe11000_LancamentoEntrada_Service.salvaMultiItens(itens, [], cabecalhoRow);
                    })
                    .then(impostosProdutos => {
                        var itens = itensWidget.dataSource.data,
                            impostos = impostosProdutos.dataset.impostosTemp;

                        impostos.forEach(imposto => {
                            imposto = Object.keys(imposto).map(key => imposto[key]);
                            imposto.forEach(impos => {
                                impos.CDIMPOSTO = impos.CDIMPOTEMP;
                                impos.__is_new = false;

                                delete impos.CDIMPOTEMP;
                            });
                            Df11000_Lancamento_Service.setDataSourceItensImpostos(imposto);
                        });

                        itens.forEach(item => {
                            item.__is_new = false;
                            delete item.changed;
                        });

                        Df11000_Lancamento_Service.setDataSourceItem(itens).then(() => {
                            Df11000_Lancamento_Service.atualizaLancamento().then(itensWidget.reload());
                        });

                        alteraStatusNotafiscal(cabecalhoWidget, true).then(() => controlaStatusWidgets(cabecalhoWidget, cabecalhoWidget.name, true));

                        itensWidget.list();
                        cabecalhoWidget.view();
                    }).catch(requestError);
            } else
                deferred.resolve();
        } else
            deferred.resolve();

        return deferred;
    };
    
    // Se cumprir os requisitos chama a função de salvar a nota    
    this.validaStatusSalvaNota = function (lancamentoCabecalhoArgs) {
        if(lancamentoCabecalhoArgs.row.__is_new) {
            this.salvaCabecalhoLancamentoOnClick(lancamentoCabecalhoArgs);
            //this.validaSugereAlmox();
        } else {
            Df11000_Lancamento_Service.getStatusNota(lancamentoCabecalhoArgs.row).then(salvaNota => {
                if(salvaNota) self.salvaCabecalhoLancamentoOnClick(lancamentoCabecalhoArgs);
                else          MessageService.showMessageByCode('BLOCK_NOTE');
            }, requestError);
        }
    };

    /* @desc - Função responsável pelo salvamento da notafiscal, importação de af e chave de acesso
     * @emit - No evento de onClick da action salvar
     * @param object argsCabecalho */
    this.salvaCabecalhoLancamentoOnClick = function(argsCabecalho) {
        if(argsCabecalho.owner.widget.isValid()){
            validaDataPeriodoContabil().then( response => {
            if(response){
                var cabecalhoWidget = argsCabecalho.owner.widget;
            
                Dfe11000_LancamentoEntrada_Service.getFilial().then(function(result){
                    if(!cabecalhoWidget.currentRow.CDFILIAL)
                        cabecalhoWidget.currentRow.CDFILIAL = result.dataset.filial[0].CDFILIAL;
                
                    if (!cabecalhoWidget.isValid()) {
                        return argsCabecalho.e.preventDefault();
                    }
                    
                    alteraStatusNotafiscal(cabecalhoWidget, false);
                    return realizaSalvamentoCabecalhoNotaFiscal(cabecalhoWidget);
                });
            } else {
                return MessageService.showMessageByCode('DT_ENTRADA_FORA_PERIODO_CONTABIL');
            }
        });
        }
        
    };
    
    var validaDataPeriodoContabil = function(){
        var promise = ZHPromise.defer();
        var widget = templateManager.container.getActiveWidget();
        var dtentrsaid = widget.currentRow.DTENTRSAID,
            empresa = widget.currentRow.CDEMPRESA,
            nmempresa = widget.currentRow.NMEMPRESA;
        
        if(dtentrsaid && empresa) {
            let filter = [
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": empresa
                }
            ];
                
            General.callRestEngine("df#/crud/contopectbl", "FilterData", filter).then(function(success) {
                if(success.dataset.contopectbl.length) {
                    if(success.dataset.contopectbl[0].DTINIINTCONTDFE && success.dataset.contopectbl[0].DTFININTCONTDFE) {
                        var dataEntrada = formataData(dtentrsaid);
                        var dataIni = formataData(success.dataset.contopectbl[0].DTINIINTCONTDFE.substr(0, 10));
                        var dataFin = formataData(success.dataset.contopectbl[0].DTFININTCONTDFE.substr(0, 10));
            
                        var periodoContabilValido;
                
                        if(dataEntrada >= dataIni && dataEntrada <= dataFin) {
                            periodoContabilValido = true;
                            promise.resolve(periodoContabilValido);
                        } else {
                            periodoContabilValido = false;
                            promise.resolve(periodoContabilValido);
                        }
                    }
                } else {
                    MessageService.showMessageByCode('PARAMETRIZACAO_CONTABIL_NAO_REALIZADA', {"CDEMPRESA": empresa, "NMEMPRESA": nmempresa});
                }
            }).catch( error => {
                MessageService.errorNotificationByCode(ScreenService.showMessage(error));
            });
            
            return promise;
        }
    };

    
    var formataData = function(dataString){
        var arrData = dataString.split('/');
        var dataFormatada = arrData[1] + '-' + arrData[0] + '-' + arrData[2];
        var dataFinal = new Date(dataFormatada);
        
        return dataFinal;
    };

    this.validaFornecedorOnChange = function(cabecalhoArgs) {
        var cabecalhoRow = cabecalhoArgs.row;
        var cabecalhoWidget = cabecalhoArgs.owner.field.widget;
        var autoForneWidget = cabecalhoWidget.container.getWidget('autorizacaoFornecimento');
        limpaWidgetAutoForne(autoForneWidget, cabecalhoWidget);
        validaFornecedorBloqTpOperac(cabecalhoWidget);
        validaCampoAF(cabecalhoWidget);
    };

    var criaParametrosImportacaoAf = function(cabecalhoWidget, importacaoAfWidget) {
        var cabecalhoRow = cabecalhoWidget.currentRow;
        var filial = cabecalhoRow.CDFILIRECE;
        var fornecedor = cabecalhoRow.CDFORNECED;
        var dtminvazia = cabecalhoRow.DTMINVAZIA;
        var dtmaxvazia = cabecalhoRow.DTMAXVAZIA;
        var dtprocini = cabecalhoRow.DTPROCINI;
        var dtprocfin = cabecalhoRow.DTPROCFIN;

        var dataSourceFilterImportacaoAF = [
            {
                name: 'P_CDFILIAL',
                operator: '=',
                value: filial
            },
            {
                name: 'P_CDFORNECED',
                operator: '=',
                value: fornecedor
            },
            {
                name: 'P_DTPROCINI',
                operator: '=',
                value: dtprocini
            },
            {
                name: 'P_DTMINVAZIA',
                operator: '=',
                value: dtminvazia
            },
            {
                name: 'P_DTPROCFIN',
                operator: '=',
                value: dtprocfin
            },
            {
                name: 'P_DTMAXVAZIA',
                operator: '=',
                value: dtmaxvazia
            }
        ];

        importacaoAfWidget.dataSourceFilter = dataSourceFilterImportacaoAF;
        importacaoAfWidget.reload();
    };

    this.abreImportacaoAF = function(field) {
        var cabecalhoWidget = field.widget;
        delete cabecalhoWidget.currentRow.AF;

        var importaAf = field.value();

        if (importaAf === 'S') {
            var autoFornWidget = cabecalhoWidget.container.getWidget('autorizacaoFornecimento');
            autoFornWidget.selectField = field;

            ScreenService.openPopup(autoFornWidget);
            criaParametrosImportacaoAf(cabecalhoWidget, autoFornWidget);
        }
    };

    this.checarAFs = AFWidget => (!AFWidget.dataSource.data.length && (AFWidget.selectField.validations && AFWidget.selectField.validations.required))? showMessageDfe('AF_OBRIGATORIA_E_NENHUMA_ENCONTRADA') : false;

    this.actConfirmarAfsSelecionadas = function(autoForneArgs) {
        var autoForneWidget = autoForneArgs.owner.widget;
        var afsSelecionadas = autoForneWidget.getCheckedRows();
        var cabecalhoWidget = autoForneArgs.owner.widget.container.getWidget('cabecalho');
        var cabecalhoRow = cabecalhoWidget.currentRow;

        if (afsSelecionadas.length) {
            cabecalhoRow.AF = afsSelecionadas;

            var geraNfIgualXml = cabecalhoRow.IDGERNFIGUALXML === 'N';
            if ((!('NRACESSONFE' in cabecalhoRow) || !cabecalhoRow.NRACESSONFE)) {
                ScreenService.showLoader();
                
                var cdfililancs = afsSelecionadas.map(af => af.CDFILLANC).join('_');
                var nrautofrons = afsSelecionadas.map(af => af.NRAUTOFORN).join('_');

                var filter = [
                    {
                        "name": "CDFILLANC",
                        "operator": "=",
                        "value": cdfililancs
                    },
                    {
                        "name": "NRAUTOFORN",
                        "operator": "=",
                        "value": nrautofrons
                    },
                    {
                        "name": "CDFILDEST",
                        "operator": "=",
                        "value": afsSelecionadas[0].CDFILDEST
                    },
                    {
                        "name": "NRORG",
                        "operator": "=",
                        "value": getLocalVar('NRORG')
                    }
                ];
                

               var afEstrangeira = afsSelecionadas.filter(af =>  af.CDINDICE != null);
                
                if(afEstrangeira.length === 0){
                    General.callRestEngine('df_entrada#/crud/totalNf_af', 'FilterData', filter).then(result => {
                        if(result.dataset.totalNf_af && result.dataset.totalNf_af.length > 0 && result.dataset.totalNf_af[0].VRNOTAFISC){
                             var valorNota = result.dataset.totalNf_af[0].VRNOTAFISC;
                                cabecalhoWidget.currentRow.VRNOTAFISC = valorNota;
                                ScreenService.closePopup();
                        } else {
                            ScreenService.showMessage('Erro ao buscar o valor total da nota.');
                        }
                        ScreenService.hideLoader();
                    }, this.genericalRequestError);
                }else{
                    cabecalhoWidget.currentRow.VRNOTAFISC = null;
                    ScreenService.closePopup();
                    ScreenService.hideLoader();
                }
            } else {
                ScreenService.closePopup();
            }
        } else {
            limpaWidgetAutoForne(autoForneWidget, cabecalhoWidget);
            ScreenService.closePopup();
        }
    };

    this.genericalRequestError = (error) => {
        if (error.data.error) {
            ScreenService.showMessage(error.data.error);
        } else {
            ScreenService.showMessage(error);
        }
        ScreenService.hideLoader();
    };

    this.actCancelarAfsSelecionadas = function(autoForneArgs) {
        var cabecalhoWidget = autoForneArgs.owner.widget.container.getWidget('cabecalho');
        var autoFornWidget = autoForneArgs.owner.widget;
        limpaWidgetAutoForne(autoFornWidget, cabecalhoWidget);
        ScreenService.closePopup();
    };

    var applyZeroFillNumeroNota = function(cabecalhoWidget) {
        var filter =  [{"name": "CDFILIAL", "operator": "=", "value": cabecalhoWidget.currentRow.CDFILIRECE}],
            nrNotaFiscField = cabecalhoWidget.getField('NRNOTAFISC'),
            nrTamNumNfUt,
            quantCaracteres;
        
        General.callRestEngine("df#/crud/paramfilial", "FilterData", filter).then((success) => {
            if(success.dataset.paramfilial[0]) 
                nrTamNumNfUt = success.dataset.paramfilial[0].NRTAMNUMNFUTDFE;
            
            quantCaracteres = nrTamNumNfUt ? nrTamNumNfUt : 9;
            nrNotaFiscField.mask.params.maxlength = quantCaracteres;
            nrNotaFiscField.validations.maxLength.length = nrTamNumNfUt ? nrTamNumNfUt : 20;

            nrNotaFiscField.reload();
        });
    };

    var limpaOutDataChaveAcess = function(currentRow, outDataForneced = false) {
        currentRow.NRNOTAFISC  = null;
        currentRow.VRNOTAFISC  = 0;
        currentRow.NRACESSONFE = null;
        currentRow.CDSERIEENTR = null;
        currentRow.DSSERIEENTR = null;
        currentRow.DTEMISSAO   = null;

        currentRow.CDMODDOCFISC = null;
        currentRow.DSMODDOCFISC = null;
        currentRow.IDMODDOCNFE  = null;
        currentRow.IDOBRCHAVACES = 'N';
        
        if (outDataForneced)
            clearRowWithOutData(currentRow, outDataForneced);
    };

    const applyAccessKeyAccessibilityRules = (cabecalhoWidget, block) => {
        const dependentFields = [
                'NRNOTAFISC',  'CDSERIEENTR', 'NMRAZSOCCLIE',
                'NMRAZSOCFORN', 'DSFILIEMIT', 'DTEMISSAO', 'DSMODDOCFISC'
            ], applyRule = name => cabecalhoWidget.getField(name).readOnly = block;
        
        
        
        dependentFields.forEach(applyRule);
        
        //if(cabecalhoWidget.currentRow.IDGERNFIGUALXML == 'S') {
            cabecalhoWidget.getField('VRNOTAFISC').readOnly = block;
        //} 
        //else {
          //  cabecalhoWidget.getField('VRNOTAFISC').readOnly = false;
        //}
    };

    const applyInvalidAccessKeyRules = headerWidget => {
        const getWidget = headerWidget.container.getWidget,
            {currentRow} = headerWidget;

        if(currentRow.MANUAL_POSTING) delete currentRow.MANUAL_POSTING;

        limpaOutDataChaveAcess(currentRow, headerWidget.getField('NMRAZSOCFORN').outData);
        applyAccessKeyAccessibilityRules(headerWidget, false);
        limpaWidgetAutoForne(getWidget('autorizacaoFornecimento'), headerWidget);

        getWidget('relacionamentoItens').isVisible = false;
        return null;
    };
    
    const doNothing = (widget, vXML) =>{
        let a = widget;
        let b = vXML;
    };

    const processXMLData = (widget, XML) => {
        //Verificar se cdfilial foi digitada
        Dfe11000_LancamentoEntrada_Service.validaInscEstadual(widget.currentRow).then( () => {
            if (!XML.UTILIZADA) {
                const {currentRow} = widget;
        
                applyAccessKeyAccessibilityRules(widget, true);
                widget.container.getWidget('relacionamentoItens').isVisible = true;
                atualizouRelacionamento = false;
        
                const neededData = [
                        'VRNOTAFISC', 'CDSERIEENTR', 'CDSERIEENTR', 'NRNOTAFISC',
                        'DTEMISSAO', 'CDMODDOCFISC', 'DSMODDOCFISC', 'IDMODDOCNFE',
                        'NRPROTOCOLONFE', 'DTHRPROTOCOLNFE', 'CDCLIENTE'
                    ], copyData = name => currentRow[name] = XML[name];
        
                neededData.forEach(copyData);
                
                if(XML.NRINSJURTRANXML) {
                    var transportadora = [
                        {
                            "name": "P_NRINSJURTRAN",
                            "operator": "=",
                            "value": XML.NRINSJURTRANXML
                        }  
                    ];
                    General.callRestEngine("df#/crud/transport_municipio", "FilterData", transportadora).then((success) => {
                       if(success.dataset.transport_municipio[0]) {
                            currentRow.NRINSJURTRAN    = XML.NRINSJURTRANXML;
                            currentRow.NMRAZSOCTRAN    = success.dataset.transport_municipio[0].NMRAZSOCTRAN;
                            currentRow.NRINSJURTRAN    = success.dataset.transport_municipio[0].NRINSJURTRAN;
                            currentRow.DSENDETRAN      = success.dataset.transport_municipio[0].DSENDETRAN;
                            currentRow.NMMUNICIPIOTRAN = success.dataset.transport_municipio[0].NMMUNICIPIO;
                            currentRow.SGESTADOTRAN    = success.dataset.transport_municipio[0].SGESTADO;
                            currentRow.NRINSESTTRAN    = success.dataset.transport_municipio[0].NRINSESTTRAN;
                            currentRow.IDTPIJURTRAN    = success.dataset.transport_municipio[0].IDTPIJURTRAN;
                       } 
                    });
                }
                
                currentRow.CDIBGEDEST    = XML.CDIBGEDEST;
                currentRow.CDIBGEORIG    = XML.CDIBGEORIG;
                currentRow.CDTIPOCTE     = XML.CDTIPOCTE;
                currentRow.NRPLACAVEIC   = XML.NRPLACAVEICXML;
                currentRow.SGUFVEIC      = XML.SGUFVEICXML;
                currentRow.IDPGTOFRETE   = XML.IDPGTOFRETEXML;
                currentRow.DSQTDEVOLU    = XML.DSQTDEVOLUXML;
                currentRow.DSESPECVOLU   = XML.DSESPECVOLUXML;
                currentRow.DSMARCAVOLU   = XML.DSMARCAVOLUXML;
                currentRow.DSNUMEVOLU    = XML.DSNUMEVOLUXML;
                currentRow.VRPBRUTOVOLU  = XML.VRPBRUTOVOLUXML;
                currentRow.VRPLIQUVOLU   = XML.VRPLIQUVOLUXML;
                currentRow.CDCLIENTE     = XML.CDCLIENTE || '';
                currentRow.DTEMISSAO     = XML.DTEMISSAO;
                currentRow.IDOBRCHAVACES = XML.IDOBRCHAVACESFO;
                
                currentRow.NRNOTAFISC = currentRow.NRNOTAFISC.padStart(currentRow.NRTAMNUMNFUTDFE, '0');
                currentRow.NRACESSONFE = XML.NRACESSONFE;
        
                setCurrentRowWithOutData(currentRow, XML, widget.getField('NMRAZSOCFORN').outData);
        
                if (isAFRequired(currentRow, true) && importOnlyAFProducts(currentRow)) {
                    if(!currentRow.AF) {
                        showAFMessageAndOpenPopup(widget);
                    }
                }
        
                validaCampoAF(widget, true);
                validaChaveAcessoObrigatoria(widget);
                this.modeloDeDocumentoOnChange('', widget);
            } else if(XML.IDSTATUS == 'L'){
                widget.view();
                General.changeWidgetAcessibility(widget.widgets, true);
                
                let filter = Util.clone(widget.dataSourceFilter);
                filter = filter.filter( filtro => (filtro.name == "CDFILIRECE" || filtro.name == "CDEMPRESA"));
                filter.push(
                    {
                        "name": "NRACESSONFE",
                        "operator": "=",
                        "value": XML.NRACESSONFE
                    }
                );
                General.callRestEngine("df_entrada#/crud/notafiscal_entrada", "FilterData", filter).then(success => {
                    if(success.dataset.notafiscal_entrada[0]){
                        widget.currentRow = success.dataset.notafiscal_entrada[0];
                        setCurrentRowWithOutData(widget.currentRow, XML, widget.getField('NMRAZSOCFORN').outData);
                        this.validacoesNotaAfterMoveRow(undefined, widget);
                    }
                });
                this.modeloDeDocumentoOnChange('', widget);
            } else{
                widget.currentRow.NRACESSONFE = null;
                return showMessageDfe('CHAVE_ACESSO_UTILIZADA');
            }
        }).catch( error => {
            widget.currentRow.NRACESSONFE = null;
            requestError(error);
        });
    };
    
    const applyManualPostingWithAccessKeyRules = widget => {
        widget.currentRow.MANUAL_POSTING = true;
        limpaOutDataChaveAcess(widget.currentRow, widget.getField('NMRAZSOCFORN').outData);
        applyAccessKeyAccessibilityRules(widget, false);
        //limpaWidgetAutoForne(widget.container.getWidget('autorizacaoFornecimento'), widget);
    };

    const suggestManualIncomingPosting = widget => MessageService.confirmMessageByCode(
        'PERMITE_LANCAMENTO_MANUAL', null,
        {
            type: MESSAGES.PERMITE_LANCAMENTO_MANUAL.type,
            success: applyManualPostingWithAccessKeyRules.bind(this, widget),
            fail: applyInvalidAccessKeyRules.bind(this, widget)
        }
    );

    const invalidAccessKey = widget => applyInvalidAccessKeyRules(widget) || showMessageDfe('CHAVE_ACESSO_INVALIDA');

    const XMLNotFound = widget =>  {
        var filter = [
            {
                "name": "CDFORNECED",
                "operator": "=",
                "value": 'J' + widget.currentRow.NRACESSONFE.substr(6, 14)
            }  
        ];
        General.callRestEngine("df#/crud/paramforne_fornecedor", "FilterData", filter).then((fornecedor) => {
            if(fornecedor.dataset.paramforne_fornecedor[0]) {
                if(fornecedor.dataset.paramforne_fornecedor[0].IDOBRIMPXMLNF != 'S') {
                    suggestManualIncomingPosting(widget);
                }
                else {
                    invalidAccessKey(widget);
                }
            }
            else {
                invalidAccessKey(widget);
            }
        });
    };
    
    const fetchIncomingByAccessKey = (widget, ACCESS_KEY) => Dfe11000_LancamentoEntrada_Service.buscaChaveAcesso(ACCESS_KEY)
        .then(response => response.dataset.intg_notafiscal_lancamento)
        .then(([XML = false]) => (XML? processXMLData : XMLNotFound)(widget, XML));
        
    const fetchAccessKeyByOtherFields = (widget, params) => Dfe11000_LancamentoEntrada_Service.buscaChaveAcessoPorCampos(params)
        .then(response => response.dataset.intg_notafiscal_lancamento_campos)

        .then(([XML = false]) => {
            if(XML) {
                widget.currentRow.NRACESSONFE = XML.NRACESSONFE;
                processXMLData(widget, XML);
            }
            else {
                doNothing(widget, XML);
            }
        });
        
    this.accessKeyOnBlur = ({owner: {field}}) => {
        const ACCESS_KEY = field.value() || false;
        let {widget} = field;
        let ACCESS_KEY_NOMASK = '';
        
        if (ACCESS_KEY.length >= 44) {
            ACCESS_KEY_NOMASK = ACCESS_KEY.replace(/[^\d]+/g, "");
            
            if(!field.mask) {
                field.mask = {
                    type: 'fix',
                            params: {
                                mask: '9999.9999.9999.9999.9999.9999.9999.9999.9999.9999.9999'
                            }
                };
                field.widget.redraw();
            }
        }
        else {
            ACCESS_KEY_NOMASK = ACCESS_KEY;
            if(field.mask) {
                delete field.mask;
                field.widget.redraw();
            }
        }
        
        if (ACCESS_KEY){
            let filter_nf = [
                {
                    "name": "NRACESSONFE",
                    "operator": "=",
                    "value": ACCESS_KEY_NOMASK
                }
            ];
            
            General.callRestEngine("df#/crud/intg_notafiscal", "FilterData", filter_nf).then(function(notafiscal){
                if (notafiscal.dataset.intg_notafiscal[0]){
                    let cdforneced = notafiscal.dataset.intg_notafiscal[0].CDFORNECED;
                    
                    let filter_end = [
                        {
                            "name": "CDFORNECED",
                            "operator": "=",
                            "value": cdforneced
                        }
                    ];
                    
                    General.callRestEngine("df#/crud/endeforn", "FilterData", filter_end).then(function(endeforneced){
                        if(endeforneced.dataset.endeforn[0]){
                            return fetchIncomingByAccessKey(widget, ACCESS_KEY_NOMASK);
                        } else {
                            return MessageService.showMessageByCode('FORNECEDOR_SEM_ENDERECO');
                        }
                    }, function(callback) {
                        return MessageService.showMessageByCode('FALHA_CONSULTA_BANCO');
                    });
                    
                } else {
                    field.setValue(null);
                    return MessageService.showMessageByCode('CHAVE_ACESSO_INVALIDA');
                }
            }, function(callback) {
                return MessageService.showMessageByCode('FALHA_CONSULTA_BANCO');
            });
        } else {
            return applyInvalidAccessKeyRules(widget);
            
        }
    };

    const showAFMessageAndOpenPopup = widget => {
        const data = MESSAGES.AF_OBRIGATORIA,
            field = widget.getField('CBUTILIZAAF'),
            openAFPopup = () => {
                widget.currentRow.CBUTILIZAAF = 'S';
                widget.currentRow.DSUTILIZAAF = 'Realizar importação Af';

                field.value('S');
                this.abreImportacaoAF(field);
            };

        MessageService.showMessageByCode('AF_OBRIGATORIA', null, data).then(openAFPopup);
    };

    /* ************************* Lancamento Entrada - Itens ********************************* */

    var somaValorTotalItens = function(itensWidget) {
        var dataSourceItem = itensWidget.dataSource.data,
            valorTotal = Df11000_Lancamento_Service.somaTotalItens(dataSourceItem);
            
        return valorTotal;
    };

    const validaEdicaoImportacaoXml =lancamentoItemWidget => {
        const parentWidgetCurrentRow = lancamentoItemWidget.getParent().currentRow,
            importadoViaXml = parentWidgetCurrentRow.IDNFGERADAVIAXML === 'S',
            importacaoIdenticaXml = parentWidgetCurrentRow.IDGERNFIGUALXML === 'S',
            changeEventQuantidade = importadoViaXml ? 'calculaValorUnitario(true);' : 'quantidadeFieldOnChange(args);';
        
        lancamentoItemWidget.getField('QTITEMPROD').events[0].code = `Dfe11000_LancamentoEntrada_Controller.${changeEventQuantidade}`;

        ['VRUNITITEM', 'VRTOTAITEM', 'VRDESCITEM'].forEach(name =>
            lancamentoItemWidget.getField(name).readOnlyOnEdit = importadoViaXml);
    };

    this.actNovoItemOnClick = function(lancamentoItemArgs) {
        lancamentoItemArgs.owner.widget.newRow();
        
        Df11000_Lancamento_Service.getProxSeqItens().then(nrseqitprod => {
            lancamentoItemArgs.owner.widget.currentRow.NRSEQITPROD = nrseqitprod;
            controlaStatusWidgets(lancamentoItemArgs.owner.widget, lancamentoItemArgs.owner.widget.name, false);
        });
    };

    this.actEditarItemOnClick = function(lancamentoItemArgs) {
        var lancamentoItemWidget = lancamentoItemArgs.owner.widget;
        var lancamentoItemRow = lancamentoItemArgs.row;
        
        if(lancamentoItemRow.hasOwnProperty('__rightActions') || lancamentoItemRow.hasOwnProperty('__leftActions')){
            delete lancamentoItemRow.__rightActions;
            delete lancamentoItemRow.__leftActions;
        }
        General.edit(lancamentoItemWidget);
        validaEdicaoImportacaoXml(lancamentoItemWidget);
        validaEdicaoItemNotaOrigem(lancamentoItemWidget);
        controlaStatusWidgets(lancamentoItemWidget, lancamentoItemWidget.name, false);
    };

    var validaEdicaoItemNotaOrigem = function(itensWidget) {
        var qtFieldOrig = itensWidget.getField('QTITEMORIG'),
            qtField = itensWidget.getField('QTITEMPROD');

        if (itensWidget.getParent().currentRow.IDOPERDEVONF == 'S') {
            qtFieldOrig.isVisible = true;
            qtField.validations.max = {value: itensWidget.currentRow.QTITEMORIG};
        } else {
            qtFieldOrig.isVisible = false;
            delete qtField.validations.max;
        }
    };

    this.actCancelarItemOnClick = function(lancamentoItemArgs)  {
        var lancamentoItemWidget = lancamentoItemArgs.owner.widget;
        
        controlaStatusWidgets(lancamentoItemWidget.getParent(), lancamentoItemWidget.name, true);
        backStatusModify();

        if (lancamentoItemWidget.inlineEditing || lancamentoItemWidget.getField('QTITEMPROD').inlineEditable) {
            lancamentoItemWidget.list();
            fieldItensInlineEditable(lancamentoItemWidget, false);

            //TODO alterar para remover os itens manualmente e executar o calculo do valor total
            lancamentoItemWidget.reload();

            delete lancamentoItemWidget.inlineEditing;
            return lancamentoItemWidget.rollbackInlineEdit();
        }
        
        return General.backOrCancel(lancamentoItemArgs);
    };

    var calculaImpostoItemProduto = function(widgetParentRow, lancamentoItemRow) {
        if(lancamentoItemRow) {
            
            if(lancamentoItemRow.hasOwnProperty('__rightActions') || lancamentoItemRow.hasOwnProperty('__leftActions')){
                delete lancamentoItemRow.__rightActions;
                delete lancamentoItemRow.__leftActions;
            }
            return Dfe11000_LancamentoEntrada_Service.calculaImpostoItemProduto(widgetParentRow, lancamentoItemRow).then(function(calculoImpostoProduto) {
                var impostosTemp = calculoImpostoProduto.dataset.calculoImpostoProduto;
    
                impostosTemp = Object.keys(impostosTemp).map(key => impostosTemp[key]);
    
                impostosTemp.forEach(imposto => {
                    imposto.CDIMPOSTO = imposto.CDIMPOTEMP;
                    imposto.VRALIQUTMP = imposto.VRALIQUTMP;
    
                    imposto.CDFILIAL = this.CDFILIAL;
                    imposto.NRLANCTONF = this.NRLANCTONF;
                    imposto.NRSEQITPROD = this.NRSEQITPROD;
                    imposto.__is_new = false;
    
                    delete imposto.CDIMPOTEMP;
                });
    
                Df11000_Lancamento_Service.setDataSourceItensImpostos(impostosTemp);
            }.bind(lancamentoItemRow));
        }
    };

    this.actIncluirItemOnClick = function(lancamentoItemArgs) {
        Df11000_Lancamento_Service.getStatusNota(lancamentoItemArgs.owner.widget.getParent().currentRow).then(salvaNota => {
            if(salvaNota) {
                var lancamentoItemWidget = lancamentoItemArgs.owner.widget;
                var cabecalhoRow = lancamentoItemWidget.getParent().currentRow;
                var validacoes = processaValidacoesNotaOrigem(templateManager.container.getWidget("cabecalho").currentRow);
                
                if(validacoes.devolucao) 
                    this.chamaDadosAdicionais(lancamentoItemArgs);
                
                if (lancamentoItemWidget.getField('QTITEMPROD').inlineEditable) {
                    return this.actSalvarMultiItemOnClick(lancamentoItemArgs); //Widget em modo de edição de múltiplos itens.
                }
                if (!lancamentoItemWidget.isValid())
                    return lancamentoItemWidget.e.preventDefault();
        
                var lancamentoItemRow = lancamentoItemArgs.row;
                var widgetParentRow = lancamentoItemArgs.owner.widget.getParent().currentRow;
                const values = getCorrectsValues(lancamentoItemWidget);
                if(lancamentoItemRow.hasOwnProperty('__rightActions') || lancamentoItemRow.hasOwnProperty('__leftActions')){
                    delete lancamentoItemRow.__rightActions;
                    delete lancamentoItemRow.__leftActions;
                }
        
                lancamentoItemRow.NRLANCTONF = lancamentoItemRow.NRLANCTONF || widgetParentRow.NRLANCTONF;
                lancamentoItemRow.CDFILIAL = lancamentoItemRow.CDFILIAL || widgetParentRow.CDFILIAL;
                lancamentoItemRow.CDFILIMOVI = widgetParentRow.CDFILIRECE || lancamentoItemRow.CDFILIAL;
                lancamentoItemRow.QTITEMPROD = values.QTITEMPROD;
        
                lancamentoItemRow.VRUNITITEM = values.VRUNITITEM;
                lancamentoItemRow.VRTOTAITEM = values.VRTOTAITEM;
                lancamentoItemRow.VRDESCITEM = values.VRDESCITEM;
        
                Dfe11000_LancamentoEntrada_Service.validaParamProduto(lancamentoItemRow.CDFILIAL, lancamentoItemRow.CDARVPROD).then(function(response){
                    var idbloqnfsaf = response.dataset.validaParamProduto[0].IDBLOQNFSAF == 'S' ? true : false;
                    if(idbloqnfsaf){
                        ScreenService.showMessage("Esse produto não está vinculado a uma AF.");
                    } else{
                        Df11000_Lancamento_Service.salvaItem(widgetParentRow, lancamentoItemRow).then(() => {
                            lancamentoItemRow.__generate_taxes = lancamentoItemRow.__is_new;
                            alteraStatusNotafiscal(lancamentoItemWidget.getParent()).then(() => {
                                if(cabecalhoRow.IDNFGERADAVIAXML != 'S') {
                                    if(cabecalhoRow.hasOwnProperty('__rightActions') || cabecalhoRow.hasOwnProperty('__leftActions')){
                                        delete cabecalhoRow.__rightActions;
                                        delete cabecalhoRow.__leftActions;
                                    }
                                    calculaImpostoItemProduto(widgetParentRow, lancamentoItemRow);
                                }
                                templateManager.container.getWidget("impostosItem").fields[2].inlineEditable = "number";
                                templateManager.container.getWidget("impostosItem").fields[3].inlineEditable = "number";
                            });
                            if(lancamentoItemRow.__is_new == false && lancamentoItemRow.NRAUTOFORN) {
                                lancamentoItemRow.OLDQTITEMPROD = lancamentoItemWidget.backupRow.QTITEMPROD;
                                Dfe11000_LancamentoEntrada_Service.atualizaItemAf(lancamentoItemRow);
                            }
                
                            lancamentoItemRow.__is_new = false;
                            Df11000_Lancamento_Service.setDataSourceItem(lancamentoItemRow)
                                .then(Df11000_Lancamento_Service.atualizaLancamento)
                                .then(() => {
                                    Df11000_Lancamento_Service.setDataSourceLancamentoNota();
                                    validaEdicaoItemNotaOrigem(lancamentoItemWidget);
                                    lancamentoItemWidget.view();
                                    controlaStatusWidgets(lancamentoItemWidget, lancamentoItemWidget.name, true);
                                    backStatusModify();
                                    if(lancamentoItemRow.hasOwnProperty('__rightActions') || lancamentoItemRow.hasOwnProperty('__leftActions')){
                                        delete lancamentoItemRow.__rightActions;
                                        delete lancamentoItemRow.__leftActions;
                                    }
                                });
                        }, error => {
                            if (Array.isArray(error)) {
                                var stringCamposObrig = error.join(', ');
                                var mensagem = 'Os campos %1 deve(m) ser maior que zero.'.replace('%1', stringCamposObrig);
                                return ScreenService.showMessage(mensagem);
                            } else if (typeof error === 'string')
                                return ScreenService.showMessage(error);
                            return ScreenService.showMessage(error.data.error);
                        });
                    }
                });
            }
            else MessageService.showMessageByCode('BLOCK_NOTE');
        }, requestError);
    };
    
   this.validaOnTab = function(lancamentoItemArgs) {
    console.log(lancamentoItemArgs);
    if(lancamentoItemArgs.e.keyCode===9||lancamentoItemArgs.e.keyCode===13){
    lancamentoItemArgs.e.stopPropagation();
    
         }
    };

    this.actSalvarMultiItemOnClick = function(lancamentoItemArgs) {

        Df11000_Lancamento_Service.getStatusNota(lancamentoItemArgs.owner.widget.getParent().currentRow).then(salvaNota => {
            if(salvaNota) {
                var lancamentoItemWidget = lancamentoItemArgs.owner.widget;
                var itens = lancamentoItemWidget.dataSource.data;
                var parentWidget = lancamentoItemWidget.getParent();
                var currentRowParentWidget = Util.clone(parentWidget.currentRow, ["__rightActions", "__leftActions"]);
        
                var isInvalid = itens.some(item => !item.QTITEMPROD || !item.VRUNITITEM || !item.VRTOTAITEM);
        
                if (isInvalid) {
                    return ScreenService.showMessage('Campos obrigatórios não preenchidos.');
                }
                
        
                var novosItens = itens.filter(item => item.__is_new);
                novosItens.forEach(item => {
                    delete(item.__rightActions); 
                    delete(item.__leftActions);
                });
                var itensAlterados = itens.filter(item => item.changed && !item.__is_new);
                itensAlterados.forEach(item => {
                    delete(item.__rightActions); 
                    delete(item.__leftActions);
                });
        
                //TODO validar campos obrigatórios igual a 0
                Dfe11000_LancamentoEntrada_Service.salvaMultiItens(novosItens, itensAlterados, currentRowParentWidget)
                    .then(calculoImpostosProdutos => {
                        var impostos = calculoImpostosProdutos.dataset.impostosTemp;
        
                        impostos.forEach(imposto => {
                            imposto = Object.keys(imposto).map(key => imposto[key]);
                            imposto.forEach(impos => {
                                impos.CDIMPOSTO = impos.CDIMPOTEMP;
                                impos.__is_new = false;
        
                                delete impos.CDIMPOTEMP;
                            });
                            Df11000_Lancamento_Service.setDataSourceItensImpostos(imposto);
                        });
        
                        itens.forEach(item => {
                            item.__is_new = false;
                            //@todo remover delete item.changed quando desmarcaLinhasEditadas for implementada
                            delete item.changed_QTITEMPROD;
                            delete item.changed_VRUNITITEM;
                            delete item.changed_VRTOTAITEM;
                            delete item.changed_VRDESCITEM;
                            delete item.changed;
                        });
        
                        Df11000_Lancamento_Service.setDataSourceItem(itens).then(function () {
                                setTimeout(Df11000_Lancamento_Service.atualizaLancamento, 500);
                            });
        
                        alteraStatusNotafiscal(parentWidget).then(() => {
                            controlaStatusWidgets(parentWidget, lancamentoItemWidget.name, true, lancamentoItemWidget.widgets);
                            controlaStatusWidgets(lancamentoItemWidget, lancamentoItemWidget.name, true);
                            fieldItensInlineEditable(lancamentoItemWidget, false);
                            delete lancamentoItemWidget.inlineEditing;
                        });
                        lancamentoItemWidget.list();
                    })
                    .catch(requestError);
            }
            else MessageService.showMessageByCode('BLOCK_NOTE');
        }, requestError);
    };

    this.actExcluirItemOnClick = function(lancamentoItemArgs) {
        ScreenService.confirmMessage(
            ScreenService.i18n('Excluir Registro?'),
            'question', () => Df11000_Lancamento_Service.getStatusNota(lancamentoItemArgs.owner.widget.getParent().currentRow).then(salvaNota => {
                if(salvaNota) {
                    const {owner: {widget}, row} = lancamentoItemArgs;
    
                    Df11000_Lancamento_Service.excluiItem(row)
                        .then(() => alteraStatusNotafiscal(widget.getParent()))
                        .then(() => Df11000_Lancamento_Service.excluiItemDataSource(row.NRSEQITPROD))
                        .then(Df11000_Lancamento_Service.atualizaLancamento)
                        .then(() => {
                            if(row.NRAUTOFORN) {
                                Dfe11000_LancamentoEntrada_Service.excluirItemAf(row);
                            }
                            Df11000_Lancamento_Service.setDataSourceLancamentoNota();
                            General.backOrCancel(lancamentoItemArgs);
                            widget.reload();
                            widget.activate();
                        });
                }
                else MessageService.showMessageByCode('BLOCK_NOTE');
            }, requestError)
        );
    };

    this.nivelCompletoProduto = function() {
        return General.getLevelByMask('GER_CDPICTPROD','1').length;
    };

    var setValoresEmissaoProdutoOnChange = function(lancamentoItemRow) {
        lancamentoItemRow.CDPRODEMIS = lancamentoItemRow.CDARVPROD;
        lancamentoItemRow.DSPRODEMIS = lancamentoItemRow.NMPRODUTO;
    };
    
    var informacoesComplementaresProduto = function(lancamentoItemArgs){
        var widgetParentRow;
        if (lancamentoItemArgs.owner.owner == undefined){
            widgetParentRow = lancamentoItemArgs.owner.getParent().getParent().currentRow;
        }else{
            widgetParentRow = lancamentoItemArgs.owner.owner.getParent().getParent().currentRow;
            
        }
        lancamentoItemArgs.row.CDFILIMOVI = widgetParentRow.CDFILIRECE;
        lancamentoItemArgs.row.CDFILIAL = widgetParentRow.CDFILIAL;
        
        lancamentoItemArgs.row.IDENTRSAIDOP = widgetParentRow.IDENTRSAIDOP;
        lancamentoItemArgs.row.CDTIPOOPER = widgetParentRow.CDTIPOOPER;
        
        var row = {
            IDENTRSAIDOP:lancamentoItemArgs.row.IDENTRSAIDOP,
            CDTIPOOPER:lancamentoItemArgs.row.CDTIPOOPER
        };
        
        General.callRestEngine("df_entrada#/getIDATUESTTPOP", "Row", row).then((success) => {
          atualizaEstoque = success.dataset.atualizaEstoque.IDATUESTTPOP;
           
            if((sitSugAlmox == true )){
              lancamentoItemArgs.row.CDALMOXARIFE = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDALMOXARIFE').value();
              lancamentoItemArgs.row.CDLOCALESTOQ = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDLOCALESTOQ').value();
            }else{
                Lib00206_InfComplProduto_Controller.infComplementares(templateManager.container.getWidget('itens'), lancamentoItemArgs.row, false, atualizaEstoque);        
            }
            //if(!templateManager.container.getWidget('WidgetSugereAlmox') && (lancamentoItemArgs.row.__is_new == true )){
              
              //}
          });
          
           //if(!templateManager.container.getWidget('WidgetSugereAlmox')){
        //   Lib00206_InfComplProduto_Controller.infComplementares(lancamentoItemArgs.owner.field.widget, lancamentoItemArgs.row, false, atualizaEstoque);
           //}    
        //});
        
    };
    
    this.validacoesProdutoOnChange = function(lancamentoItemArgs) {
        setValoresEmissaoProdutoOnChange(lancamentoItemArgs.row);
        informacoesComplementaresProduto(lancamentoItemArgs);
    };

    var calculaValorTotal = function(lancamentoItemArgs) {
        const widget = lancamentoItemArgs.owner.field.widget;
        var values = {};
    
        if (widget.inlineEditing) {
            values.QTITEMPROD = lancamentoItemArgs.row.QTITEMPROD_inline ? lancamentoItemArgs.row.QTITEMPROD_inline : lancamentoItemArgs.row.QTITEMPROD;
            values.VRUNITITEM = lancamentoItemArgs.row.VRUNITITEM_inline ? lancamentoItemArgs.row.VRUNITITEM_inline : lancamentoItemArgs.row.VRUNITITEM;

        } else {
            values = getCorrectsValues(widget);
        }
        
        widget.getField('VRTOTAITEM').value(Df11000_Lancamento_Service.calculaValorTotal(
            values.QTITEMPROD, values.VRUNITITEM
        )); 
        
        widget.currentRow.VRTOTAITEM_inline = widget.getField('VRTOTAITEM').value();
        
    };

    this.valorUnitarioFieldOnChange = function(lancamentoItemArgs) {
        var widget = lancamentoItemArgs.owner.field.widget;
        lancamentoItemArgs.owner.field.modify = true;
        widget.getField('VRTOTAITEM').modify = true;
        calculaValorTotal(lancamentoItemArgs);
    };

    this.quantidadeFieldOnChange = function(lancamentoItemArgs) {
        var widget = lancamentoItemArgs.owner.field.widget;
        lancamentoItemArgs.owner.field.modify = true;
        widget.getField('VRTOTAITEM').modify = true;
        calculaValorTotal(lancamentoItemArgs);
      
        };

    this.calculaValorUnitario = function(changeField) {
        const widget = templateManager.container.getWidget('itens');
        
        var values = {};
        var lancamentoItemCurrentRow = widget.currentRow;

        if (changeField) {
            widget.getField('QTITEMPROD').modify = true;
            widget.getField('VRUNITITEM').modify = true;
        }

        if (widget.inlineEditing) {
            values.QTITEMPROD = lancamentoItemCurrentRow.QTITEMPROD_inline ? lancamentoItemCurrentRow.QTITEMPROD_inline : lancamentoItemCurrentRow.QTITEMPROD;
            values.VRTOTAITEM = lancamentoItemCurrentRow.VRTOTAITEM_inline ? lancamentoItemCurrentRow.VRTOTAITEM_inline : lancamentoItemCurrentRow.VRTOTAITEM;
            
        } else {
            values = getCorrectsValues(widget);
        }
        
        lancamentoItemCurrentRow.VRUNITITEM = Df11000_Lancamento_Service.calculaValorUnitario(
            values.QTITEMPROD, values.VRTOTAITEM
        );

    };

    this.valorTotalFieldOnChange = function(lancamentoItemArgs) {
        lancamentoItemArgs.owner.field.modify = true;
        lancamentoItemArgs.owner.field.widget.getField('VRUNITITEM').modify = true;
        this.calculaValorUnitario(false);
    };
    
    this.validateActionsWidgetOnEnter = function(lancamentoItemArgs) {
        var lancamentoItemWidget = lancamentoItemArgs.owner,
            parentCurrentRow = lancamentoItemWidget.getParent().currentRow,
            importadoViaXml = parentCurrentRow.IDNFGERADAVIAXML === 'S',
            importacaoIdenticaXml = parentCurrentRow.IDGERNFIGUALXML === 'S',
            notaIgualXml = importacaoIdenticaXml && importadoViaXml,
            statusNota = parentCurrentRow.IDSTATUS,
            disableActionNotaIgualXml = !notaIgualXml && (statusNota === 'D' || statusNota === 'P'),
            disableActionNotaDevolucao = (parentCurrentRow.IDOPERDEVONF == 'N' || parentCurrentRow.CDTIPOOPER == 3),
            disableActionEdicao = (parentCurrentRow.IDSTATUSNFE === 'R' || parentCurrentRow.IDSTATUSNFE === 'P' || parentCurrentRow.IDSTATUSNFE === undefined) && (statusNota === 'D' || statusNota === 'P'),
            isTipo10 = (parentCurrentRow.CDTIPOOPER != '10'),
            tipooper = parentCurrentRow.CDTIPOOPER,
            itnotafisc = parentCurrentRow.itnotafisc;

        lancamentoItemWidget.getAction('actNovoItem').isVisible = (disableActionNotaIgualXml && disableActionNotaDevolucao);
        lancamentoItemWidget.getAction('actExcluirItem').isVisible = (disableActionNotaIgualXml );
        lancamentoItemWidget.getAction('actEditarItem').isVisible = (disableActionEdicao);
        
        if(parentCurrentRow.IDNFGERADAVIAXML === 'S'){
            lancamentoItemWidget.getAction('actNovoItem').isVisible = false;
            lancamentoItemWidget.getAction('actExcluirItem').isVisible = false;
        }

        var saveAction = lancamentoItemWidget.getAction('save');
        if (saveAction) {
            saveAction.isVisible = false;
        }

        fieldItensInlineEditable(lancamentoItemWidget, false);
        
        lancamentoItemWidget.container.getWidget('impostosItem').enabled = isTipo10;
        lancamentoItemWidget.container.getWidget('detComb').enabled = true;
    };
    
    this.verificaTipoLancamento = function() {
        if(templateManager.container.getWidget("cabecalho").currentRow.IDNFGERADAVIAXML === 'S'){
            templateManager.container.getWidget("cabecalho").getField('VRNOTAFISC').readOnly = true;  
        }else{
            templateManager.container.getWidget("cabecalho").getField('VRNOTAFISC').readOnly = false; 
        }
    };

    this.after = function(lancamentoItemArgs) {
        var produtoField = lancamentoItemArgs.owner.field;
        var produtoFieldWidget = produtoField.selectWidget;
        produtoFieldWidget.unSelectAll();

        if (!produtoFieldWidget.getAction('confirmarProdutos')) {
            produtoFieldWidget.showCheckbox = true;

            var actionConfirmarProdutos = {
                name: 'confirmarProdutos',
                label: 'Confirmar',
                showAsAction: 'never_list',
                isVisible: true,
                showOnList: true,
                events: [{
                    name: 'ActionEvent',
                    code: 'Dfe11000_LancamentoEntrada_Controller.confirmarSelecaoProdutos(args);',
                }]
            };
            actionConfirmarProdutos = metaDataFactory.actionFactory(actionConfirmarProdutos);
            actionConfirmarProdutos.widget = produtoFieldWidget;
            produtoFieldWidget.actions.push(actionConfirmarProdutos);

            eventEngine.unbindEvent(produtoFieldWidget, 'WidgetAfterMoveRow', 0);
            eventEngine.bindEvent(produtoFieldWidget, 'WidgetAfterMoveRow', 'args.owner.toggle(args.owner.currentRow);');

            templateManager.updateTemplate();
        }
    };

    var fieldItensInlineEditable = function(itensWidget, isInlineEditable) {
        if (isInlineEditable) {
            itensWidget.getField('QTITEMPROD').inlineEditable = 'number';
            itensWidget.getField('VRUNITITEM').inlineEditable = 'number';
            itensWidget.getField('VRTOTAITEM').inlineEditable = 'number';
            itensWidget.getField('VRDESCITEM').inlineEditable = 'number';
        } else {
            delete itensWidget.getField('QTITEMPROD').inlineEditable;
            delete itensWidget.getField('VRUNITITEM').inlineEditable;
            delete itensWidget.getField('VRTOTAITEM').inlineEditable;
            delete itensWidget.getField('VRDESCITEM').inlineEditable;
        }
        templateManager.updateTemplate();
    };

    this.confirmarSelecaoProdutos = function(args) {
        var fieldProdutoWidget = args.owner.widget;
        var fieldProduto = fieldProdutoWidget.selectField;
        var itensWidget = fieldProduto.widget;
        var selectedRows = fieldProdutoWidget.getCheckedRows();
        var multiItens = selectedRows.length !== 1;
        var ignoredPropertyes = ['__rightActions', '__leftActions'];

        itensWidget.insertMultipleLines = true;
        //itensWidget.getAction('actSalvarMultiItem').isVisible = multiItens;
        //itensWidget.getAction('actSalvarItem').isVisible = !multiItens;

        if (!multiItens) {
            args.owner = fieldProdutoWidget;
            args.row = args.selectedRow;
            fieldProdutoWidget.setSelected(args);
            itensWidget.insertMultipleLines = false;
            fieldItensInlineEditable(itensWidget, false);
            return args;
        }

        var parentWidget = itensWidget.getParent();
        var emptyRow = Util.clone(itensWidget.currentRow, ignoredPropertyes);
        var indexNumberRow = emptyRow.__index;
        var seqItens = emptyRow.NRSEQITPROD;
        
        itensWidget.dataSource.data.splice(itensWidget.currentRow.__index, 1);

        selectedRows.forEach(selectedItem => {
            var newRegister = Util.clone(emptyRow, ignoredPropertyes);

            setCurrentRowWithOutData(newRegister, selectedItem, fieldProduto.outData);
            setValoresEmissaoProdutoOnChange(newRegister);

            newRegister.__index = ++indexNumberRow;
            newRegister.NRSEQITPROD = '0000'.substring(0, 4 - seqItens.length) + seqItens;

            newRegister.NRLANCTONF = newRegister.NRLANCTONF || parentWidget.currentRow.NRLANCTONF;
            newRegister.CDFILIAL   = newRegister.CDFILIAL || parentWidget.currentRow.CDFILIAL;
            newRegister.CDFILIMOVI = newRegister.CDFILIAL;
            newRegister.__rightActions = itensWidget.currentRow.__rightActions;
            newRegister.__leftActions = itensWidget.currentRow.__leftActions;
            
            itensWidget.dataSource.data.push(newRegister);
            seqItens = (++seqItens).toString();
        });

        //itensWidget.inlineEditing = true; aparentemente não tem necessidade de setar editing como true, incluisive isto causa erros ao adicionar as rows.
        fieldItensInlineEditable(itensWidget, true);

        ScreenService.closePopup();
        ScreenService.closeSwipe();

        controlaStatusWidgets(itensWidget.getParent(), itensWidget.name, false, itensWidget.widgets);

        itensWidget.edit();
        templateManager.updateTemplate();
    };

    const getCorrectsValues = widget => {
        const currentRow = widget.currentRow;
        const auxRow = widget.backupRow;

        const qtIsModify = widget.getField('QTITEMPROD').modify;
        const vrUniIsModify = widget.getField('VRUNITITEM').modify;
        const totUniIsModify = widget.getField('VRTOTAITEM').modify;
        const descUniIsModify = widget.getField('VRDESCITEM').modify;

        const back = {
            'QTITEMPROD': qtIsModify || currentRow.__is_new ? currentRow.QTITEMPROD : auxRow.QTITEMPROD,
            'VRUNITITEM': vrUniIsModify || currentRow.__is_new ? currentRow.VRUNITITEM : auxRow.VRUNITITEM,
            'VRTOTAITEM': totUniIsModify || currentRow.__is_new ? currentRow.VRTOTAITEM : auxRow.VRTOTAITEM,
            'VRDESCITEM': descUniIsModify || currentRow.__is_new ? currentRow.VRDESCITEM : auxRow.VRDESCITEM
        };

        return back;
    };

    const backStatusModify = () => {
        const widget = templateManager.container.getWidget('itens');
        widget.getField('QTITEMPROD').modify = false;
        widget.getField('VRUNITITEM').modify = false;
        widget.getField('VRTOTAITEM').modify = false;
        widget.getField('VRDESCITEM').modify = false;
    };

    /* *********************** Lancamento Entrada - Imposto Item ****************************** */
    this.actSalvaImpostosItemWidgetOnSaveInlineEdit = function(impostosItemArgs) {
        Df11000_Lancamento_Service.getStatusNota(getCabecalhoWidget().currentRow).then(salvaNota => {
            if(salvaNota) {
                var impostosItemWidget = impostosItemArgs.owner,
                    statusNota = impostosItemArgs.owner.getParent().getParent().currentRow.IDSTATUS;
                    
                const data = impostosItemWidget.dataSource.data,
                      camposAlterados = data.filter(row => (!!('changed_VRIMPOSTOIT' in row) || !!('changed_VRALIQIMPOIT' in row)));
                
                camposAlterados.forEach((row) => {
                    if((row.changed_VRIMPOSTOIT || row.changed_VRIMPOSTOIT === 0)  && !row.changed_VRALIQIMPOIT) {
                        row.VRALIQIMPOIT = (row.VRIMPOSTOIT / impostosItemWidget.getParent().currentRow.VRTOTAITEM) * 100;
                    }
                    else if((row.changed_VRALIQIMPOIT || row.changed_VRALIQIMPOIT === 0)&& !row.changed_VRIMPOSTOIT) {
                        row.VRIMPOSTOIT = (row.VRALIQIMPOIT * impostosItemWidget.getParent().currentRow.VRTOTAITEM) / 100;   
                    }
                });
                
                const salvaImpostosTmpItem = () =>
                    Df11000_Lancamento_Service.salvaImpostosTmpItem(camposAlterados)
                        .then(() => {
                            Df11000_Lancamento_Service.setDataSourceItensImpostos(data)
                            .then(()=> Df11000_Lancamento_Service.atualizaLancamento());
                            removeEdicaoLinhasWidget(camposAlterados);
                            impostosItemWidget.list();
                        })
                        .catch(requestError);
                        
                const salvaImpostosItem = () =>
                    Df11000_Lancamento_Service.salvaImpostosItem(camposAlterados)
                        .then(() => {
                            Df11000_Lancamento_Service.setDataSourceItensImpostos(data)
                            .then(()=> Df11000_Lancamento_Service.atualizaLancamento());
                            removeEdicaoLinhasWidget(camposAlterados);
                            impostosItemWidget.list();
                        })
                        .catch(requestError);
        
                if (statusNota !== 'D')
                    salvaImpostosItem();
                else
                    salvaImpostosTmpItem();
            }
            else MessageService.showMessageByCode('BLOCK_NOTE');
        }, requestError);
    };

    /* *********************** Lancamento Entrada - Imposto ********************************** */

    this.recalculoImpostosNota = function(impostosArgs) {
        var impostosWidget = impostosArgs.owner;

        Df11000_Lancamento_Service.calculaTotalImpostos().then(() => {
            impostosWidget.redraw();
            impostosWidget.reload();
            });
    };

    this.setIdvalorinfo = function(row) {
        if (!row.VRIMPOSTOIT || row.VRIMPOSTOIT == 0) {
            row.IDVALORINFO = 'N';
        } else {
            row.IDVALORINFO = 'S';
        }
    };

    /* ************************* Lancamento Entrada - Encargos ********************************* */

    this.encargoOnChange = function(encargosArgs) {
        var encargoWidget = encargosArgs.owner.field.widget;
        controlaStatusWidgets(encargoWidget.getParent(), encargoWidget.name, false);
    };

    this.setDtsEncargoOnEnter = function(encargosArgs) {
        var widgetEncargo = encargosArgs.owner;
        if (!widgetEncargo.dataSource.data.length) {
            Df11000_Lancamento_Service.buscaEncargosPadrao().then(encargos => {
                encargos.forEach(encargo => {
                    encargo.VRITEMENCA = 0;
                    encargo.NRLANCTONF = widgetEncargo.getParent().currentRow.NRLANCTONF;
                    encargo.CDFILIAL = widgetEncargo.getParent().currentRow.CDFILIAL;
                    encargo.VRENMOEDESTR = '';
                    encargo.IDALTERADO = 'N';
                    encargo.__is_new = true;
                });
                Df11000_Lancamento_Service.setDataSourceEncargo(encargos).then(() => {
                    widgetEncargo.currentRow = encargos;
                    widgetEncargo.reload();
                });
            });
        }
    };

    this.salvaEncargoWidgetOnSaveInlineEdit = function(encargosArgs) {
        if (encargosArgs.owner.isValid()) {
            Df11000_Lancamento_Service.getStatusNota(encargosArgs.owner.getParent().currentRow).then(salvaNota => {
                if(salvaNota) {
                    var encargoWidget = encargosArgs.owner,
                        itensWidget   = encargosArgs.owner.container.getWidget('itens'),
                        dataSourceEncargo = encargoWidget.dataSource.data,
                        parentWidget = encargosArgs.owner.getParent(),
                        totalItens   = somaValorTotalItens(itensWidget),
                        validaTotalEncargos = Df11000_Lancamento_Service.validaTotalEncargos(dataSourceEncargo, totalItens),
                        encargosSalvar;
                        
                    if (!validaTotalEncargos)
                        return requestError('Valor de encargo a descontar maior que o valor total dos itens.');
        
                    //TODO remover esta linha e coloca-la no general
                    
                    if (encargosArgs.row.__is_new) {
                        encargosSalvar = dataSourceEncargo;
                    } else {
                        encargosSalvar = encargosArgs.dataSource.filter(encargo => !!encargo.changed);
                    }
        
                    Df11000_Lancamento_Service.salvaEncargo(encargosSalvar).then(() => {
                        alteraStatusNotafiscal(parentWidget);
                        encargosSalvar.forEach(encargo => {
                            encargo.__is_new = false;
                            //@todo remover delete encargo.changed quando desmarcaLinhasEditadas for implementada
                            delete encargo.changed_VRITEMENCA;
                            delete encargo.changed;
                        });
        
                        Df11000_Lancamento_Service.setDataSourceEncargo(encargosArgs.dataSource)
                            .then(Df11000_Lancamento_Service.atualizaLancamento)
                            .then(() => {
                                controlaStatusWidgets(encargoWidget.getParent(), encargoWidget.name, true);
                                //@todo desmarcaLinhasEditadas
                                //GerUtil.desmarcaLinhasEditadas(lancamentoEncargoWidget, CANCELAR);
                                Df11000_Lancamento_Service.setDataSourceLancamentoNota();
                                //encargosArgs.owner.view();
                                encargosArgs.owner.list();
                                encargosArgs.owner.reload();
                            });
                    }, requestError);
                }
                else MessageService.showMessageByCode('BLOCK_NOTE');
            }, requestError);
        }
    };

    this.cancelaEncargoWidgetOnCancelInlineEdit = function(encargosArgs) {
        // TODO criar função para desmarcar linhas editadas
        // GerUtil.desmarcaLinhasEditadas(lancamentoEncargoWidget, CANCELAR);
        
        let encargoWidget = encargosArgs.owner;
        encargosArgs.owner.dataSource.data.forEach(encargo => {
            encargo.VRITEMENCA = (encargo.changed) ? encargo.changed_VRITEMENCA : encargo.VRITEMENCA;
            delete encargo.changed_VRITEMENCA;
            delete encargo.changed;
        });
        controlaStatusWidgets(encargoWidget.getParent(), encargoWidget.name, true);
        encargoWidget.list();
        encargoWidget.reload();
    };

    /* ************************* Lancamento Entrada - Vencimentos ********************************* */

    this.actNovoVencimentoActionEvent = function(vencimentoArgs) {
        ScreenService.showLoader();
        var vencimentoWidget = vencimentoArgs.owner.widget;
        var widgetParentRow = vencimentoWidget.getParent().currentRow;

        
        var vencimentoCurrentRow = vencimentoWidget.currentRow;

        var dataSourceVencimento = vencimentoWidget.dataSource.data;
        var valorNotaFiscal = widgetParentRow.VRNOTAFISC;
        
        var promises = [];
        
        promises.push(Df11000_Lancamento_Service.somaTotalImpostosRetidos().then(valorImpostosRetidos => {
            var valorVencimento = Df11000_Lancamento_Service.calculaValorVencimento(dataSourceVencimento, valorNotaFiscal, valorImpostosRetidos);
            vencimentoWidget.getField('VRATUAPAG').defaultValue     = valorVencimento;
        }));
        promises.push(Df11000_Lancamento_Service.getProxSeqVencimento().then(nrseqvenpag => {
            vencimentoWidget.getField('NRSEQVENPAG').defaultValue   = nrseqvenpag;
        }));
        
        ZHPromise.all(promises).then((success) => {
            vencimentoWidget.newRow();
            ScreenService.hideLoader();
        });
    };

    this.editarWidget = function(args){
        General.edit(args.owner.widget);
        args.owner.widget.getField('DSLINKANEXO').isVisible = false;
        args.owner.widget.getField('DSLINKANEXO').validations = {};
        args.owner.widget.getField('CBUTILIZAAF').validations = {};
        controlaStatusWidgets(args.owner.widget, args.owner.widget.name, false);
        validaCampoModDocFiscal(args.owner.widget, args.row);
    };

    this.actIncluirVencimentoActionEvent = vencimentoArgs => {
        if (vencimentoArgs.owner.widget.isValid()) {
            Df11000_Lancamento_Service.getStatusNota(vencimentoArgs.owner.widget.getParent().currentRow).then(salvaNota => {
                 if(salvaNota) {
                    var vencimentoWidget     = vencimentoArgs.owner.widget,
                        dataSourceVencimento = vencimentoWidget.dataSource.data,
                        widgetParent         = vencimentoArgs.owner.widget.getParent(),
                        widgetParentRow      = widgetParent.currentRow,
                        valorNotaFiscal      = widgetParentRow.VRNOTAFISC,
                        vencimentoRow        = vencimentoArgs.row,
                        dataEmissao          = widgetParentRow.DTEMISSAO,
                        dataVencimento       = vencimentoRow.DTATUAVENPAG,
                        erroDataVencimento   = Dfe11000_LancamentoEntrada_Service.validaDataVencimento(dataEmissao, dataVencimento);
        
                    if (erroDataVencimento)
                        return ScreenService.showMessage(erroDataVencimento);
                        
                    if (vencimentoRow.VRATUAPAG === "0.00" || vencimentoRow.VRATUAPAG === 0.00)
                        return ScreenService.showMessage("Valor deve ser maior que zero.");
                    
                    Df11000_Lancamento_Service.somaTotalImpostosRetidos().then(valorImpostosRetidos => {
                        let valorVencimento = Df11000_Lancamento_Service.validaValorVencimento(dataSourceVencimento, valorNotaFiscal, valorImpostosRetidos);
                        if(valorVencimento < 0) {
                            return ScreenService.showMessage('Total de vencimentos maior que total da nota!');
                        }
                        
                        vencimentoRow.NRPARCELAPAG = '00';
                        vencimentoRow.NRLANCTONF   = widgetParentRow.NRLANCTONF;
                        vencimentoRow.CDFILIAL     = widgetParentRow.CDFILIAL;
                        vencimentoRow.CDEMPRESA    = widgetParentRow.CDEMPRESA;
                        vencimentoRow.NRORG        = widgetParentRow.NRORG;
                        vencimentoRow.VRORIGPAG    = vencimentoRow.VRATUAPAG;
                        vencimentoRow.DTORIGVENPAG = vencimentoRow.DTATUAVENPAG;
            
                        Dfe11000_LancamentoEntrada_Service.salvaVencimento(vencimentoRow).then(() => {
                            vencimentoRow.__is_new = false;
                            alteraStatusNotafiscal(widgetParent);
                            
                            Df11000_Lancamento_Service.setDataSourceVencimento(vencimentoRow)
                                .then(Df11000_Lancamento_Service.atualizaLancamento)
                                .then(Df11000_Lancamento_Service.setDataSourceLancamentoNota)
                                .then(ScreenService.goBack.bind(ScreenService))
                                .catch(requestError);
                        }, requestError);
                    });
                 }
                 else MessageService.showMessageByCode('BLOCK_NOTE');
             }, requestError);
        }
    };

    this.actExcluirVencimentoOnClick = lancamentoVencimentoArgs => {
        ScreenService.confirmMessage(
            ScreenService.i18n('Excluir Registro?'), 'question', () => {
                Df11000_Lancamento_Service.getStatusNota(lancamentoVencimentoArgs.owner.widget.getParent().currentRow).then(salvaNota => {
                    if(salvaNota) {
                        Dfe11000_LancamentoEntrada_Service.excluiVencimento(lancamentoVencimentoArgs.row).then(() => {
                            alteraStatusNotafiscal(lancamentoVencimentoArgs.owner.widget.getParent());
        
                            Df11000_Lancamento_Service.excluiVencimentoDataSource(lancamentoVencimentoArgs.row.NRSEQVENPAG)
                                .then(Df11000_Lancamento_Service.atualizaLancamento)
                                .then(Df11000_Lancamento_Service.setDataSourceLancamentoNota)
                                .then(() => {
                                    General.backOrCancel(lancamentoVencimentoArgs);
                                    lancamentoVencimentoArgs.owner.widget.reload();
                                })
                                .catch(requestError);
                        }, requestError);
                    }
                    else MessageService.showMessageByCode('BLOCK_NOTE');
                }, requestError);
            }
        );
    };

    this.qtDiasPadVencimentoFieldOnChange = function(vencimentoArgs) {
        var qtdias = vencimentoArgs.owner.field.value();
        var vencimentoWidget = vencimentoArgs.owner.field.widget;
        var vencimentoRow = vencimentoWidget.currentRow;
        var cabecalhoRow = vencimentoWidget.getParent().currentRow;
        var dtemissao = cabecalhoRow.DTEMISSAO;

        vencimentoRow.DTATUAVENPAG = Df11000_Lancamento_Service.calculaDataVencimento(qtdias, dtemissao);
    };

    this.dtVencimentoFieldOnChange = function(vencimentoArgs) {
        var vencimentoWidget = vencimentoArgs.owner.field.widget;
        var vencimentoRow = vencimentoWidget.currentRow;
        var cabecalhoRow = vencimentoWidget.getParent().currentRow;
        var dtEmissao = cabecalhoRow.DTEMISSAO;
        var dtVencimento = vencimentoRow.DTATUAVENPAG;

        //.toString() necessario pois ao validar a widget o 0 é considerado como boolean, ai . . .
        vencimentoRow.QTDIASVENPAG = Df11000_Lancamento_Service.calculaNumeroDiasVencimento(dtVencimento, dtEmissao).toString();
    };

    /* ************************* Lancamento Entrada - Dados Adic ***************************** */

    this.actNovoDadosAdicionaisOnClick = function(dadosAdicArgs) {
        dadosAdicArgs.owner.widget.newRow();
        Df11000_Lancamento_Service.getProxSeqDadosAdicionais().then(nrdadoadic => {
            dadosAdicArgs.owner.widget.currentRow.NRDADOADIC = nrdadoadic;
        });
    };


    this.limpaCampoCodigoDadosAdic = function(dadosAdicArgs) {
        dadosAdicArgs.row.CDMENSAGEM = null;
    };

    this.salvaDadosAdicActionEvent = function(dadosAdicArgs) {
        if (dadosAdicArgs.owner.widget.isValid()) {
            Df11000_Lancamento_Service.getStatusNota(dadosAdicArgs.owner.widget.getParent().currentRow).then(salvaNota => {
                 if(salvaNota) {
                    var dadosAdicRow    = dadosAdicArgs.row,
                        widgetparent    = dadosAdicArgs.owner.widget.getParent(),
                        widgetParentRow = widgetparent.currentRow;
        
                    dadosAdicRow.NRLANCTONF = widgetParentRow.NRLANCTONF;
                    dadosAdicRow.CDFILIAL   = widgetParentRow.CDFILIAL;
        
                    Df11000_Lancamento_Service.salvaDadosAdicionais(dadosAdicRow).then(() => {
                        alteraStatusNotafiscal(widgetparent);
                        dadosAdicRow.__is_new = false;
        
                        Df11000_Lancamento_Service.setDataSourceDadosAdicionais(dadosAdicRow)
                            .then(Df11000_Lancamento_Service.atualizaLancamento)
                            .then(Df11000_Lancamento_Service.setDataSourceLancamentoNota)
                            .then(dadosAdicArgs.owner.widget.view)
                            .catch(requestError);
                    });
                 }
                 else MessageService.showMessageByCode('BLOCK_NOTE');
             }, requestError);
        }
    };

    this.deletaDadosAdic = function(dadosAdicArgs) {
        ScreenService.confirmMessage(
            ScreenService.i18n('Excluir Registro?'), 'question', () => {
                Df11000_Lancamento_Service.getStatusNota(dadosAdicArgs.owner.widget.getParent().currentRow).then(salvaNota => {
                    if(salvaNota) {
                        var dadosAdicRow    = dadosAdicArgs.row,
                            dadosAdicWidget = dadosAdicArgs.owner.widget;
                            
                        Df11000_Lancamento_Service.excluiDadosAdicionais(dadosAdicRow)
                            .then(() => alteraStatusNotafiscal(dadosAdicWidget.getParent()))
                            .then(() => Df11000_Lancamento_Service.excluiDadosAdicionaisDataSource(dadosAdicRow.NRDADOADIC))
                            .then(Df11000_Lancamento_Service.atualizaLancamento)
                            .then(Df11000_Lancamento_Service.setDataSourceLancamentoNota)
                            .then(() => {
                                General.backOrCancel(dadosAdicArgs);
                                dadosAdicWidget.reload();
                            });
                    }
                    else MessageService.showMessageByCode('BLOCK_NOTE');
                }, requestError);
            }
        );
    };

    /* ************************* Lancamento Entrada - Relacionamento Itens ********************************* */
    this.actEditarRelacionamentoItensOnClick = function(lancamentoRelacionamentoItensArgs) {
        var lancamentoRelacItensWidget = lancamentoRelacionamentoItensArgs.owner.widget,
            parentWidget = lancamentoRelacItensWidget.getParent(),
            parentCurrentRow = parentWidget.currentRow,
            produtoImportarField = lancamentoRelacItensWidget.getField('CDARVPRODFORNXML');

        
        this.produtosImportarFieldBeforeSelectOpen(lancamentoRelacItensWidget.getField('CDARVPRODFORNXML'));

        General.edit(lancamentoRelacItensWidget);
    };

    this.actVoltarRelacionamentoItensList = function(lancamentoRelacionamentoItensArgs) {
        General.backOrCancel(lancamentoRelacionamentoItensArgs);
    };

    this.actExcluirRelacionamentoItem = function(lancamentoRelacionamentoItensArgs) {
        var lancamentoRelacItensWidget = lancamentoRelacionamentoItensArgs.owner.widget,
            currentRow = lancamentoRelacItensWidget.currentRow,
            cdprodutoxml = currentRow.CDPRODUTOINTG,
            cdforneced = lancamentoRelacItensWidget.getParent().currentRow.CDFORNECED,
            cdfilial = lancamentoRelacItensWidget.getParent().currentRow.CDFILIRECE,
            cdproduto  = currentRow. CDPRODFORNXML;

        ScreenService.confirmMessage(
            'Deseja remover o relacionamento?',
            'question',
            () => {
                Dfe11000_LancamentoEntrada_Service.removerRelacionamentoItemXml(cdprodutoxml, cdforneced, cdfilial, cdproduto)
                    .then(() => {
                        currentRow.CDFORNECED = null;
                        currentRow.CDARVPRODFORNXML = null;
                        currentRow.NMPRODUTOFORNXML = null;
                        currentRow.CDPRODFORNXML = null;
                        lancamentoRelacItensWidget.list();
                        //lancamentoRelacItensWidget.reload();
                        lancamentoRelacItensWidget.view();
                    })
                    .catch(requestError);
            }
        );
    };

    this.actCancelarRelacionamentoItens = function(lancamentoRelacionamentoItensArgs) {
        General.backOrCancel(lancamentoRelacionamentoItensArgs);
    };

    this.actSalvarRelacionamentoItens = function(lancamentoRelacItensWidget) {
        if(lancamentoRelacItensWidget.isValid()) {
            let {currentRow} = lancamentoRelacItensWidget;
    
            let parentRow = lancamentoRelacItensWidget.getParent().currentRow; 
    
            const {CDPRODFORNXML, CDPRODUTOINTG} = currentRow;
    
            if (!parentRow.CDFORNECED) {
                return ScreenService.showMessage('Fornecedor não encontrado.');
            }
    
            currentRow.CDFORNECED   = parentRow.CDFORNECED;
            currentRow.CDPRODUTOXML = parentRow.CDPRODUTOINTG;
            currentRow.CDFILIAL     = parentRow.CDFILIRECE;
            currentRow.CDPRODUTOXML_BACKUP_ROW = lancamentoRelacItensWidget.backupRow.CDPRODFORNXML;
    
            if (isAFRequired(parentRow, true) && importOnlyAFProducts(parentRow)) {
                const produtoRelacionado = lancamentoRelacItensWidget.dataSource.data
                    .findIndex(item =>
                        (item.CDPRODFORNXML === CDPRODFORNXML) &&
                        (item.CDPRODUTOINTG !==  CDPRODUTOINTG));
    
                if (produtoRelacionado !== -1)
                    return showMessageDfe('PRODUTO_JA_RELACIONADO');
            }
    
            return Dfe11000_LancamentoEntrada_Service.salvaRelacionamentoItensXml(currentRow)
                .then(() =>  {
                    lancamentoRelacItensWidget.list();
                    //lancamentoRelacItensWidget.reload();
                    lancamentoRelacItensWidget.view();
                })
                .catch(requestError);
        }
    };

    this.actProdutosAfRelacionamentoItensOnClick = function(lancamentoRelacionamentoItensArgs) {
        var lancamentoRelacItensWidget = lancamentoRelacionamentoItensArgs.owner.widget,
            itensProgAfWidget = lancamentoRelacItensWidget.container.getWidget('itensProgAf');

        itensProgAfWidget.reload();
        ScreenService.openPopup(itensProgAfWidget);
    };

    var createDataSourceFilterRelacionamentoItens = function(lancamentoRelacItensWidget, currentRowParentWidget) {

        lancamentoRelacItensWidget.dataSourceFilter = [];
        var dataSourceFilter = lancamentoRelacItensWidget.dataSourceFilter,
            filterDefault = {
                'operator': '='
            };

        if (currentRowParentWidget.NRACESSONFE) {
            filterDefault.name = 'NRACESSONFE';
            filterDefault.value = currentRowParentWidget.NRACESSONFE;
            dataSourceFilter.push(Util.clone(filterDefault));

            filterDefault.name = 'CDFORNECED';
            filterDefault.value = currentRowParentWidget.CDFORNECED;
            dataSourceFilter.push(Util.clone(filterDefault));
            
            filterDefault.name = 'CDFILIAL';
            filterDefault.value = currentRowParentWidget.CDFILIRECE;
            dataSourceFilter.push(Util.clone(filterDefault));
        }
    };

    var createDataSourceFilterItensProgAf = function(itensProgAfWidget, currentRowParentWidget) {

        itensProgAfWidget.dataSourceFilter = [];

        var dataSourceFilter = itensProgAfWidget.dataSourceFilter,
            filterDefault = {
                'operator': '='
            };

        if ('AF' in currentRowParentWidget) {
            filterDefault.name = 'AF';
            filterDefault.value = currentRowParentWidget.AF;
            dataSourceFilter.push(Util.clone(filterDefault));
        }
    };

    const getItensNaoRelacionados = (itensPrincipais, itensSec, compare) => itensPrincipais.filter(itemXml => !itensSec.some(compare(itemXml)));

    var reloadRelacionamentoItens = function(itensProgAfWidget, lancamentoRelacItensWidget, cabecalhoRow) {
        var reloadAndCleanItensXml = function reloadAndCleanItensXml() {
            var itensAF = [];
            return itensProgAfWidget.reload()
                .then(itensProgAf => {
                    itensAF = itensProgAf.dataset.grupo_itens_afs;

                    return lancamentoRelacItensWidget;
                })
                .then(relacItensXml => {

                    var itensXml = ( relacItensXml.dataset.produtos_xml ) ? relacItensXml.dataset.produtos_xml : relacItensXml.dataset.produtos_xml_filial,
                        compare = function compare(item) {
                            return function(itemAf) {
                                return item.CDPRODFORNXML === itemAf.CDPRODUTO;
                            };
                        };

                    var itensNaoRelacionados = getItensNaoRelacionados(itensXml, itensAF, compare);

                    if (itensAF.length && itensNaoRelacionados.length) {
                        let message = 'AF_OBRIGATORIA_E_INSUFICIENTE';

                        showMessageDfe(message);
                    }

                    itensNaoRelacionados.forEach(item => {
                        item.NMPRODUTOFORNXML = null;
                        item.CDARVPRODFORNXML = null;
                        item.CDFORNECED = null;
                        item.CDPRODFORNXML = null;
                        item.CDPRODUTOXML = null;
                        item.NMPRODUTOFORNXML = null;
                    });

                    return itensXml;
                })
                .catch(error => {
                    itensProgAfWidget.dataSource.data = [];
                    lancamentoRelacItensWidget.dataSource.data = [];
                    requestError(error);
                })
            ;
        };

        var onlyReloadWidgets = function onlyReloadWidgets() {

            if (lancamentoPossuiAf) {
                itensProgAfWidget.reload();
            }

            return lancamentoRelacItensWidget.reload().then(relacItensXml => {
                var itensXml = relacItensXml.dataset.produtos_xml;
                return itensXml;
            });
        };

        var parentCurrentRow = lancamentoRelacItensWidget.getParent().currentRow,
            useOnlyAFProducts = isAFRequired(parentCurrentRow) && importOnlyAFProducts(parentCurrentRow),
            lancamentoPossuiAf = ('AF' in parentCurrentRow);

        return useOnlyAFProducts ? reloadAndCleanItensXml() : onlyReloadWidgets();
    };

    var createDataSourceRelacionamentoItens = function(lancamentoRelacItensWidget, itensProgAfWidget, cabecalhoCurrentRow) {
        createDataSourceFilterItensProgAf(itensProgAfWidget, cabecalhoCurrentRow);
        createDataSourceFilterRelacionamentoItens(lancamentoRelacItensWidget, cabecalhoCurrentRow);
    };
    
    this.relacionamentoItensWidgetOnMoveRow = function(lancamentoRelacionamentoItensArgs){
          let lancamentoRelacItensWidget = lancamentoRelacionamentoItensArgs.owner,
              parentCurrentRow = lancamentoRelacItensWidget.getParent().currentRow,
              permiteAlterar = (parentCurrentRow.IDBLOQALTPROXML !== 'S' && parentCurrentRow.IDBLOQALTPRODREL !== 'S');
          
        lancamentoRelacItensWidget.getAction('actEditarRelacionamentoItens').isVisible = permiteAlterar;
        lancamentoRelacItensWidget.getAction('actExcluirRelacionamentoItens').isVisible = permiteAlterar;
          
    };

    this.relacionamentoItensWidgetOnEnter = function(lancamentoRelacionamentoItensArgs) {
        
        if(!atualizouRelacionamento){
            var lancamentoRelacItensWidget = lancamentoRelacionamentoItensArgs.owner,
            parentWidget = lancamentoRelacItensWidget.getParent(),
            parentCurrentRow = parentWidget.currentRow,
            afsSelecionadas = ('AF' in parentCurrentRow),
            visibleActionCabecalhoEdit = parentWidget.mode !== 'edit',
            itensProgAfWidget = lancamentoRelacItensWidget.container.getWidget('itensProgAf');

            lancamentoRelacItensWidget.getAction('actVoltarRelacionamentoItensList').isVisible = visibleActionCabecalhoEdit;
            lancamentoRelacItensWidget.getAction('actProdutosAfRelacionamentoItens').isVisible = afsSelecionadas;
    
            createDataSourceRelacionamentoItens(lancamentoRelacItensWidget, itensProgAfWidget, parentCurrentRow);
    
            reloadRelacionamentoItens(itensProgAfWidget, lancamentoRelacItensWidget, lancamentoRelacItensWidget.getParent().currentRow)
                .then(() => {
                    atualizouRelacionamento = true;
                    if (isAFRequired(parentCurrentRow) && importOnlyAFProducts(parentCurrentRow) && !afsSelecionadas)
                        showMessageDfe('AF_OBRIGATORIA_E_NENHUMA_SELECIONADA');
                });
        }
    };

    var criaDataSourceCdarvprodfornxmlTodosProdutos = function(cdarvprodfornxmlField, eFilialOl, cdforneced) {
        var dataSource = cdarvprodfornxmlField.dataSource;
        cdarvprodfornxmlField.dataSourceFilter = [];
        var cabecalho = templateManager.container.getWidget('cabecalho');
        dataSource.name = eFilialOl ? 'df_entrada#/produtos_relacionados_ol' : 'df#/produtoImportarLancamento';

        if (!eFilialOl) {
            cdarvprodfornxmlField.dataSourceFilter = [
                {
                    'name': 'CDFILIAL',
                    'operator': '=',
                    'value': cabecalho.currentRow.CDFILIRECE
                },
                {
                    'name': 'IDPRODATIVPR',
                    'operator': '=',
                    'value': 'S'
                },
                {
                    'name': 'IDPRODATIV',
                    'operator': '=',
                    'value': 'A'
                },
                {
                    'name': 'CDNVPRODUTO',
                    'operator': '=',
                    'value': self.nivelCompletoProduto()
                },
                {
                    'name': 'CDFORNECED',
                    'operator': '=',
                    'value': cdforneced
                },
                {
                    'name': 'NRAUTOFORN',
                    'operator': '=',
                    'value': (cabecalho.currentRow.AF) ? self.buildInstrAf(cabecalho.currentRow.AF) : ''
                },
                {
                    "name": "DTPROGENTAF",
                    "operator": "=",
                    "value": (cabecalho.currentRow.AF) ? cabecalho.currentRow.AF[0].DTPROGENTAF : null
                } 
                
            ];
        }
        else {
            cdarvprodfornxmlField.dataSourceFilter = [
                {
                    'name': 'CDFILIAL',
                    'operator': '=',
                    'value': cabecalho.currentRow.CDFILIRECE
                },
                {
                    'name': 'CDFORNECED',
                    'operator': '=',
                    'value': cdforneced
                },
                {
                    'name': 'NRAUTOFORN',
                    'operator': '=',
                    'value': (cabecalho.currentRow.AF) ? self.buildInstrAf(cabecalho.currentRow.AF) : ''
                }
            ];
        }
    };
    
    this.buildInstrAf = function(AF) {
        let instrAF = '_';
        if(Array.isArray(AF)) {
            AF.forEach((af) => {
                instrAF += af.NRAUTOFORN + '_'; 
            });
        }  
        return instrAF;
    };

    this.produtosImportarFieldBeforeSelectOpen = function(field) {
        const {widget} = field, AFWidget = widget.container.getWidget('itensProgAf');

        const isFilialOL   = widget.getParent().currentRow.IDFUNCAOFILI  === 'O',
            AFProductsOnly = isAFRequired(widget.getParent().currentRow) && importOnlyAFProducts(widget.getParent().currentRow);

        criaDataSourceCdarvprodfornxmlTodosProdutos(field, isFilialOL, widget.getParent().currentRow.CDFORNECED);

        field.dataSourceFilter = (AFProductsOnly)?
            getProdutosImportarFilterByAF(widget, AFWidget, field.dataSourceFilter)
            : getProdutosImportarFilterAllProducts(field.dataSourceFilter);

        field.reload();
    };

    const getProdutosImportarFilterByAF = (widget, AFWidget, previousFilter) => {
        const AFItems = AFWidget.dataSource.data.map(item => item.CDPRODUTO),
            XMLItems = widget.dataSource.data.map(item => item.CDPRODFORNXML);
            
        let products = [];
        var item = [];

        AFItems.forEach((itemAf) => {
            item = [];
            item = XMLItems.filter(( xml ) => {
                return itemAf == xml; 
            });
            
            if( item.length == 0 ) {
                products.push(itemAf);
            }
        });

        const productFilter = previousFilter.find(filter => filter.name == 'CDPRODUTO');

        if (productFilter) {
            productFilter.operator = 'IN';
            productFilter.value = products;
        } else
            previousFilter.push({name: 'CDPRODUTO', operator: 'IN', value: products});

        return previousFilter;
    };

    const getProdutosImportarFilterAllProducts = previousFilter => previousFilter.filter(filter => filter.name !== 'CDPRODUTO');

    var validacaoRelacionamentoItens = function(cabecalhoWidget) {
        var lancamentoRelacItensWidget = cabecalhoWidget.container.getWidget('relacionamentoItens'),
            itensProgAfWidget   = cabecalhoWidget.container.getWidget('itensProgAf'),
            currentRowCabecalho = cabecalhoWidget.currentRow,
            possuiChaveAcesso   = !!currentRowCabecalho.NRACESSONFE,
            deferred = ZHPromise.defer(),
            isNew = currentRowCabecalho.__is_new;
            
        createDataSourceRelacionamentoItens(lancamentoRelacItensWidget, itensProgAfWidget, currentRowCabecalho);
        datasourceRelacionamento = cabecalhoWidget.container.getWidget('relacionamentoItens').dataSource.data;
        
        if (possuiChaveAcesso && isNew) {
            var reload = reloadRelacionamentoItens(itensProgAfWidget, lancamentoRelacItensWidget);
            reload.then(itensRelacionados => {
                const produtoNaoRelacionado = Array.isArray(itensRelacionados)
                    && itensRelacionados.some(item => !item.CDPRODUTOXML);

                if (produtoNaoRelacionado) {
                    deferred.reject('EXISTE_PRODUTOS_NAO_RELACIONADO');
                    lancamentoRelacItensWidget.activate();
                } else {
                    deferred.resolve();
                }
            });
        } else {
            deferred.resolve();
        }
        
        return deferred.promise;
    };

    this.actConfirmarNotaRelacionamentoItens = function(lancamentoRelacionamentoItensArgs) {
        var lancamentoRelacItensWidget = lancamentoRelacionamentoItensArgs.owner.widget,
            cabecalhoWidget = lancamentoRelacItensWidget.getParent();
        var dataSource = lancamentoRelacItensWidget.dataSource.data;
        
        if(validaProdutosRelacionados(dataSource)){
            return showMessageDfe("EXISTE_PRODUTOS_NAO_RELACIONADO");
        } else{
            var datasourceProduto = dataSource[0];
            realizaSalvamentoCabecalhoNotaFiscal(cabecalhoWidget, datasourceProduto);
        }
    };
    
    var validaProdutosRelacionados = function(dataSource){
        var produtoNaoRelacionado = false;
        dataSource.forEach((produto) => {
           if(produto.CDARVPRODFORNXML === '' || produto.CDARVPRODFORNXML === null) produtoNaoRelacionado = true;
        });
        
        return produtoNaoRelacionado;
    };
    
    this.getCurrentField = function(field) {
        var cabecalhoWidget = getCabecalhoWidget();
        if (cabecalhoWidget)
             return !cabecalhoWidget.currentRow[field] ? null : cabecalhoWidget.currentRow[field];
        return null;
    };
    
    this.getFieldFilter = function(fieldName, args) {
        if(args) console.log(args.owner);  
    };
    
    this.bloqueiaEdicaoImpostos = function(cabecalhoArgs){
        var rowNota = cabecalhoArgs.row;
        var impostosItens = cabecalhoArgs.owner.container.getWidget('impostosItem');
        
        if(rowNota.IDSTATUS === 'D' || rowNota.IDSTATUS === 'P'){
            impostosItens.fields.forEach( row => {
                if(row.name === 'VRALIQIMPOIT' || row.name === 'VRIMPOSTOIT')
                     row.inlineEditable = "number";
            });
        }else{
            impostosItens.fields.forEach(row => {
                delete(row.inlineEditable);
            });
        }
    };
    
    this.setDefaultNovaNota = function (args) {
        var row = {CDFILIAL: args.e.preference.FILTER_ROW.CDFILIRECE};
        General.callRestEngine("df_entrada#/getDefaultNovaNota", "Row", row).then((success) => {
            Df11000_Lancamento_Service.setDefaultNovaNota(success.dataset.defaultNovaNota);
        });
    };
    
    this.generateReportConsistencia = function() {
        var row = templateManager.container.getWidget('cabecalho').currentRow;
        var rowReport = {
            CDFILIAL: row.CDFILIAL,
            CHAVE: [row.CDFILIAL+row.NRLANCTONF],
            DTINTERVALO: {start: row.DTENTRSAID.substr(0, 10), end: row.DTENTRSAID.substr(0, 10)},
            L_CDFILIRECE: '_'+row.CDFILIRECE+'_',
            L_CHAVE: '_'+row.CDFILIAL+row.NRLANCTONF+'_',
            NMFILIAL: row.NMFILIAL, 
            NRNOTAFISC: [row.NRNOTAFISC],
            P_DTFINAL: row.DTENTRSAID.substr(0, 10),
            P_DTINICIAL: row.DTENTRSAID.substr(0, 10),
            T_CDFILIAL: "L",
            NMRELATORIO: 'DFE16000',
            __report_name: "DFE16000"
        };
        
        General.callRestEngine("df_entrada#/notafiscal_consistencias_af_nf", "Row", rowReport).then( (response) => {
            window.open(response.messages[0].message);
        });
    };
    
    this.searchForAccessKey = function(widget){
        let valfDTEMISSAO    = widget.getField('DTEMISSAO').value();
        let valfCDSERIEENTR  = widget.getField('CDSERIEENTR').value();
        let valfNRNOTAFISC   = widget.getField('NRNOTAFISC').value();
        let valfNMRAZSOCFORN = widget.getField('NMRAZSOCFORN').value();
        let nracessonfe      = widget.getField('NRACESSONFE').value();
        if( valfDTEMISSAO && 
           valfCDSERIEENTR && valfNRNOTAFISC && valfNMRAZSOCFORN && !nracessonfe){
                let params = {};
                params.DTEMISSAO    = valfDTEMISSAO;  
                params.CDSERIEENTR  = widget.currentRow.CDSERIEENTR;  
                params.NRNOTAFISC   = valfNRNOTAFISC;  
                params.NRINSJURNF   = widget.currentRow.NRINSJURNF;
                fetchAccessKeyByOtherFields(widget, params);
                widget.getField('NRACESSONFE').value(); //ScreenService.showMessage('SUCESSO!'); 
        }
    };

    this.abrirPopupBuscarAf = function(widget) {
        var buscarAf = templateManager.container.getWidget('NOVA_AF');
        ScreenService.openPopup(buscarAf).then(() => {
            buscarAf.activate();
            buscarAf.isVisible = true;
        });
    };
    
    this.buscarAfPorCodigo = function(widget) {
        if(widget.isValid()) {
            let cabecalho   = templateManager.container.getWidget('cabecalho');
            let autoforne   = templateManager.container.getWidget('autorizacaoFornecimento');
            let cabecalhoRow = cabecalho.currentRow;
            let dtminvazia  = cabecalhoRow.DTMINVAZIA;
            let dtmaxvazia  = cabecalhoRow.DTMAXVAZIA;
            let dtprocini   = cabecalhoRow.DTPROCINI;
            let dtprocfin   = cabecalhoRow.DTPROCFIN;
            let filter = [
                {
                    "name": "P_CDFILIAL",
                    "operator": "=",
                    "value": cabecalho.currentRow.CDFILIRECE
                },
                {
                    "name": "P_CDFORNECED",
                    "operator": "=",
                    "value": "T"
                },
                {
                    "name": "P_DTPROCINI",
                    "operator": "=",
                    "value": dtprocini
                },
                  {
                    "name": "P_DTMINVAZIA",
                    "operator": "=",
                    "value": dtminvazia
                },
                {
                    "name": "P_DTPROCFIN",
                    "operator": "=",
                    "value": dtprocfin
                },
                {
                    "name": "P_DTMAXVAZIA",
                    "operator": "=",
                    "value": dtmaxvazia
                },
                {
                    "name": "NRAUTOFORN",
                    "operator": "=",
                    "value": widget.currentRow.NRAUTOFORN
                }
                
            ];
            
            General.callRestEngine("df_entrada#/autoforne_itemautf", "FilterData", filter).then((success) => {
                if(success.dataset.autoforne_itemautf[0]) {
                    //Tira os elementos repetidos
                    autoforne.dataSource.data = autoforne.dataSource.data.filter( data => {
                        return data.NRAUTOFORN !== success.dataset.autoforne_itemautf[0].NRAUTOFORN || data.NRINSJURFORN !== success.dataset.autoforne_itemautf[0].NRINSJURFORN;
                    });
                    autoforne.dataSource.data.unshift(success.dataset.autoforne_itemautf[0]);
                    ScreenService.closePopup(widget);
                    ScreenService.successNotification("Autorização de Fornecedor encontrada.");

                }
                else {
                    ScreenService.errorNotification("Autorização de Fornecimento não encontrada.");
                }
            }, (error) => {
                ScreenService.errorNotification("Ocorreu um erro ao buscar a autorização de fornecimento");
            });  
        }
    };
    
    this.closePopupBuscarAf = function(widget) {
        ScreenService.closePopup(widget);
    };
    

    /***************************** Anexos *********************************************/
    
    this.inicializaAnexo = function(args){
        var filter = [
            {
                "name": "P_CDFILIAL",
                "operator": "=",
                "value": args.owner.getParent().currentRow.CDFILIAL
            },
            {
                "name": "P_NRLANCTONF",
                "operator": "=",
                "value": args.owner.getParent().currentRow.NRLANCTONF
            }
            
        ];
        
        General.callRestEngine("df#/crud/anexo_obrigatorio", "FilterData", filter).then((success) => {
            if(success.dataset.anexo_obrigatorio[0].IDBLOQANEXO) {
                if(success.dataset.anexo_obrigatorio[0].IDBLOQANEXO == 0) {
                    args.owner.getAction("actNovoAnexo").isVisible = false;
                    args.owner.getAction("actDeleteAnexo").isVisible = false;
                }
                else if(success.dataset.anexo_obrigatorio[0].IDBLOQANEXO == 1 && args.owner.getParent().currentRow.IDSTATUS == 'A') {
                    args.owner.getAction("actNovoAnexo").isVisible = false;     
                    args.owner.getAction("actDeleteAnexo").isVisible = false;
                }                
                else if(success.dataset.anexo_obrigatorio[0].IDBLOQANEXO == 2 && (args.owner.getParent().currentRow.IDBLOQNFFIN == 'L')) {
                    args.owner.getAction("actNovoAnexo").isVisible = false;     
                    args.owner.getAction("actDeleteAnexo").isVisible = false;
                }
                else {
                    args.owner.getAction("actNovoAnexo").isVisible = true;    
                    args.owner.getAction("actDeleteAnexo").isVisible = true;
                }
            }
        });
        args.owner.reload();
    };
    
    
    this.downloadArqNF = function(widget){
        var row = widget.currentRow;

        window.open(row.link);
    };
    
    this.salvarAnexo = function(widget){
        if(widget.isValid()){
            Df11000_Lancamento_Service.getStatusNota(widget.getParent().currentRow).then(salvaNota => {
                 if(salvaNota) {
                    var row = widget.currentRow,
                        widgetReload = widget.parent.parent;
                        
                    row.CDFILIAL = widgetReload.currentRow.CDFILIAL;
                    row.NRLANCTONF = widgetReload.currentRow.NRLANCTONF;
                    row = Util.clone(widget.currentRow, ['__rightActions', '__leftActions']);
                    
                    General.callRestEngine('df_entrada#/salvar_Anexo', "Row", row).then(function() {
                        widget.reload();
                        ScreenService.closeSwipe();
                        widgetReload.resizeGridColumns(true);
                    }.bind(this), this.errorRequest);
                 }
                 else MessageService.showMessageByCode('BLOCK_NOTE');
             }, requestError);
        }
    };
    
    this.deleteAnexo = widget => {
        Df11000_Lancamento_Service.getStatusNota(widget.getParent().currentRow).then(salvaNota => {
             if(salvaNota) General.deleteCrud(widget);
             else          MessageService.showMessageByCode('BLOCK_NOTE');
         }, requestError);
    };
    
    const atualizarVrItemProduto = function (widget) {
       let row = Util.clone(widget.currentRow);
        General.callRestEngine("df_entrada#/atualizaVrItemProduto", "Row", row).then((success) => {
             ScreenService.showMessage("Valores dos produtos atualizados com sucesso");  
        }, (error) => {
                ScreenService.showMessage(error.data.error);
            });  
    };
    
    /* ************************** Lancamento Entrada - Controle de Lançamento Retroativo ************************** */
    
    this.cancelaContrLancRetro = function(args){
        ScreenService.closePopup(args.owner.widget);  
    };
    
    this.openContrLancRetro = function(widget){
        Df11000_Lancamento_Service.getStatusNota(widget.currentRow).then(salvaNota => {
            if(salvaNota) ScreenService.openPopup(templateManager.container.getWidget("controleLancRetroativo"));
            else          MessageService.showMessageByCode('BLOCK_NOTE');
         }, requestError);
    };
    
    this.gerarSenha = function(args){
        let widget = args.owner.widget;
        
        if(widget.isValid()){
            Dfe11000_LancamentoEntrada_Service.geraSenhaLancRetroativo(widget.currentRow).then( response => {
                widget.currentRow.SENHAGERADA = response.dataset.senha.SENHAGERADA;
            });
        }
    };

    /* ************************** Lancamento Entrada - Lançamento Retroativo ************************** */
    
    this.openLancRetro = function(args){
        let widgetLancRetro = templateManager.container.getWidget("lanctoRetroativo"),
        rowLancamento = args.owner.widget.currentRow;
        
        ScreenService.openPopup(widgetLancRetro);
        widgetLancRetro.currentRow.CDFILIAL = rowLancamento.CDFILIAL;
        widgetLancRetro.currentRow.NRLANCTO = rowLancamento.NRLANCTONF;
    };
    
    this.cancelaLancRetro = function(args){
        ScreenService.closePopup(args.owner.widget);  
    };
    
    this.validaSenha = function(args){
        let widget = args.owner.widget,
        currentRow = widget.currentRow;
        if(widget.isValid()){
            Dfe11000_LancamentoEntrada_Service.geraSenhaLancRetroativo(currentRow).then( response => {
                if(response.dataset.senha.SENHAGERADA == currentRow.SENHALANCTO){
                    ScreenService.closePopup(widget);
                    this.validaEdicaoCabecalho(widget);
                    this.habilitaEdicaoNotaEntrada(templateManager.container.getActiveWidget());
                } else{
                    ScreenService.showMessage("Senha inválida");
                }
            });
        }
    };
    
    /*	
    * Tipo de Operação 11	
    **/	
    this.habilitaTabProdutosOuNotas = function(widget) {	
        templateManager.container.getWidget('entrada_semnf').isVisible = (widget.currentRow.CDTIPOOPER == '11');	
        templateManager.container.getWidget('entrada_semnf').showAsTab = (widget.currentRow.CDTIPOOPER == '11');	
    }; 	
    	
    this.actNovaEntradaSemNota = function(widget) {	
        let entradaSemNota = templateManager.container.getWidget('popup_entradaSemNf');	
        entradaSemNota.activate();	
        entradaSemNota.isVisible = true;	
        ScreenService.openPopup(entradaSemNota).then(() => {	
            entradaSemNota.reload();	
        });	
    };	
    	
    this.actClosePopupEntradaSemnota = function(widget) {	
        let entradaSemNota = templateManager.container.getWidget('popup_entradaSemNf');	
        ScreenService.closePopup();	
        entradaSemNota.isVisible = false;	
        templateManager.container.getWidget('entrada_semnf').activate();	
        	
    };	
    	
    	
    this.validaActionsEntradaSemNota = function(widget) {	
        let idStatus = widget.getParent().currentRow.IDSTATUS;	
        if(idStatus != 'A') {	
            if(idStatus == 'P') widget.getAction('actFecharNotaSNF').isVisible = true;	
            else widget.getAction('actFecharNotaSNF').isVisible = false;	
            	
            widget.getAction('actNovoEntradaSNF').isVisible = true;	
            widget.getAction('actFecharNotaSNF').isVisible = true;	
        }	
        else {	
            widget.getAction('actFecharNotaSNF').isVisible = false;	
            widget.getAction('actNovoEntradaSNF').isVisible = false;            	
        }	
    };	
    
    
    this.ativaWidgets = function(widget){
        var widgetAutoriza = templateManager.container.getWidget('autorizacaoDenegacao');
        var fieldChaveAcessoCons = templateManager.container.getWidget('consultaSituacaoAtualNfe').getField('NRACESSONFE');
        var fieldAmb = widget.getField('IDTPAMBNFE');
        var fieldChaveAcesso = templateManager.container.getWidget('cabecalho').getField('NRACESSONFE');
        
        ScreenService.openPopup(widget).then(function() {
                widgetAutoriza.isVisible = true;
                fieldChaveAcessoCons.setValue(fieldChaveAcesso.value());
                var filter = [
                   {operator: "=", name: "P_NRACESSONFE", value: fieldChaveAcesso.value()}, 
                    {operator: "=", name: "P_IDENTRSAIDOP", value:"E"},
                ];
            
            //General.callRestEngine("df#/crud/status_chave", "FilterData",filter).then((success) => {
             //   if(success.dataset.status_chave[0]) {
              //      var status = success.dataset.status_chave[0].IDSTATUS;
              //      if(status == "C"){
             //           widget.getAction('Sincronizar').isVisible = false;
             //      }else{
              //          widget.getAction('Sincronizar').isVisible = true;
              //      }
             //    }
            //});
            widget.reload().then(function(){
                if(widget.dataSource.data[0]){
                    fieldAmb.setValue(widget.dataSource.data[0].IDTPAMBNFE);
                }
            });
        
        });
    };
    
    
    
    this.adicionaValorFields = function(widget){
        var fieldVerAp = templateManager.container.getWidget('autorizacaoDenegacao').getField('VERSAOAPLICATIVO');
        var fieldCdStatus = templateManager.container.getWidget('autorizacaoDenegacao').getField('CDSTATUS');
        var fieldDescStatus = templateManager.container.getWidget('autorizacaoDenegacao').getField('DSSTATUS');
        var fieldProtocolo = templateManager.container.getWidget('autorizacaoDenegacao').getField('PROTOCOLO');
        var fieldDigVal = templateManager.container.getWidget('autorizacaoDenegacao').getField('DIGESTVALUE');
        var fieldDataHora = templateManager.container.getWidget('autorizacaoDenegacao').getField('DATAEHORA');
        
        
        fieldVerAp.setValue("");
        fieldCdStatus.setValue("");
        fieldDescStatus.setValue("");
        fieldProtocolo.setValue("");
        fieldDigVal.setValue("");
        fieldDataHora.setValue("");
                    
    };
    
    //DEIXA ACTION 'CONSULTA SITUACAO ATUAL DA NOTA' VISIVEL APENAS PARA NOTAS QUE POSSUEM CHAVE DE ACESSO
    this.controlaVisibilidadeConsultaSituacao = function(){
        var fieldChaveAcesso = templateManager.container.getWidget('cabecalho').getField('NRACESSONFE');
        var widget = templateManager.container.getWidget('cabecalho');
        if(!fieldChaveAcesso.value()){
            widget.getAction('consultaSituacaoNfe').isVisible = false;
        }else{
          widget.getAction('consultaSituacaoNfe').isVisible = true;  
        }
    };
    
    //DEIXA ACTION 'Lancamento NFe Saida' VISIVEL PARA TODAS AS NOTAS 
    this.controlaVisibilidadeActLancamentoNFeSaida = function(){
        var widget = templateManager.container.getWidget('cabecalho');
        
        widget.getAction('actLancamentoNFeSaida').isVisible = true;
    };
    
    this.controlaVisibilidadeSincronizacao = function(){
        var status;
        var widget = templateManager.container.getWidget('consultaSituacaoAtualNfe');
        var chave = widget.getField('NRACESSONFE').value();
        var filter = [
            {operator: "=", name: "P_IDENTRSAIDOP", value:"E"},
        ];
            
        //General.callRestEngine("df#/crud/status_chave", "FilterData",filter).then((success) => {
         //   if(success.dataset.status_chave[0]) {
          //      status = success.dataset.status_chave[0].IDSTATUS;
          //      if(status == "C"){
          //          widget.getAction('Sincronizar').isVisible = false;
          //      }else{
           //         widget.getAction('Sincronizar').isVisible = true;
           //     }
           //  }
        //});
    };
    
    this.consultaSituacaoNF = function(widget){
        var row = widget.currentRow;
        
        var widgetCancelamento = templateManager.container.getWidget('cancelamento');
        var widgetCarta = templateManager.container.getWidget('carta');
        
        widgetCarta.isVisible = false;
        widgetCancelamento.isVisible = false;
        
        this.adicionaValorFields(widget);
        
        var fieldAmb = widget.getField('IDTPAMBNFE');
        
        //dados autorização/denegação
        var fieldVerAp = templateManager.container.getWidget('autorizacaoDenegacao').getField('VERSAOAPLICATIVO');
        var fieldCdStatus = templateManager.container.getWidget('autorizacaoDenegacao').getField('CDSTATUS');
        var fieldDescStatus = templateManager.container.getWidget('autorizacaoDenegacao').getField('DSSTATUS');
        var fieldProtocolo = templateManager.container.getWidget('autorizacaoDenegacao').getField('PROTOCOLO');
        var fieldDigVal = templateManager.container.getWidget('autorizacaoDenegacao').getField('DIGESTVALUE');
        var fieldDataHora = templateManager.container.getWidget('autorizacaoDenegacao').getField('DATAEHORA');
        
        //dados cancelamento
        var fieldCanVerAp = templateManager.container.getWidget('cancelamento').getField('VERSAOAPLICATIVO');
        var fieldCanCdStatus = templateManager.container.getWidget('cancelamento').getField('CDSTATUS');
        var fieldCanDescStatus = templateManager.container.getWidget('cancelamento').getField('DSSTATUS');
        var fieldCanProtocolo = templateManager.container.getWidget('cancelamento').getField('PROTOCOLO');
        var fieldCanDataHora = templateManager.container.getWidget('cancelamento').getField('DATAEHORA');
        var fieldCanMotivo = templateManager.container.getWidget('cancelamento').getField('MOTIVO');
        var fieldCanCodigo = templateManager.container.getWidget('cancelamento').getField('CODIGO');
        var fieldCanCNPJ = templateManager.container.getWidget('cancelamento').getField('CNPJ');
        var fieldCanSequencia = templateManager.container.getWidget('cancelamento').getField('SEQUENCIA');
        
        //dados  Carta de Correção
        var fieldCartVerAp = templateManager.container.getWidget('carta').getField('VERSAOAPLICATIVO');
        var fieldCartCodigo = templateManager.container.getWidget('carta').getField('CODIGO');
        var fieldCartCdStatus = templateManager.container.getWidget('carta').getField('CDSTATUS');
        var fieldCartDescStatus = templateManager.container.getWidget('carta').getField('DSSTATUS');
        var fieldCartSequencia = templateManager.container.getWidget('carta').getField('SEQUENCIA');
        var fieldCartCNPJ = templateManager.container.getWidget('carta').getField('CNPJ');
        var fieldCartDataHora = templateManager.container.getWidget('carta').getField('DATAEHORA');
        var fieldCartProtocolo = templateManager.container.getWidget('carta').getField('PROTOCOLO');
        var fiedlCartCorrecao = templateManager.container.getWidget('carta').getField('CORRECAO');
        var fiedlCartCondUso = templateManager.container.getWidget('carta').getField('CONDICAODEUSO');
        
        if(widget.isValid()){
            if(fieldAmb.value() == '0'){
                fieldAmb.setValue('1');
            }
            General.callRestEngine("df#/consultaSituacaoAtualNF", "Row", row).then((sucess) => {
                if(sucess.dataset.consultaSituacaoAtualNfeNF.length == 0){
                    ScreenService.showMessage("Não foi possivel realizar a consulta. Tente novamente mais tarde." , "warning");
                }else{
                    if(sucess.dataset.consultaSituacaoAtualNfeNF){  
                        if(sucess.dataset.consultaSituacaoAtualNfeNF.verAplic){
                            fieldVerAp.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.verAplic);
                        }
                    
                        if(sucess.dataset.consultaSituacaoAtualNfeNF.aProt){
                            if(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.nProt){
                                fieldProtocolo.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.nProt);
                            }
                            if(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.digVal){
                                fieldDigVal.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.digVal);
                            }
                            if(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.dhRecbto){
                                fieldDataHora.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.dhRecbto);
                            }
                            if(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.xMotivo){
                                fieldDescStatus.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.xMotivo);
                            }else{
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.xMotivo){
                                    fieldDescStatus.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.xMotivo);
                                }
                            }
                            if(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.cStat){
                                fieldCdStatus.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aProt.cStat);
                            }else{
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.cStat){
                                    fieldCdStatus.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.cStat);
                                }
                            }
                        }
                        if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc){
                            if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.length != 0){
                                 widgetCancelamento.isVisible = true;
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.verAplic){
                                    fieldCanVerAp.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.verAplic);
                                }
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.cStat){
                                    fieldCanCdStatus.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.cStat);
                                }
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.xMotivo){
                                    fieldCanDescStatus.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.xMotivo);
                                }
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.dhRecbto){
                                    fieldCanDataHora.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.dhRecbto);
                                }
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.nProt){
                                   fieldCanProtocolo.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.nProt);
                                }
                                if(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.xJust){
                                  fieldCanMotivo.setValue(sucess.dataset.consultaSituacaoAtualNfeNF.aCanc.xJust);
                                }
                            }else{
                                widgetCancelamento.isVisible = false;
                            }
                        }
                        if(sucess.dataset.consultaSituacaoAtualNfeNF.aEvent){
                            sucess.dataset.consultaSituacaoAtualNfeNF.aEvent.forEach(dados => {
                                dados.forEach(dado => {
                                    if(dado.tpEvento == 110111 || dado.tpEvento == 110112){
                                        widgetCancelamento.isVisible = true; 
                                        if(dado.cOrgao){
                                            fieldCanCodigo.setValue(dado.cOrgao);
                                        }
                                        if(dado.CNPJDest){
                                            fieldCanCNPJ.setValue(dado.CNPJDest);
                                        }
                                        if(dado.nSeqEvento){
                                            fieldCanSequencia.setValue(dado.nSeqEvento);
                                        }
                                    }else if(dado.tpEvento == 110110){
                                       widgetCarta.isVisible = true; 
                                       if(dado.cOrgao){
                                            fieldCartCodigo.setValue(dado.cOrgao);
                                        }
                                        if(dado.CNPJDest){
                                            fieldCartCNPJ.setValue(dado.CNPJDest);
                                        }
                                        if(dado.nSeqEvento){
                                            fieldCartSequencia.setValue(dado.nSeqEvento);
                                        }
                                        if(dado.verAplic){
                                            fieldCartVerAp.setValue(dado.verAplic);
                                        }
                                        if(dado.cStat){
                                            fieldCartCdStatus.setValue(dado.cStat);
                                        }
                                        if(dado.xMotivo){
                                            fieldCartDescStatus.setValue(dado.xMotivo);
                                        }
                                        if(dado.nSeqEvento){
                                            fieldCartSequencia.setValue(dado.nSeqEvento);
                                        }
                                        if(dado.xMotivo){
                                            fieldCartDescStatus.setValue(dado.xMotivo);
                                        }
                                        if(dado.dhRegEvento){
                                            fieldCartDataHora.setValue(dado.dhRegEvento);
                                        }
                                        if(dado.nProt){
                                            fieldCartProtocolo.setValue(dado.nProt);
                                        }
                                        if(dado.xCorrecao){
                                            fiedlCartCorrecao.setValue(dado.xCorrecao);
                                        }
                                        if(dado.xCondUso){
                                            fiedlCartCondUso.setValue(dado.xCondUso);
                                        }
                                    } 
                                });
                                
                            });
                        } 
                    }
                }
                
            });	
        }
    };
    
    this.sincronizaDadosNF = function(widget){
        var cabecalho = templateManager.container.getWidget('cabecalho');
        var row = widget.currentRow;
        row.CDFILIAL = cabecalho.currentRow.CDFILIAL;
        row.NRLANCTONF = cabecalho.currentRow.NRLANCTONF;
        //localStorageEngine.getDataSource("df#/config_transmissao").then(function(transmissao){
            //row.CONFIG = transmissao[0].config;
            General.callRestEngine("df#/sincronizaDadosNF", "Row", row).then((sucess) => {
                if(sucess.dataset.sincronizaNF.ERRO){
                     ScreenService.showMessage(sucess.dataset.sincronizaNF.ERRO, "warning");
                }else if(sucess.dataset.sincronizaNF.SUCESS){
                     ScreenService.successNotification(sucess.dataset.sincronizaNF.SUCESS);
                }
            //});
        });
    };
    
    
    this.closePopup = function(widget){
        var widgetAutoriza = templateManager.container.getWidget('autorizacaoDenegacao');
        var widgetCarta = templateManager.container.getWidget('carta');
        var widgetCancelamento = templateManager.container.getWidget('cancelamento');
        
        widgetAutoriza.isVisible = false;
        widgetCarta.isVisible = false;
        widgetCancelamento.isVisible = false;
        
        widget.activate();
        this.adicionaValorFields(widget);
        ScreenService.closePopup(widget);
    };
    
    this.actSalvaEntradaSemNota = function(widget) {
        Df11000_Lancamento_Service.getStatusNota(widget.getParent().currentRow).then(salvaNota => {
             if(salvaNota) {
                var itens = widget.getCheckedRows(),
                    cabecalho = templateManager.container.getWidget('cabecalho').currentRow,
                    rows = { cabecalho : cabecalho,
                             itens : itens };
                        
                General.callRestEngine("df#/salvarNotaOperacaoOnze", "DataSet", rows).then(() => {	
                    this.actClosePopupEntradaSemnota();	
                    templateManager.container.getWidget('entrada_semnf').reload();	
                    removeDataSourcesConsultaLancEntradaActionEvent();	
                    criaDetalhesLancamentoWidgetAfterMoveRow(cabecalho);
                    ScreenService.successNotification('Notas Fiscais relacionadas com sucesso.');	
                    alteraStatusNotafiscal(templateManager.container.getWidget('cabecalho'), true);	
                }, (error) => {	
                    ScreenService.errorRequest("Ocorreu um erro ao relacionar as notas.");	
                });
             }
             else MessageService.showMessageByCode('BLOCK_NOTE');
         }, requestError);
    };	
    	
    this.actExcluirEntradaSemNota = function(widget) {	
        var row = widget.currentRow;	
        General.callRestEngine("df#/excluirRelacionamentoOpOnze", "Row", row).then(() => {	
            this.actClosePopupEntradaSemnota();	
            templateManager.container.getWidget('entrada_semnf').reload();	
            removeDataSourcesConsultaLancEntradaActionEvent();	
            criaDetalhesLancamentoWidgetAfterMoveRow(row);	
            ScreenService.successNotification('Exclusão realizada com sucesso.');	
        });	
    };
    
    this.sgEstadoNotaOnChange = function(widget) {
        widget.getField('NMMUNICIPIONOTA').readOnly = widget.currentRow.SGESTADONOTA ? false : true;
        widget.currentRow.CDMUNICIPIO = null;
        widget.currentRow.CDMUNICIPIONOTA = null;
        widget.currentRow.NMMUNICIPIONOTA = null;
        widget.currentRow.SGESTADO = widget.currentRow.SGESTADONOTA;
        if (widget.currentRow.SGESTADONOTA) {
    		widget.getField('NMMUNICIPIONOTA').dataSourceFilter.forEach(data => {
    		    if(data.name == "SGESTADO") data.value = widget.currentRow.SGESTADONOTA;
    		});
        }
    };
    
    this.nmMunicipioNotaOnChange = function(widget) {
        widget.currentRow.CDMUNICIPIO = widget.currentRow.CDMUNICIPIONOTA;
   };
    
    this.controlVisibilityLocalPrestServ = function(widget) {
        let rowCDTIPOOPER = widget.currentRow.CDTIPOOPER;
        let fieldSGESTADONOTA = widget.getField('SGESTADONOTA');
        let fieldNMMUNICIPIONOTA = widget.getField('NMMUNICIPIONOTA');
        let dsNMTIPOOPER = widget.getField('NMTIPOOPER').dataSource.data;
        let utilizaLocalPrestServ = false;
        
        for(let data in dsNMTIPOOPER) {
            if(rowCDTIPOOPER === dsNMTIPOOPER[data].CDTIPOOPER) {
                if(dsNMTIPOOPER[data].IDUTLOCPRESTSERV === 'S') {
                    utilizaLocalPrestServ = true;
                }
                break;
            }
        }
        if(widget.editing) { //True = Add e edit nota.
            if(utilizaLocalPrestServ) {
                if(widget.currentRow.__is_new) {
                    widget.currentRow.CDMUNICIPIONOTA = null;
                    widget.currentRow.NMMUNICIPIONOTA = null;
                    widget.currentRow.SGESTADONOTA = null;
                    widget.currentRow.NMESTADONOTA = null;
                } else {
                    if (widget.currentRow.SGESTADONOTA) {
                        widget.getField('NMMUNICIPIONOTA').dataSourceFilter.forEach(data => {
                		    if(data.name == "SGESTADO") data.value = widget.currentRow.SGESTADONOTA;
                		});
                    }
                }
                widget.fieldGroups.forEach(group => {
                    if(group.name === 'prestacaoServico') {
                        group.isVisible = true;
                        group.opened = true;
                    }
                });
                widget.currentRow.SGESTADO = widget.currentRow.SGESTADONOTA;
                widget.currentRow.CDMUNICIPIO = widget.currentRow.CDMUNICIPIONOTA;
                fieldSGESTADONOTA.isVisible = true;
                fieldSGESTADONOTA.readOnly = false;
                fieldSGESTADONOTA.validations.required = true;
                fieldNMMUNICIPIONOTA.isVisible = true;
                fieldNMMUNICIPIONOTA.readOnly = widget.currentRow.SGESTADONOTA ? false : true;
                fieldNMMUNICIPIONOTA.validations.required = true;
            } else {
                widget.fieldGroups.forEach(group => {
                    if(group.name === 'prestacaoServico') {
                        group.isVisible = false;
                        group.opened = false;
                    }
                });
                fieldSGESTADONOTA.isVisible = false;
                fieldSGESTADONOTA.readOnly = true;
                fieldSGESTADONOTA.validations.required = false;
                fieldNMMUNICIPIONOTA.isVisible = false;
                fieldNMMUNICIPIONOTA.readOnly = true;
                fieldNMMUNICIPIONOTA.validations.required = false;
            }
        } else { //False = Visualizar nota.
            if(utilizaLocalPrestServ) {
                widget.fieldGroups.forEach(group => {
                    if(group.name === 'prestacaoServico') {
                        group.isVisible = true;
                    }
                });
                fieldSGESTADONOTA.isVisible = true;
                fieldNMMUNICIPIONOTA.isVisible = true;
            } else {
                widget.fieldGroups.forEach(group => {
                    if(group.name === 'prestacaoServico') {
                        group.isVisible = false;
                    }
                });
                fieldSGESTADONOTA.isVisible = false;
                fieldNMMUNICIPIONOTA.isVisible = false;
            }
        }
   };
   
    var validaVisibilidadeActionDocComp = function(widgetCabecalho) {
        var action = widgetCabecalho.getAction('actDocumentosComposicaoCustos');
        
        if(widgetCabecalho.currentRow.IDSTATUS == 'P') 
            action.isVisible = true;
        else 
            action.isVisible = false; 
    
    };
    
    var salvaImpostosTmpItemNotaXML = function() {
        var rowCabecalho = getCabecalhoWidget().currentRow,
            dataItens = getItensWidget().dataSource.data,
            rowSave = [],
            filter = [{"name": "CDFILIAL", "operator": "=", "value": rowCabecalho.CDFILIAL},
                      {"name": "NRLANCTONF", "operator": "=", "value": rowCabecalho.NRLANCTONF},
                      {"name": "NRORG", "operator": "=", "value": rowCabecalho.NRORG}];
        
        General.callRestEngine("df#/crud/itemproimpos", "FilterData", filter).then((success) => {
            dataItens.forEach( item => {
                success.dataset.itemproimpos.forEach( imposto => {
                    if(item.NRSEQITPROD == imposto.NRSEQITPROD) {
                       rowSave.push(imposto);
                    }
                });
            });
            
            Dfe11000_LancamentoEntrada_Service.insereTrabitproimpos(rowSave);

        });
    };
    
    /********************************* Bloco Referente ao Produto -> Detalhamento Específico de Combustíveis *********************************/
    /************************** Fonte compartilhado entre as telas lançamento de entrada e saída evitando duplicar código ********************/
    this.detCombOnEnterTab = (widget) => {
        Df11000_Lancamento_Service.getDataSourceItensCombs().then(resp => {
            let allActionsCombs = widget.getActions().filter(action => action.name !== 'actVoltarComb'),
                dataRow = resp.find(data => data.NRSEQITPROD === widget.getParent().currentRow.NRSEQITPROD),
                statusAceitosNFE = {P: {}, R: {}};
                
            widget.dataSource.data = resp;
            widget.currentRow = dataRow ? dataRow : [];
            
            allActionsCombs.forEach(action => {
                if(widget.getParent().getParent().currentRow.IDSTATUS === 'P' &&
                widget.getParent().getParent().currentRow.IDSTATUSNFE in statusAceitosNFE)
                    action.isVisible = true;
                else
                    action.isVisible = false;
                    
                if(action.name === 'actExcluirComb' && action.isVisible && !dataRow)
                    action.isVisible = false;
            });
        });
   };
   
   this.editDetComb = (widget) => {
       if(!widget.currentRow.hasOwnProperty('__is_new')) widget.newRow();
       General.edit(widget);
   };
   
   this.cancelDetComb = (widget) => {
       if(widget.currentRow.changed) this.detCombOnEnterTab(widget);
       widget.list();
   };
   
   this.removeDetComb = (widget) => {
       MessageService.confirmMessageByCode("REGISTRO_EXCLUIR").then(sucess => {
           Df11000_Lancamento_Service.getStatusNota(widget.currentRow).then(salvaNota => {
               if(salvaNota) {
                   General.callRestEngine('df#/crud/detespcombnfe/remove', "Row", widget.currentRow).then(resp => {
                       
                       //Tabela filha não precisa ser manipulada devido a CONSTRAINT ON DELETE CASCADE.
                       if(resp.notifications[0].type == 'success') {
                           MessageService.successNotificationByCode('REGISTRO_EXCLUIDO');
                           Df11000_Lancamento_Service.excluiItemCombsDataSource(widget.currentRow.NRSEQITPROD).then(() => {
                               widget.getAction('actExcluirComb').isVisible = false;
                               widget.currentRow = [];
                               widget.reload();
                           });
                       }
                       else MessageService.errorNotificationByCode('ERRO_GERAL');
                   }, requestError);
               }
               else MessageService.showMessageByCode('BLOCK_NOTE');
           }, requestError);
       });
   };
   
   this.cideCombsOnChange = (row) => {
       if(!Util.isEmptyOrBlank(row.VRBCCIDE) && !Util.isEmptyOrBlank(row.VRALIQCIDE)) {
           row.VRBCCIDE   = General.valueToFloat(row.VRBCCIDE);
           row.VRALIQCIDE = General.valueToFloat(row.VRALIQCIDE);
           
           row.VRCIDE = (row.VRBCCIDE * (row.VRALIQCIDE / 100)).toFixed(2);
       }
       else row.VRCIDE = null;
   };
   
   this.validSaveComb = (widget, row) => {
       if(widget.isValid()) {
           Df11000_Lancamento_Service.getStatusNota(row).then(salvaNota => {
               if(salvaNota) {
                   let gravaDados = true;
                   
                   if((Util.isEmptyOrBlank(row.VRBCCIDE) && !Util.isEmptyOrBlank(row.VRALIQCIDE)) || (!Util.isEmptyOrBlank(row.VRBCCIDE) && Util.isEmptyOrBlank(row.VRALIQCIDE))) {
                        MessageService.showMessageByCode('ITEMCOMBS_ERRO_CIDE', null, {type: 'ERROR'});
                        gravaDados = false;
                    }
                    else if(!Util.isEmptyOrBlank(row.NRBICO) || !Util.isEmptyOrBlank(row.NRTANQUE) || !Util.isEmptyOrBlank(row.VRENCERRAINI)
                            || !Util.isEmptyOrBlank(row.VRENCERRAFIM) || !Util.isEmptyOrBlank(row.NRBOMBA)) {
                                
                        if(Util.isEmptyOrBlank(row.NRBICO) || Util.isEmptyOrBlank(row.NRTANQUE) || Util.isEmptyOrBlank(row.VRENCERRAINI) || Util.isEmptyOrBlank(row.VRENCERRAFIM)) {
                            
                            MessageService.showMessageByCode('ITEMCOMBS_ERRO_ENCERRANTE', null, {type: 'ERROR'});
                            gravaDados = false;
                        }
                    }
                    if(gravaDados) this.saveDetComb(widget, row);
               }
               else MessageService.showMessageByCode('BLOCK_NOTE');
           }, requestError);
       }
   };
   
   this.saveDetComb = (widget, row) => {
        let dadosCombs = Object.assign({}, row), detCide = {}; 
        delete dadosCombs.VRBCCIDE; delete dadosCombs.VRALIQCIDE; delete dadosCombs.VRCIDE;
        
        //Inicio. Tabela principal - DETESPCOMBNFE.
        General.callRestEngine('df#/crud/detespcombnfe/save', "Row", dadosCombs).then(resp => { //Linha toda nova ou atualiza a existente.
            if(resp.dataset.columnsToReturn) {
                MessageService.successNotificationByCode('REGISTRO_SALVO');
                
                //Tabela filha CIDE - GRCIDEDETCOMB.
                detCide.CDFILIAL = row.CDFILIAL; detCide.NRLANCTONF = row.NRLANCTONF; detCide.NRSEQITPROD = row.NRSEQITPROD; detCide.CDGRCIDEDETCOMB = '0001';
                detCide.VRBCCIDE = row.VRBCCIDE; detCide.VRALIQCIDE = row.VRALIQCIDE; detCide.VRCIDE      = row.VRCIDE;
                
                if(row.__is_new && !Util.isEmptyOrBlank(row.VRCIDE)) { //Linha toda nova.
                    detCide.__is_new = true;
                    General.callRestEngine('df#/crud/grcidedetcomb/save', "Row", detCide).then(() => {
                        this.updateLocalStorageCombs(row, widget);
                    }, requestError);
                }
                else {
                    let filter = [{"name":"CDFILIAL"   , "operator":"=", "value": row.CDFILIAL},
                                  {"name":"NRLANCTONF" , "operator":"=", "value": row.NRLANCTONF},
                                  {"name":"NRSEQITPROD", "operator":"=", "value": row.NRSEQITPROD}];
                    
                    General.callRestEngine('df#/crud/grcidedetcomb', 'FilterData', filter).then(sucess => { //Pesquisa cide.
                        detCide.__is_new = sucess.dataset.grcidedetcomb.length ? false : true;
                        
                        if(!Util.isEmptyOrBlank(row.VRCIDE)) { //Linha nova cide ou atualiza linha existente.
                            General.callRestEngine('df#/crud/grcidedetcomb/save', "Row", detCide).then(() => {
                                this.updateLocalStorageCombs(row, widget);
                            }, requestError);
                        }
                        else if(sucess.dataset.grcidedetcomb.length) { //Remove linha cide quando foi removido da tela e ainda existe no banco.
                            General.callRestEngine('df#/crud/grcidedetcomb/remove', "Row", detCide).then(() => {
                                this.updateLocalStorageCombs(row, widget);
                            }, requestError);
                        }
                        else this.updateLocalStorageCombs(row, widget);
                    }, requestError);
                }
            } else MessageService.errorNotificationByCode('ERRO_GERAL');
        }, requestError);
   };
   
   this.updateLocalStorageCombs = (row, widget) => {
       if(row.__is_new) row.__is_new = false;
       
       for(let posicao in widget.dataSource.data) {
            if(row.NRSEQITPROD === widget.dataSource.data[posicao].NRSEQITPROD) {
                let newData = Object.assign({}, row);
                
                if(newData.changed)        delete newData.changed;
                if(newData.__createdLocal) delete newData.__createdLocal;
                if(newData.__index)        delete newData.__index;
                
                widget.dataSource.data[posicao] = newData;
                break;
            }
        }
        Df11000_Lancamento_Service.setDataSourceItensCombs(widget.dataSource.data).then(() => {
            this.detCombOnEnterTab(widget);
            widget.list();
        });
   };
   /********************************* FIM - Bloco Referente ao Produto -> Detalhamento Específico de Combustíveis *********************************/
   //comentario para gerar conteudo - resolver conflito
    this.ajusteDSNOTAFISCORIG = () => {
        var data = getCabecalhoWidget().dataSource.data;
        data.forEach(nota => {
            if((nota.DSNOTAFISCORIG) && (nota.DSNOTAFISCORIG != "")){
                let arrayDS = nota.DSNOTAFISCORIG.split(",");
                nota.DSNOTAFISCORIG = arrayDS;
            } else {
                return;
            }
        });
    };
    
     /*****************************************************implementação da rotina: Sugere Almoxarifado/Localização**********************************/
    this.validaSugereAlmox = function(cabecalhoRow){
        
        General.callRestEngine('df#/crud/paramfilial', 'FilterData', []).then(function(success) {
            var filiais =  success.dataset.paramfilial;
            var filialFiltrada;
            
            filiais.forEach(filial=>{
               if(filial.CDFILIAL == getCabecalhoWidget().currentRow.CDFILIRECE) {
                   return ((filialFiltrada = filial));
               }
            });
            if(filialFiltrada){
                if (filialFiltrada.IDUTILALLONF == 'S' && (filialFiltrada.IDUTILALMOX == 'S' || filialFiltrada.IDUTILLCESTQ == 'S')){
                    //var fieldChaveAcesso = templateManager.container.getWidget('cabecalho').getField('NRACESSONFE');
                    if(filialFiltrada.IDUTILLOTE != 'S'){
                        self.setVisibleWidgetAlmox(cabecalhoRow);
                        self.openPopupSugereAlmox();
                    }else{
                    }
                }else{
                    return false; 
                }
            }
        });
    };
    
    this.openPopupSugereAlmox = function() {
        var wdgSuge = templateManager.container.getWidget('WidgetSugereAlmox');
        wdgSuge.isVisible = true;
        ScreenService.openPopup(wdgSuge);
    };
    
    this.closePopupSugereAlmox = function() {
        var wdgSuge = templateManager.container.getWidget('WidgetSugereAlmox');
        ScreenService.closePopup();
        wdgSuge.isVisible = false;
    };
    
     /**Editar e cancelar da widget**/
    this.setEnabled = function(widget, enabled) {
        if (widget.widgets[0]) {
            widget.widgets[0].enabled = enabled;
        }
    };
    
    this.setVisibleWidgetAlmox = function() {
        
        General.callRestEngine('df#/crud/paramfilial', 'FilterData', []).then(function(success) {
            var filiais =  success.dataset.paramfilial;
            var filialFiltrada;
            
            filiais.forEach(filial=>{
              if(filial.CDFILIAL == getCabecalhoWidget().currentRow.CDFILIRECE) {
                  return ((filialFiltrada = filial));
              }
            });
            if(filialFiltrada){
            var idutilalmox = filialFiltrada.IDUTILALMOX;
            var almox = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDALMOXARIFE');
            
            var local = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDLOCALESTOQ');
            
                if (idutilalmox === 'S') {
                var idutillcestq = filialFiltrada.IDUTILLCESTQ;
                    if (idutillcestq === 'S') {
                         almox.readOnly = true;
                         local.readonly = true;
                    }else {
                        almox.isVisible = true;
                        local.isVisible = true;
                        local.readOnly = true;
                         delete local.validations;
                        
                    }
                }
            }

        });
    };
    
   this.actSalvarSugereAlmox = function(widget){
       var nf, dados, indexNota;
      if(widget.isValid()){
 			widget.saveRow().then(function() {
				if (widget.currentRow) {
					//widget.list(true);
					//ScreenService.goBack();
					//widget.reload();
				} else {
					widget.view();
				}
				 var almoxPadrao = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDALMOXARIFE').value();
                 var localPadrao = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDLOCALESTOQ').value();
                 
                 //busca swipe da nota lançada;
                 //getCabecalhoWidget().reload().then(()=>{
                    // nf = getCabecalhoWidget().currentRow;
                    // dados = getCabecalhoWidget().dataSource.data;
                     //indexNota = dados.findIndex(el => el.NRNOTAFISC == nf.NRNOTAFISC);
                   // nf = dados[indexNota];
                    // self.getSwipeNf(nf);
                   //  templateManager.container.getWidget('cabecalho').activate();
                // });
                 
			},function(callback){
					if(callback.data){
						ScreenService.showMessage(callback.data.error);
					}
			});
        
            this.closePopupSugereAlmox();
            sitSugAlmox = true;
            //General.backOrCancel(widget);
            var fieldChaveAcesso = templateManager.container.getWidget('cabecalho').getField('NRACESSONFE');
            if(fieldChaveAcesso.value()){
                var widgetItens = templateManager.container.getWidget("itens");
                widgetItens.dataSource.data[0].CDALMOXARIFE = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDALMOXARIFE').value();
                widgetItens.dataSource.data[0].CDLOCALESTOQ = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDLOCALESTOQ').value();
                General.callRestEngine("df_entrada#/atualizaAlmoxarifado", "Row", widgetItens.dataSource.data).then((cabecalhoRelacionamento) => {
                });
                //for(var i=0 ; i < widget.dataSource.data.length  ; i++){ 
                 //   widget.dataSource.data[i].CDALMOXARIFE = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDALMOXARIFE').value();
                 //   widget.dataSource.data[i].CDLOCALESTOQ = templateManager.container.getWidget('WidgetSugereAlmox').getField('CDLOCALESTOQ').value();
                 //   Dfe11000_LancamentoEntrada_Service.atualizaItemAf(widget.dataSource.data[i]);
               // }
            }   
      }
    };


    this.getSwipeNf = function(nf){
        var widget = getCabecalhoWidget();
        widget.moveToNext();
        while(nf.NRNOTAFISC != widget.currentRow.NRNOTAFIS){
            widget.moveToNext();
        }
        
       // do
        //    getCabecalhoWidget().moveToNext();
        //while (nf.NRNOTAFISC != getCabecalhoWidget().currentRow.NRNOTAFISC);
    };
    
/**fim da implementação da rotina: Sugere Almoxarifado/Localização*/

// Inicio - Processo de Geração de NF Saída da Tela de Lançamento de Entrada
    this.openWidgetLancNfeSaida = function(){
        var wdgSaida;
        if(templateManager.container) wdgSaida = this.getWidget('lancamentoNfeSaida');
        this.habilitaCamposlancamentoNfeSaida(wdgSaida);
        wdgSaida.isVisible = true;
        ScreenService.openPopup(wdgSaida);
        wdgSaida.activate();
    };
    
    this.habilitaCamposlancamentoNfeSaida = (widget)=>{
        var actions = widget.getActions();
        actions.forEach(action => {
            action.isVisible = true;
        });
        
    };
    
    this.closeWidgetLancNfeSaida = function(){
        var widgetOwner     = getCabecalhoWidget();
        var widgetPopup     = this.getWidget('lancamentoNfeSaida');
        
        widgetPopup.reload();
        this.verifyFieldEnabletoDisabled(widgetPopup); 
        this.clearFieldsWidget(widgetPopup);
        widgetPopup.isVisible = false;
        ScreenService.closePopup(widgetPopup.name);
            
        widgetOwner.reload();
    };
    
    //clearFieldsWidget -> passar o campo field como array e a widget pai deste mesmo campo.
    this.clearFieldsWidget = (widgetPopup, field) => {
        
        var fields = field ? field : widgetPopup.fields;
        
        fields.forEach(field => {
            field.setValue("");
        });
        
        widgetPopup.reload();
    };
    
    this.verifyFieldEnabletoDisabled = (pai) => {
        pai.fields.forEach(field => {
        if(field.name == 'NMRAZSOCCLIE' || field.name == 'NMRAZSOCFORN' || field.name == 'DSFILIRECE'){
            
            this.clearFieldsWidget(pai, [field]);
            field.isVisible = false;
            field.showOnForm = false;
            field.showOnList = false;
            field.showOnView = false;
        }});
    };
    
    this.setAnotherFieldsNotRequire = (field, pai) => {
        const destinos = ['NMRAZSOCFORN', 'NMRAZSOCCLIE', 'DSFILIRECE'];
        var name;
        
        name = field.name;
        
        destinos.forEach(destino => {
            
            if(destino != name){
                if(pai.getField(destino).validations) delete pai.getField(destino).validations;
            }
            
        });
        
    };
    
    this.changeFieldDestinatario = args => {
        var pai, dest;
        
        pai = this.getWidget('lancamentoNfeSaida');
        dest = pai.getField('NMTIPOOPER').dataSource.checkedRows[0] ? pai.getField('NMTIPOOPER').dataSource.checkedRows[0].IDORIGDESTOP : "";
        
        switch (dest){
            case "": return this.verifyFieldEnabletoDisabled(pai);
        }  
        
        this.verifyFieldEnabletoDisabled(pai);
        
        const destinos = {
            F: {
                name: 'NMRAZSOCFORN'
            },
            C: {
                name: 'NMRAZSOCCLIE'
            },
            L: {
                name: 'DSFILIRECE'
            }
        };
        
        pai.getField(destinos[`${dest}`].name).isVisible = true;
        pai.getField(destinos[`${dest}`].name).showOnForm = true;
        pai.getField(destinos[`${dest}`].name).showOnList = true;
        pai.getField(destinos[`${dest}`].name).showOnView = true;
        pai.getField(destinos[`${dest}`].name).validations = {required: true};
        
        this.setAnotherFieldsNotRequire(pai.getField(destinos[`${dest}`].name), pai);
    };
    
    this.confirmarLancamentoNfeSaida = args => {
        
        var cabecalho, nf, params, newNf, produtos, widget;
        
        //produtos
        produtos = this.getWidget('itens').dataSource.data;
        
        //impostos
        Df11000_Lancamento_Service.getDataSourceLancamentoNota('lancamento_nota_imposto').then(impostos => {
            
            //widget pai do processo
            widget = this.getWidget('lancamentoNfeSaida');
            
            
            //cabecalho - entrada
            cabecalho = args.owner.widget.getParent();
            
            nf = cabecalho.currentRow;
            nf.produtos = produtos;
            nf.impostos = impostos;
            newNf = args.row;
            
            if(nf.IDSTATUS == 'D' || nf.IDSTATUS == 'C'){
                return ScreenService.errorNotification('A nota não será lançada pois o status atual dela não permite a realização desse processo.');
            }
            
            if(widget.isValid()){
                    
                if((newNf.porcentagemVenda == "") || (newNf.porcentagemVenda == 0) || isNaN(newNf.porcentagemVenda)){
                    newNf.porcentagemVenda = 0;
                }
                
                params = {
                  "nfEntrada": nf,
                  "nfSaida": newNf
                };
                
                General.callRestEngine("df_entrada#/lancNfSaida","Row",params).then(respBack => {
                    if (respBack.dataset.lancNfSaida.erros.length > 0){
                        respBack.dataset.lancNfSaida.erros.forEach(erro => {
                            if(typeof(erro) == 'string'){
                                ScreenService.errorNotification(erro);
                            }else{
                                console.log("Error: ", erro);
                            }
                        });
                        //Processo de exclusão da nota de saída
                        if (typeof respBack.dataset.lancNfSaida.nfSaida.NRLANCTONF != "undefined") {
                            if(respBack.dataset.lancNfSaida.nfSaida.NRLANCTONF) this.deleteNfSaida(respBack.dataset.lancNfSaida.nfSaida);
                        }
                        
                        return;
                        
                    }else{
                        this.closeWidgetLancNfeSaida();
                        ScreenService.closePopup();
                        ScreenService.successNotification("A nota foi gerada com sucesso");
                    }
                });
            }
        });
    };
    
    this.deleteNfSaida = (nf) =>{
        Df11000_Lancamento_Service.excluir_nota_saida(nf);
    };
    
    //validações necessárias para selecionar os produtos
    this.validaSelecaoProdutos = (CDTIPOOPER, CDFILIRECE, CDEMPRESA, field, args, multiItens = false, manual = true) => {
        var row;
        var produtos = [];
        
        if(CDTIPOOPER != '01'){
            return;
        }else{
           
            if(manual){
                if(!multiItens){
                    if(field.value() == ""){
                        args.owner.owner.widget.getField("DSPRODEMIS").setValue('');
                        args.owner.owner.widget.getField("CDPRODEMIS").setValue('');
                        return;
                    }
                }
                
                args.dataSource.forEach(produto => {
                    if(produto.CDPRODUTO != null) {
                        
                        var obj = {
                            CDPRODUTO: produto.CDPRODUTO,
                            boo: ""
                        };
                        
                        produtos.push(obj);
                    }else{
                        produtos.push(null);
                    }
                });
                
                row = {
                    "CDTIPOOPER": CDTIPOOPER,
                    "CDFILIAL": CDFILIRECE,
                    "CDEMPRESA": CDEMPRESA,
                    "Produtos": produtos
                };
            }else{
                var currentProd = args.owner.field.dataSource.checkedRows[0];
                
                if(currentProd.CDPRODUTO != null){
                    var obj = {
                                CDPRODUTO: args.owner.field.dataSource.checkedRows[0].CDPRODUTO,
                                boo: ""
                            };
                            
                    produtos.push(obj);
                    
                }
                        
                row = {
                    "CDTIPOOPER": CDTIPOOPER,
                    "CDFILIAL": CDFILIRECE,
                    "CDEMPRESA": CDEMPRESA,
                    "Produtos": produtos
                };
            }
            
            
            General.callRestEngine("df#/getParamsValidacaoProdutosEntrTipoOp","Row", row).then(respBack => {
                let response = respBack.dataset.validacoesProdutoEntrada[0];
                let cancel = false;
                let prodErros = [];
                response.produtos.forEach(produto => {
                    if ((((CDTIPOOPER == '01') && (response.IDBLOQPRESTO == 'S')) || ((response.IDBLOQPRESTTPOP == 'S') && (response.IDFUNCAOFILI != 'O' ))) && produto.boo) {
                        if(manual){
                            if(!multiItens){
                                field.setValue("");
                                
                                field.reload();
                            }
                            
                            cancel = true;
                        }else{
                            prodErros.push(produto);
                            cancel = true;
                        }
                        
                    }
                });
                
                if(cancel){
                    if(manual){
                        if(multiItens){
                            self.actCancelarItemOnClick(args);
                        }else{
                            args.owner.owner.widget.getField("DSPRODEMIS").setValue('');
                            args.owner.owner.widget.getField("CDPRODEMIS").setValue('');
                        }
                        return MessageService.showMessageByCode("PROD_EST_NF_COMPRA");
                    }else{
                        args.owner.field.getParent().getField('CDARVPRODFORNXML').setValue('');
                        args.owner.field.getParent().getField('NMPRODUTOFORNXML').setValue('');
                        return MessageService.showMessageByCode("PROD_EST_NF_COMPRA");
                
                    }
                }else{
                    if(manual){
                        if(multiItens){
                            this.actSalvarMultiItemOnClick(args);
                        }
                        
                        this.validacoesProdutoOnChange(args);
                    }
                } 
            });
    
        }
    };
    
// Final - Processo de Geração de NF Saída da Tela de Lançamento de Entrada
};
    
Configuration(function(ContextRegister) {
    ContextRegister.register('Dfe11000_LancamentoEntrada_Controller', Dfe11000_LancamentoEntrada_Controller);
});